'use strict';

/**
 * @author schukai GmbH
 */

import {assignToNamespace, Monster} from '../namespace.js';
import {Base} from '../types/base.js';


/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 * 
 * The abstract constraint defines the api for all constraints. mainly the method isValid() is defined.
 *
 * derived classes must implement the method isValid().
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary The abstract constraint
 */
class AbstractConstraint extends Base {

    /**
     *
     */
    constructor() {
        super();
    }

    /**
     * this method must return a promise containing the result of the check.
     *
     * @param {*} value
     * @returns {Promise}
     */
    isValid(value) {
        return Promise.reject(value);
    }
}

assignToNamespace('Monster.Constraints', AbstractConstraint);
export {Monster, AbstractConstraint}