'use strict';

/**
 * @author schukai GmbH
 */
import {assignToNamespace, Monster} from '../namespace.js';
import {AbstractConstraint} from "./abstract.js";

/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * Operators allow you to link constraints together. for example, you can check whether a value is an object or an array. each operator has two operands that are linked together.
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary The abstract operator constraint
 */
class AbstractOperator extends AbstractConstraint {

    /**
     *
     * @param {AbstractConstraint} operantA
     * @param {AbstractConstraint} operantB
     * @throws {TypeError} "parameters must be from type AbstractConstraint"
     */
    constructor(operantA, operantB) {
        super();

        if (!(operantA instanceof AbstractConstraint) || !(operantB instanceof AbstractConstraint)) {
            throw new TypeError("parameters must be from type AbstractConstraint")
        }

        this.operantA = operantA;
        this.operantB = operantB;

    }


}

assignToNamespace('Monster.Constraints', AbstractOperator);
export {Monster, AbstractOperator}