'use strict';

/**
 * @author schukai GmbH
 */

import {internalSymbol} from "../../../constants.js";
import {assignToNamespace, Monster} from '../../../namespace.js';

/**
 * Error message for API requests with extension of request and validation.
 * 
 * @since 1.24.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data.Datasource.RestAPI
 * @summary the error is thrown by the rest api in case of error
 */
class WriteError extends Error {
    /**
     *
     * @param {string} message
     * @param {Response} response
     */
    constructor(message, response, validation) {
        super(message);
        this[internalSymbol] = {
            response: response,
            validation: validation
        };
    }

    /**
     * @return {Response}
     */
    getResponse() {
        return this[internalSymbol]['response']
    }

    /**
     * @return {Object}
     */
    getValidation() {
        return this[internalSymbol]['validation']
    }
}


assignToNamespace('Monster.Data.Datasource.RestAPI', WriteError);
export {Monster, WriteError}