'use strict';

/**
 * @author schukai GmbH
 */

import {internalSymbol} from "../../../constants.js";
import {assignToNamespace, Monster} from '../../../namespace.js';
import {getGlobalObject} from "../../../types/global.js";
import {Datasource} from "../../datasource.js";
import {Storage, storageObjectSymbol} from "../storage.js";


/**
 * 
 * 
 * You can create an object of this class using the monster namespace `Monster.Data.Datasource.Storage.LocalStorage()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Data.Datasource.Storage.LocalStorage()
 * </script>
 * ```
 *
 * Alternatively you can import the class directly
 *
 * ```
 * <script type="module">
 * import {LocalStorage} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/datasource/storage/localstorage.js';
 * new LocalStorage()
 * </script>
 * ```
 *
 * @since 1.22.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data.Datasource.Storage
 * @summary The LocalStorage class encapsulates the access to data objects.
 */
class LocalStorage extends Storage {

    /**
     * @throws {Error} this method must be implemented by derived classes.
     * @return {external:localStorage}
     * @private
     */
    [storageObjectSymbol]() {
        return getGlobalObject('localStorage');
    }

    /**
     * Create clone
     * @return {LocalStorage}
     */
    getClone() {
        const self = this;
        return new LocalStorage(self[internalSymbol].getRealSubject()['options'].key);
    }


}

assignToNamespace('Monster.Data.Datasource.Storage', LocalStorage);
export {Monster, LocalStorage}
