'use strict';

/**
 * @author schukai GmbH
 */

import {internalSymbol} from "../../../constants.js";
import {assignToNamespace, Monster} from '../../../namespace.js';
import {getGlobalObject} from "../../../types/global.js";
import {Datasource} from "../../datasource.js";
import {Storage, storageObjectSymbol} from "../storage.js";

/**
 * You can create an object of this class using the monster namespace `Monster.Data.Datasource.Storage.SessionStorage()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Data.Datasource.Storage.SessionStorage()
 * </script>
 * ```
 *
 * Alternatively you can import the class directly
 *
 * ```
 * <script type="module">
 * import {SessionStorage} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/datasource/storage/sessionstorage.js';
 * new SessionStorage()
 * </script>
 * ```
 *
 * @since 1.22.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data.Datasource.Storage
 * @summary The LocalStorage class encapsulates the access to data objects.
 */
class SessionStorage extends Storage {

    /**
     * @throws {Error} this method must be implemented by derived classes.
     * @return {external:sessionStorage}
     * @private
     */
    [storageObjectSymbol]() {
        return getGlobalObject('sessionStorage');
    }

    /**
     * Create Clone
     * 
     * @return {SessionStorage}
     */
    getClone() {
        const self = this;
        return new SessionStorage(self[internalSymbol].getRealSubject()['options'].key);
    }

}

assignToNamespace('Monster.Data.Datasource.Storage', SessionStorage);
export {Monster, SessionStorage}
