'use strict';

import {Monster} from '../namespace.js';
/**
 * @author schukai GmbH
 */


/**
 * default theme
 * @memberOf Monster.DOM
 * @type {string}
 */
const DEFAULT_THEME = 'monster';

/**
 * @memberOf Monster.DOM
 * @since 1.8.0
 * @type {string}
 */
const ATTRIBUTE_PREFIX = 'data-monster-';

/**
 * This is the name of the attribute to pass options to a control
 *
 * @memberOf Monster.DOM
 * @since 1.8.0
 * @type {string}
 */
const ATTRIBUTE_OPTIONS = ATTRIBUTE_PREFIX + 'options';

/**
 * This is the name of the attribute to pass options to a control
 *
 * @memberOf Monster.DOM
 * @since 1.30.0
 * @type {string}
 */
const ATTRIBUTE_OPTIONS_SELECTOR = ATTRIBUTE_PREFIX + 'options-selector';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */
const ATTRIBUTE_THEME_PREFIX = ATTRIBUTE_PREFIX + 'theme-';

/**
 * @memberOf Monster.DOM
 * @type {string}
 */
const ATTRIBUTE_THEME_NAME = ATTRIBUTE_THEME_PREFIX + 'name';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */
const ATTRIBUTE_UPDATER_ATTRIBUTES = ATTRIBUTE_PREFIX + 'attributes';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.27.1
 */
const ATTRIBUTE_UPDATER_SELECT_THIS = ATTRIBUTE_PREFIX + 'select-this';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */
const ATTRIBUTE_UPDATER_REPLACE = ATTRIBUTE_PREFIX + 'replace';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */
const ATTRIBUTE_UPDATER_INSERT = ATTRIBUTE_PREFIX + 'insert';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */
const ATTRIBUTE_UPDATER_INSERT_REFERENCE = ATTRIBUTE_PREFIX + 'insert-reference';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */
const ATTRIBUTE_UPDATER_REMOVE = ATTRIBUTE_PREFIX + 'remove';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.9.0
 */
const ATTRIBUTE_UPDATER_BIND = ATTRIBUTE_PREFIX + 'bind';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.27.0
 */
const ATTRIBUTE_TEMPLATE_PREFIX = ATTRIBUTE_PREFIX + 'template-prefix';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.14.0
 */
const ATTRIBUTE_ROLE = ATTRIBUTE_PREFIX + 'role';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.24.0
 */
const ATTRIBUTE_DISABLED = 'disabled';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.24.0
 */
const ATTRIBUTE_VALUE = 'value';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.9.0
 */
const ATTRIBUTE_OBJECTLINK = ATTRIBUTE_PREFIX + 'objectlink';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.24.0
 */
const ATTRIBUTE_ERRORMESSAGE = ATTRIBUTE_PREFIX + 'error';

/**
 * @memberOf Monster.DOM
 * @type {symbol}
 * @since 1.24.0
 */
const objectUpdaterLinkSymbol = Symbol('monsterUpdater');

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const TAG_SCRIPT = 'script';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const TAG_STYLE = 'style';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const TAG_LINK = 'link';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

const ATTRIBUTE_ID = 'id';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

const ATTRIBUTE_CLASS = 'class';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_TITLE = 'title';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_SRC = 'src';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_HREF = 'href';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_TYPE = 'type';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_NONCE = 'nonce';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_TRANSLATE = 'translate';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_TABINDEX = 'tabindex';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_SPELLCHECK = 'spellcheck';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_SLOT = 'slot';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_PART = 'part';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_LANG = 'lang';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ITEMTYPE = 'itemtype';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ITEMSCOPE = 'itemscope';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ITEMREF = 'itemref';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ITEMID = 'itemid';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ITEMPROP = 'itemprop';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_IS = 'is';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_INPUTMODE = 'inputmode';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ACCESSKEY = 'accesskey';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_AUTOCAPITALIZE = 'autocapitalize';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_AUTOFOCUS = 'autofocus';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_CONTENTEDITABLE = 'contenteditable';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_DIR = 'dir';

/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_DRAGGABLE = 'draggable';


/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_ENTERKEYHINT = 'enterkeyhint';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_EXPORTPARTS = 'exportparts';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */
const ATTRIBUTE_HIDDEN = 'hidden';


export {
    Monster,
    ATTRIBUTE_HIDDEN,
    ATTRIBUTE_EXPORTPARTS,
    ATTRIBUTE_ENTERKEYHINT,
    ATTRIBUTE_DRAGGABLE,
    ATTRIBUTE_DIR,
    ATTRIBUTE_CONTENTEDITABLE,
    ATTRIBUTE_AUTOFOCUS,
    ATTRIBUTE_AUTOCAPITALIZE,
    ATTRIBUTE_ACCESSKEY,
    TAG_SCRIPT,
    TAG_LINK,
    ATTRIBUTE_INPUTMODE,
    ATTRIBUTE_IS,
    ATTRIBUTE_ITEMPROP,
    ATTRIBUTE_ITEMID,
    ATTRIBUTE_ITEMREF,
    ATTRIBUTE_ITEMSCOPE,
    TAG_STYLE,
    ATTRIBUTE_ITEMTYPE,
    ATTRIBUTE_HREF,
    ATTRIBUTE_LANG,
    ATTRIBUTE_PART,
    ATTRIBUTE_SLOT,
    ATTRIBUTE_SPELLCHECK,
    ATTRIBUTE_SRC,
    ATTRIBUTE_TABINDEX,
    ATTRIBUTE_TRANSLATE,
    ATTRIBUTE_NONCE,
    ATTRIBUTE_TYPE,
    ATTRIBUTE_TITLE,
    ATTRIBUTE_CLASS,
    ATTRIBUTE_ID,
    ATTRIBUTE_PREFIX,
    ATTRIBUTE_OPTIONS,
    DEFAULT_THEME,
    ATTRIBUTE_THEME_PREFIX,
    ATTRIBUTE_ROLE,
    ATTRIBUTE_THEME_NAME,
    ATTRIBUTE_UPDATER_ATTRIBUTES,
    ATTRIBUTE_UPDATER_REPLACE,
    ATTRIBUTE_UPDATER_INSERT,
    ATTRIBUTE_UPDATER_INSERT_REFERENCE,
    ATTRIBUTE_UPDATER_REMOVE,
    ATTRIBUTE_UPDATER_BIND,
    ATTRIBUTE_OBJECTLINK,
    ATTRIBUTE_DISABLED,
    ATTRIBUTE_ERRORMESSAGE,
    ATTRIBUTE_VALUE,
    objectUpdaterLinkSymbol,
    ATTRIBUTE_TEMPLATE_PREFIX,
    ATTRIBUTE_UPDATER_SELECT_THIS,
    ATTRIBUTE_OPTIONS_SELECTOR
} 