'use strict';

/**
 * @author schukai GmbH
 */

import {extend} from "../../../data/extend.js";
import {assignToNamespace, Monster} from "../../../namespace.js";
import {Link} from "../link.js";


/**
 * This class is used by the resource manager to embed external resources.
 *
 * You can call the method via the monster namespace `new Monster.DOM.Resource.Link.Stylesheet()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.Resource.Link.Stylesheet()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Style} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/resource/link/stylesheet.js';
 * new Stylesheet()
 * </script>
 * ```
 *
 * @since 1.25.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM.Resource
 * @summary A Resource class
 * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link
 */
class Stylesheet extends Link {

    /**
     * @property {string} rel {@link https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link#attr-rel}
     */
    get defaults() {
        return extend({}, super.defaults, {
            rel: 'stylesheet'
        })
    }

}


assignToNamespace('Monster.DOM.Resource.Link', Stylesheet);
export {Monster, Stylesheet}
