'use strict';

/**
 * @author schukai GmbH
 */
import {assignToNamespace, Monster} from '../namespace.js';
import {BaseWithOptions} from "../types/basewithoptions.js";
import {Locale} from "./locale.js"
import {Translations} from "./translations.js"

/**
 * A provider makes a translation object available.
 *
 * You can call the method via the monster namespace `new Monster.I18n.Provider()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.I18n.Provider()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Provider} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/provider.js';
 * new Provider()
 * </script>
 * ```
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.I18n
 * @see {@link https://datatracker.ietf.org/doc/html/rfc3066}
 */
class Provider extends BaseWithOptions {

    /**
     * @param {Locale|string} locale
     * @return {Promise}
     */
    getTranslations(locale) {
        return new Promise((resolve, reject) => {
            try {
                resolve(new Translations(locale));
            } catch (e) {
                reject(e);
            }

        });
    }

}


assignToNamespace('Monster.I18n', Provider);
export {Monster, Provider}
