'use strict';

/**
 * @author schukai GmbH
 */

import {assignToNamespace, Monster} from '../namespace.js';
import {Base} from '../types/base.js';
import {validateInteger} from '../types/validate.js';


/**
 * you can call the method via the monster namespace `new Monster.Logging.LogEntry()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Logging.LogEntry())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {ID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/logging/logentry.js';
 * console.log(new LogEntry())
 * </script>
 * ```
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Logging
 */
class LogEntry extends Base {
    /**
     *
     * @param {Integer} loglevel
     * @param {...*} args
     */
    constructor(loglevel, ...args) {
        super();
        validateInteger(loglevel);

        this.loglevel = loglevel
        this.arguments = args
    }

    /**
     *
     * @returns {integerr}
     */
    getLogLevel() {
        return this.loglevel
    }

    /**
     *
     * @returns {array}
     */
    getArguments() {
        return this.arguments
    }

}

assignToNamespace('Monster.Logging', LogEntry);
export {Monster, LogEntry}
