'use strict';

/**
 * @author schukai GmbH
 */

import {assignToNamespace, Monster} from '../namespace.js';

/**
 * This is the base class from which all monster classes are derived.
 *
 * You can call the method via the monster namespace `new Monster.Types.Base()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.Base()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Base} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/base.js';
 * new Base()
 * </script>
 * ```
 *
 * The class was formerly called Object.
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */
class Base extends Object {

    /**
     *
     * @returns {string}
     */
    toString() {
        return JSON.stringify(this);
    };


}

assignToNamespace('Monster.Types', Base);
export {Monster, Base}
