'use strict';

/**
 * @author schukai GmbH
 */


import {assignToNamespace, Monster} from "../namespace.js";
import {validateString} from "./validate.js";

/**
 * This function prefixes all special characters that may appear in a regex with a slash.
 * 
 * You can call the method via the monster namespace `Monster.Types.escapeString()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.escapeString()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {escapeString} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * escapeString()
 * </script>
 * ```
 *
 * @param {string} value
 * @return {string}
 * @since 1.26.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a string
 */
function escapeString(value) {
    return validateString(value)
        .replace(/[|\\{}()[\]^$+*?.]/g, '\\$&')
        .replace(/-/g, '\\x2d');
}

assignToNamespace('Monster.Types', escapeString);
export {
    Monster,
    escapeString
}
