'use strict';

import chai from "chai"
import {ATTRIBUTE_OPTIONS} from "../../../source/dom/constants.js";
import {getDocument} from "../../../source/dom/util.js";
import {chaiDom} from "../../util/chai-dom.js";
import {initJSDOM} from "../../util/jsdom.js";


let expect = chai.expect;
chai.use(chaiDom);

let html1 = `
    <div id="test1">
    </div>
`;

describe('DOM', function () {

    let CustomControl, registerCustomElement, TestComponent, document, jsdomFlag;

    describe('CustomControl()', function () {

        before(function (done) {
            initJSDOM().then(() => {

                // jsdom does not support ElementInternals
                jsdomFlag = navigator.userAgent.includes("jsdom");

                import("../../../source/dom/customelement.js").then((m) => {
                    registerCustomElement = m['registerCustomElement'];


                    import("../../../source/dom/customcontrol.js").then((m) => {

                        document = getDocument();

                        try {
                            CustomControl = m['CustomControl'];

                            TestComponent = class extends CustomControl {
                                static getTag() {
                                    return "monster-customcontrol"
                                }
                            }
                            registerCustomElement(TestComponent)


                            done()
                        } catch (e) {
                            done(e);
                        }


                    });
                });
            });
        })

        beforeEach(() => {
            let mocks = document.getElementById('mocks');
            mocks.innerHTML = html1;
        })

        afterEach(() => {
            let mocks = document.getElementById('mocks');
            mocks.innerHTML = "";
        })

        describe('create', function () {
            it('should return custom-element object', function () {
                let d = new TestComponent();
                expect(typeof d).is.equal('object');
            });
        });

        describe('connect empty element', function () {
            it('document should contain monster-customcontrol', function () {
                
                let d = document.createElement('monster-customcontrol');
                document.getElementById('test1').appendChild(d);
                expect(document.getElementsByTagName('monster-customcontrol').length).is.equal(1);
                // no data-monster-objectlink="Symbol(monsterUpdater)" because it has nothing to update
                expect(document.getElementById('test1')).contain.html('<monster-customcontrol></monster-customcontrol>');
            });
        });

        describe('Options change', function () {

            it('delegatesFocus should change from true to false', function () {
                let element = document.createElement('monster-customcontrol')

                expect(element.getOption('delegatesFocus')).to.be.true;
                element.setAttribute(ATTRIBUTE_OPTIONS, JSON.stringify({delegatesFocus: false}));
                expect(element.getOption('delegatesFocus')).to.be.false;

            })


        })

        describe('Test ElementInternals', function () {

            let form;

            beforeEach(() => {
                form = document.createElement('form');
            })

            it('formAssociated', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                expect(d.constructor.formAssociated).to.be.true;

            });
            it('form', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                if (jsdomFlag) {
                    expect(() => d.form).to.throw(Error);
                } else {
                    expect(d.form).to.be.instanceof(HTMLFormElement)
                }


            });

            it('value getter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                expect(() => d.value).to.throw(Error);

            });

            it('value setter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                expect(() => d.value = 4).to.throw(Error);

            });


            it('setFormValue', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                if (jsdomFlag) {
                    expect(() => d.setFormValue()).to.throw(Error);
                } else {

                }

            });


            it('name getter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                expect(d.name).to.be.null;

            });

            it('type getter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                expect(d.type).to.be.equal('monster-customcontrol');

            });

            it('validity getter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);
                if (jsdomFlag) {
                    expect(() => d.validity).to.throw(Error);
                } else {

                }

            });

            it('validationMessage getter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                if (jsdomFlag) {
                    expect(() => d.validity).to.throw(Error);
                } else {

                }

            });

            it('willValidate getter', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                if (jsdomFlag) {
                    expect(() => d.willValidate).to.throw(Error);
                } else {

                }

            });
            it('checkValidity()', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                if (jsdomFlag) {
                    expect(() => d.checkValidity()).to.throw(Error);
                } else {

                }

            });

            it('reportValidity()', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);

                if (jsdomFlag) {
                    expect(() => d.reportValidity()).to.throw(Error);
                } else {

                }

            });


            it('setValidity()', function () {

                let d = document.createElement('monster-customcontrol');
                form.appendChild(d);
                if (jsdomFlag) {
                    expect(() => d.setValidity()).to.throw(Error);
                } else {
                    expect(d.setValidity({'valueMissing': true}, "my message")).to.be.undefined;
                }

            });


        });
    });

});


