import {expect} from "chai"
import {Monster, assignToNamespace} from "../../source/namespace.js";

describe('Namespace', function () {

    describe('assignToNamespace', function () {


        it('assignToNamespace() without arguments throw exception', function () {
            expect(() => assignToNamespace()).to.throw(Error)
        });

        it('assignToNamespace() with wrong arguments throw exception', function () {
            expect(() => assignToNamespace({})).to.throw(Error)
        });

        it('assignToNamespace() without function arguments throw exception', function () {
            expect(() => assignToNamespace('test')).to.throw(Error)
        });
        it('assignToNamespace() with wrong arguments throw exception', function () {
            expect(() => assignToNamespace('test', {})).to.throw(Error)
        });

        it('assignToNamespace() with wrong arguments throw exception', function () {
            function testMock() {

            }

            expect(assignToNamespace('test', testMock)).to.be.an.instanceof(Object)
        });

        it('assignToNamespace() with corrupted function as arguments throw exception', function () {
            function testMock() {

            }

            // delete name property for toString detection
            delete testMock.name;

            testMock.toString = () => {
                return {}
            }

            expect(() => assignToNamespace('test', testMock)).to.throw(Error)
        });

        it('assignToNamespace() with corrupted function as arguments throw exception', function () {
            function testMock() {

            }

            // delete name property for toString detection
            delete testMock.name;

            testMock.toString = () => {
                return "unsupported"
            }

            expect(() => assignToNamespace('test', testMock)).to.throw(Error)
        });

        it('assignToNamespace() with corrupted function as arguments throw exception', function () {
            function testMock() {

            }

            // delete name property for toString detection
            delete testMock.name;

            expect(assignToNamespace('test', testMock)).to.be.an.instanceof(Object)
        });

        it('assignToNamespace() without name', function () {
            class testMockClass {

            }

            delete testMockClass.name;

            expect(assignToNamespace('test', testMockClass)).to.be.an.instanceof(Object)
        });

        it('Namespace().toString() should return string', function () {
            class testMockClass {

            }

            expect(assignToNamespace('Test', testMockClass).toString()).to.be.equal('Monster.Test');
        });
        
    });

});
