import {
    Monster,
    isPrimitive,
    isBoolean,
    isString,
    isObject,
    isArray,
    isInstance,
    isFunction,
    isIterable,
    isInteger,
    isSymbol
} from "../../../source/types/is.js";


import * as Crypto from "@peculiar/webcrypto";
if(!global['crypto']) {
    global['crypto'] = new Crypto.Crypto();
}

import {ID} from "../../../source/types/id.js"

import {expect} from "chai"

describe('Is', function () {

    describe('.isPrimitive()', function () {

        [
            ['test1', true],
            [undefined, true],
            [null, true],
            [() => {
            }, false],
            [2, true],
            [parseInt("a"), true],
            [false, true],
            [true, true],
            [4.5, true],
            [{}, false],
            [[1, 2, 3], false],
            [Symbol("foo"), true],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isPrimitive(' + typeof a + ') should return ' + b, function () {
                expect(isPrimitive(a)).is.equal(b)
            });
        });


    });
    describe('.isSymbol()', function () {

        [
            ['test1', false],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [2, false],
            [parseInt("a"), false],
            [false, false],
            [true, false],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], false],
            [Symbol("foo"), true],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isSymbol(' + typeof a + ') should return ' + b, function () {
                expect(isSymbol(a)).is.equal(b)
            });
        });


    });

    describe('.isInteger()', function () {

        [
            ['test1', false],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [2, true],
            [parseInt("a"), false],
            [false, false],
            [true, false],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], false],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isInteger(' + typeof a + ') should return ' + b, function () {
                expect(isInteger(a)).is.equal(b)
            });
        });


    });

    describe('.isIterable()', function () {

        [
            ['test1', true],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [parseInt("a"), false],
            [2, false],
            [false, false],
            [true, false],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], true],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isIterable(' + typeof a + ') should return ' + b, function () {
                expect(isIterable(a)).is.equal(b)
            });
        });


    });

    describe('.isBoolean()', function () {

        [
            ['test1', false],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [2, false],
            [false, true],
            [parseInt("a"), false],
            [true, true],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], false],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isBoolean(' + typeof a + ') should return ' + b, function () {
                expect(isBoolean(a)).is.equal(b)
            });
        });


    });

    describe('.isString()', function () {

        [
            ['test1', true],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [2, false],
            [false, false],
            [parseInt("a"), false],
            [true, false],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], false],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isString(' + typeof a + ') should return ' + b, function () {
                expect(isString(a)).is.equal(b)
            });
        });


    });

    describe('.isInstance()', function () {

        [
            [new ID(), ID,  true],
            [new ID(), ()=>{},  false],
            ['test1', undefined, false],
            [undefined, undefined, false],
            [null, undefined, false],
            [() => {
            }, undefined, false],
            [2, undefined, false],
            [false, undefined, false],
            [parseInt("a"), undefined, false],
            [true, undefined, false],
            [4.5, undefined, false],
            [{}, undefined, false],
            [[1, 2, 3], undefined, false],
            [Symbol("foo"), undefined, false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()
            let c = data.shift()

            it('is.isInstance(' + JSON.stringify(a) + ') should return ' + typeof b, function () {
                expect(isInstance(a, b)).is.equal(c)
            });
        });
    });
    
    
    describe('.isObject()', function () {

        [
            ['test1', false],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [2, false],
            [false, false],
            [parseInt("a"), false],
            [true, false],
            [4.5, false],
            [{}, true],
            [[1, 2, 3], false],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isObject(' + JSON.stringify(a) + ') should return ' + b, function () {
                expect(isObject(a)).is.equal(b)
            });
        });


    });


    describe('.isArray()', function () {

        [
            ['test1', false],
            [undefined, false],
            [null, false],
            [() => {
            }, false],
            [2, false],
            [false, false],
            [parseInt("a"), false],
            [true, false],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], true],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isArray(' + typeof a + ') should return ' + b, function () {
                expect(isArray(a)).is.equal(b)
            });
        });
    });

    describe('.isFunction()', function () {

        [
            ['test1', false],
            [undefined, false],
            [null, false],
            [() => {
            }, true],
            [2, false],
            [false, false],
            [parseInt("a"), false],
            [true, false],
            [4.5, false],
            [{}, false],
            [[1, 2, 3], false],
            [Symbol("foo"), false],
        ].forEach(function (data) {

            let a = data.shift()
            let b = data.shift()

            it('is.isFunction(' + typeof a + ') should return ' + b, function () {
                expect(isFunction(a)).is.equal(b)
            });
        });
    });

});

