'use strict';

import {extend} from "../../source/data/extend.js";
import {getGlobal} from "../../source/types/global.js";

export const isBrowser = new Function("try {return this===window;}catch(e){ return false;}");

export const isNode = new Function("try {return this===global;}catch(e){return false;}");


/**
 * this helper function creates the dom stack in the node environment
 *
 * @return {Promise<unknown>|Promise<void>}
 */
function initJSDOM(options) {
    if (typeof window === "object" && window['DOMParser']) return Promise.resolve();

    const g = getGlobal();

    options = extend({}, {
        pretendToBeVisual: true,
        contentType: "text/html",
        includeNodeLocations: true,
        storageQuota: 10000000,
        runScripts: "dangerously",
        resources: "usable"
    }, options||{})

    return import("jsdom").then(({JSDOM}) => {
        const {window} = new JSDOM(`<html>
<head>
</head>
<body>
<div id="mocks"></div>
</body>`, options);

        g['window'] = window;

        return new Promise(resolve =>
            window.addEventListener("load", () => {

                [
                    'self',
                    'HTMLCollection',
                    'NodeList',
                    'ElementInternals',
                    'HTMLDocument',
                    'HTMLFormElement',
                    'HTMLInputElement',
                    'HTMLSelectElement',
                    'HTMLTextAreaElement',
                    'document',
                    'Document',
                    'Node',
                    'ShadowRoot',
                    'Event',
                    'CustomEvent',
                    'Element',
                    'HTMLElement',
                    'HTMLDivElement',
                    'customElements',
                    'DocumentFragment',
                    'DOMParser',
                    'CSSStyleSheet',
                    'HTMLScriptElement',
                    'MutationObserver',
                    'HTMLTemplateElement',
                    'XMLSerializer',
                    'NodeFilter',
                    'navigator',
                    'InputEvent',
                    'Blob',
                    'CustomEvent'
                ].forEach(key => {
                    g[key] = window[key]
                });

                resolve();
            })
        );


    });
}

export {initJSDOM}

