const util = require('util');
const urlExist = require('url-exist');
const fs = require('fs');
const exec = util.promisify(require('child_process').exec);


async function getVersions() {
    try {
        const {stdout, stderr} = await exec('npm view @schukai/monster versions --json');
        return JSON.parse(stdout);
    } catch (err) {
        console.error(err);
    }
};

async function writeFile(filename, writedata) {

    try {
        await fs.promises.writeFile(filename, writedata, 'utf8');
    } catch (err) {
        console.log('not able to write data in the file ')
    }
}


async function existsUrl(version) {
    let url = "https://monsterjs.org/en/doc/" + version + "/";
    let r = await urlExist(url);
    return {v: version, e: r};
}


getVersions().then(versions => {

    let optionScript = `
function initmonsterversions() {    

let u = new URL(location.href).pathname.split('/');
u.pop();
const current =u.pop();
let result = u.join('/')+"/";

function compareVer(a, b) {
    function prep(t) {
        return ("" + t)
          .replace(/[^0-9\\.]+/g, function(c){return "." + ((c = c.replace(/[\\W_]+/, "")) ? c.toLowerCase().charCodeAt(0) - 65536 : "") + "."})
          .replace(/(?:\\.0+)*(\\.-[0-9]+)(\\.[0-9]+)?\\.*$/g, "$1$2")
          .split('.');
    }
    a = prep(a);
    b = prep(b);
    for (var i = 0; i < Math.max(a.length, b.length); i++)  {
        a[i] = ~~a[i];
        b[i] = ~~b[i];
        if (a[i] > b[i])
            return 1;
        else if (a[i] < b[i])
            return -1;
    }
    return 0;
}


const lastVersionContainer = document.createElement('div');
lastVersionContainer.setAttribute('style','margin-bottom:10px;');
const constainer = document.createElement('div');
constainer.setAttribute('style','display: flex;align-items: center;justify-content: flex-start;gap: 10px;align-content: center;');
constainer.appendChild(document.createTextNode('versions'));
const selectElement = document.createElement('select');
selectElement.setAttribute('onChange','location="'+result+'"+this.value');
selectElement.setAttribute('id','monster-versions');
    `;

    versions = versions.reverse();

    let promises = [];
    for (let i = 0; i < versions.length; i++) {
        let version = versions[i];

        promises.push(existsUrl(version));


    }

    Promise.all(promises).then(a => {
        let last, htmlOptions = "";

        for (let i = 0; i < a.length; i++) {
            if (a[i].e !== true) continue;
            htmlOptions += "selectElement.add(new Option('" + a[i].v + "'));\n";
            if (last === undefined) last = a[i].v;
        }


        optionScript += htmlOptions;

        optionScript += `
selectElement.value=current;
constainer.append(selectElement);
document.getElementById('sidebar-main-content').prepend(constainer);
document.getElementById('sidebar-main-content').prepend(lastVersionContainer);

    `;

        optionScript += "if(compareVer(current,'" + last + "')===-1) {;"

        optionScript += `
        let infocontainer = document.createElement('div');
        let infolink = document.createElement('a');
        let lasturl = new URL(location.href)
        lasturl.pathname=result+"` + last + `"+"/"
        infolink.setAttribute('href',lasturl);
        infolink.append(document.createTextNode('Looking for Monster ` + last + `?'));
        infocontainer.append(infolink);
        lastVersionContainer.append(infocontainer);
    `;

        optionScript += "};"
        optionScript += "};"
        optionScript += " document.addEventListener(\"DOMContentLoaded\", initmonsterversions);"


        let redirectScript = "location=location.href.replace('latest','"+last+"');";
        
        writeFile(__dirname + "/../web/js/doc/monster-versions.js", optionScript)
        writeFile(__dirname + "/../web/js/doc/monster-latest-version.js", redirectScript)
    });

});







