/**
 * Library Build-Config
 */


/**
 * @type {string}
 */
const path = require('path');


/**
 * @type {TerserPlugin}
 */
const TerserPlugin = require("terser-webpack-plugin");

/**
 *
 */
const webpack = require('webpack');

module.exports = {

    context: __dirname,

    mode: "production",
    entry: __dirname + "/../../../../packages/monster/source/monster.js",

    module: {

        rules: [
            {

                loader: 'babel-loader',
                test: /\.js$|jsx/,
                exclude: /node_modules/,
                loader: 'babel-loader',
                type: "javascript/auto",

                options: {
                    presets: [


                        [
                            "@babel/preset-env",
                            {
                                targets: {
                                    browsers: [
                                        "last 2 versions",
                                        "safari >= 7",
                                        "ie >= 11"
                                    ]
                                }
                            }
                        ]


                    ],
                    plugins: [
                        ["@babel/plugin-transform-arrow-functions"],
                        '@babel/plugin-proposal-object-rest-spread',

                        ["@babel/plugin-proposal-nullish-coalescing-operator"],
                        ["@babel/plugin-proposal-optional-chaining"],
                        [
                            "@babel/plugin-transform-regenerator",
                            {
                                "asyncGenerators": false,
                                "generators": false,
                                "async": false
                            }
                        ]

                    ]
                }
            }, {
                test: /\.css$/i,
                use: ["style-loader", "css-loader"],
            }
        ]
    },

    optimization: {

        minimize: true,
        minimizer: [
            new TerserPlugin({
                extractComments: false,
                minify: TerserPlugin.uglifyjs,
                terserOptions: {
                    keep_classnames: true,
                    keep_fnames: true,
                    ecma: 'es5',
                    mangle: false,
                    module: true,

                },
            }),
        ],

    },

    target: 'web',
    output: {
        path: __dirname + "/../../../../packages/monster/dist/",
        filename: 'monster.js',
        library: {
            name: 'window',
            type: 'umd'
        },
        environment: {
            // The environment supports arrow functions ('() => { ... }').
            arrowFunction: false,
            // The environment supports BigInt as literal (123n).
            bigIntLiteral: false,
            // The environment supports const and let for variable declarations.
            const: false,
            // The environment supports destructuring ('{ a, b } = obj').
            destructuring: false,
            // The environment supports an async import() function to import EcmaScript modules.
            dynamicImport: false,
            // The environment supports 'for of' iteration ('for (const x of array) { ... }').
            forOf: false,
            // The environment supports ECMAScript Module syntax to import ECMAScript modules (import ... from '...').
            module: false,
        },
    },


    resolve: {

        // modules: [
        //     path.resolve(__dirname, "node_modules")
        // ],

        fallback: {
            "fs": false,
            "tls": false,
            "net": false,
            "process": false,
            "child_process": false,
            "crypto": false,
            "url": false,
            "stream": false,
            "util": false,
            "string_decoder": false,
            "path": false,
            "events": false,
            "http": false,
            "https": false,
            "os": false,
            "zlib": false,
            "buffer": false,
            "assert": false,

        },


    },

    plugins: [
        new webpack.optimize.LimitChunkCountPlugin({
            maxChunks: 1
        })
    ],

}