const path = require('path');

const webpack = require('webpack');

/**
 * @type {TerserPlugin}
 */
const TerserPlugin = require("terser-webpack-plugin");

module.exports = {

    context: __dirname,

    mode: "production",
    entry: "../../../../packages/monster/test/web/import.js",

    module: {

        rules: [
            {

                loader: 'babel-loader',
                test: /\.js$|jsx/,
                exclude: /node_modules/,
                loader: 'babel-loader',
                type: "javascript/auto",

                options: {
                    presets: [


                        [
                            "@babel/preset-env",
                            {
                                corejs: {version: 3, proposals: true},
                                useBuiltIns: "usage",
                                targets: {
                                    browsers: [
                                        "last 2 versions",
                                        "safari >= 7",
                                        "ie >= 11"
                                    ]
                                }
                            }
                        ]


                    ],
                    plugins: [

                        "@babel/plugin-proposal-class-properties",
                        "@babel/plugin-transform-runtime",

                        "@babel/plugin-transform-arrow-functions",
                        '@babel/plugin-proposal-object-rest-spread',

                        "@babel/plugin-proposal-nullish-coalescing-operator",
                        "@babel/plugin-proposal-optional-chaining",
                        [
                            "@babel/plugin-transform-regenerator",
                            {
                                "asyncGenerators": false,
                                "generators": false,
                                "async": false
                            }
                        ]

                    ]
                }
            }, {
                test: /\.css$/i,
                use: ["style-loader", "css-loader"],
            }
        ]
    },

    optimization: {
        minimize: true,
        minimizer: [
            new TerserPlugin({
                extractComments: false,
                minify: TerserPlugin.uglifyjs,
                terserOptions: {
                    keep_classnames: true,
                    keep_fnames: true,
                    ecma: 'es5',
                    mangle: false,
                    module: true,

                },
            }),
        ],
    },

    target: 'web',
    output: {
        path: __dirname + "/../../../../packages/monster/test/web/",
        filename: 'tests.js',
        environment: {
            // The environment supports arrow functions ('() => { ... }').
            arrowFunction: false,
            // The environment supports BigInt as literal (123n).
            bigIntLiteral: false,
            // The environment supports const and let for variable declarations.
            const: false,
            // The environment supports destructuring ('{ a, b } = obj').
            destructuring: false,
            // The environment supports an async import() function to import EcmaScript modules.
            dynamicImport: false,
            // The environment supports 'for of' iteration ('for (const x of array) { ... }').
            forOf: false,
            // The environment supports ECMAScript Module syntax to import ECMAScript modules (import ... from '...').
            module: false,
        },
    },


    resolve: {

        modules: [
            path.resolve(__dirname, "node_modules")
        ],

        fallback: {
            "fs": false,
            "tls": false,
            "net": false,
            "process": "process/browser",
            "child_process": false,
            "crypto": require.resolve("crypto-browserify"),
            "url": require.resolve("url/"),
            "stream": require.resolve("stream-browserify"),
            "util": require.resolve("util/"),
            "string_decoder": require.resolve("string_decoder/"),
            "path": require.resolve("path-browserify"),
            "events": require.resolve("events/"),
            "http": require.resolve("stream-http"),
            "https": require.resolve("https-browserify"),
            "os": require.resolve("os-browserify/browser"),
            "zlib": require.resolve("browserify-zlib"),
            "assert": require.resolve("assert/"),

        },


    },

    plugins: [
        new webpack.ProvidePlugin({
            Buffer: ['buffer', 'Buffer'],
            process: 'process/browser',
        }),

        new webpack.optimize.LimitChunkCountPlugin({
            maxChunks: 1
        })

    ],

}