/** Monster 1.30.0, © 2021 schukai GmbH, Released under the AGPL 3.0 License. */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["window"] = factory();
	else
		root["window"] = factory();
})(self, function() {
return /******/ (function() { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ([
/* 0 */,
/* 1 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "internalSymbol": function() { return /* binding */ internalSymbol; },
/* harmony export */   "internalStateSymbol": function() { return /* binding */ internalStateSymbol; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);



/**
 * Property-Keys
 * @author schukai GmbH
 */

/**
 * @private
 * @type {symbol}
 * @memberOf Monster
 * @since 1.24.0
 */

var internalSymbol = Symbol('internalData');
/**
 * @private
 * @type {symbol}
 * @memberOf Monster
 * @since 1.25.0
 */

var internalStateSymbol = Symbol('state');


/***/ }),
/* 2 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* binding */ Monster; },
/* harmony export */   "assignToNamespace": function() { return /* binding */ assignToNamespace; }
/* harmony export */ });

/**
 * Main namespace for Monster.
 *
 * @namespace Monster
 * @author schukai GmbH
 */

/**
 * namespace class objects form the basic framework of the namespace administration.
 *
 * all functions, classes and objects of the library hang within the namespace tree.
 *
 * via `obj instanceof Monster.Namespace` it is also easy to check whether it is an object or a namespace.
 *
 * @memberOf Monster
 * @copyright schukai GmbH
 * @since 1.0.0
 */

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var Namespace = /*#__PURE__*/function () {
  /**
   *
   * @param namespace
   * @param obj
   */
  function Namespace(namespace) {
    _classCallCheck(this, Namespace);

    if (namespace === undefined || typeof namespace !== 'string') {
      throw new Error("namespace is not a string");
    }

    this.namespace = namespace;
  }
  /**
   *
   * @returns {string}
   */


  _createClass(Namespace, [{
    key: "getNamespace",
    value: function getNamespace() {
      return this.namespace;
    }
    /**
     *
     * @returns {string}
     */

  }, {
    key: "toString",
    value: function toString() {
      return this.getNamespace();
    }
  }]);

  return Namespace;
}();
/**
 * @type {Namespace}
 * @global
 */


var Monster = new Namespace("Monster");
/**
 * To expand monster, the `Monster.assignToNamespace()` method can be used.
 *
 * you must call the method in the monster namespace. this allows you to mount your own classes, objects and functions into the namespace.
 *
 * To avoid confusion and so that you do not accidentally overwrite existing functions, you should use the custom namespace `X`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * function hello() {
 *            console.log('Hello World!');
 *        }
 * Monster.assignToNamespace("Monster.X", hello)
 * Monster.X.hello(); // ↦ Hello World!
 * </script>
 *
 * ```
 *
 * @param {string} ns
 * @param {function} obj
 * @return {current}
 * @memberOf Monster
 * @throws {Error} no functions have been passed.
 * @throws {Error} the name of the class or function cannot be resolved.
 * @throws {Error} the first argument is not a function or class.
 * @throws {Error} exception
 * @since 1.0.0
 */

function assignToNamespace(ns) {
  var current = namespaceFor(ns.split("."));

  if ((arguments.length <= 1 ? 0 : arguments.length - 1) === 0) {
    throw new Error('no functions have been passed.');
  }

  for (var i = 0, l = arguments.length <= 1 ? 0 : arguments.length - 1; i < l; i++) {
    current[objectName(i + 1 < 1 || arguments.length <= i + 1 ? undefined : arguments[i + 1])] = i + 1 < 1 || arguments.length <= i + 1 ? undefined : arguments[i + 1];
  }

  return current;
}
/**
 *
 * @param {class|function} fn
 * @returns {string}
 * @private
 * @throws {Error} the name of the class or function cannot be resolved.
 * @throws {Error} the first argument is not a function or class.
 * @throws {Error} exception
 */


function objectName(fn) {
  try {
    if (typeof fn !== 'function') {
      throw new Error("the first argument is not a function or class.");
    }

    if (fn.hasOwnProperty('name')) {
      return fn.name;
    }

    if ("function" === typeof fn.toString) {
      var s = fn.toString();
      var f = s.match(/^\s*function\s+([^\s(]+)/);

      if (Array.isArray(f) && typeof f[1] === 'string') {
        return f[1];
      }

      var c = s.match(/^\s*class\s+([^\s(]+)/);

      if (Array.isArray(c) && typeof c[1] === 'string') {
        return c[1];
      }
    }
  } catch (e) {
    throw new Error("exception " + e);
  }

  throw new Error("the name of the class or function cannot be resolved.");
}
/**
 *
 * @param parts
 * @returns {Namespace}
 * @private
 */


function namespaceFor(parts) {
  var space = Monster,
      ns = 'Monster';

  for (var i = 0; i < parts.length; i++) {
    if ("Monster" === parts[i]) {
      continue;
    }

    ns += '.' + parts[i];

    if (!space.hasOwnProperty(parts[i])) {
      space[parts[i]] = new Namespace(ns);
    }

    space = space[parts[i]];
  }

  return space;
}

assignToNamespace('Monster', assignToNamespace, Namespace);


/***/ }),
/* 3 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "AbstractConstraint": function() { return /* binding */ AbstractConstraint; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 * 
 * The abstract constraint defines the api for all constraints. mainly the method isValid() is defined.
 *
 * derived classes must implement the method isValid().
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary The abstract constraint
 */

var AbstractConstraint = /*#__PURE__*/function (_Base) {
  _inherits(AbstractConstraint, _Base);

  var _super = _createSuper(AbstractConstraint);

  /**
   *
   */
  function AbstractConstraint() {
    _classCallCheck(this, AbstractConstraint);

    return _super.call(this);
  }
  /**
   * this method must return a promise containing the result of the check.
   *
   * @param {*} value
   * @returns {Promise}
   */


  _createClass(AbstractConstraint, [{
    key: "isValid",
    value: function isValid(value) {
      return Promise.reject(value);
    }
  }]);

  return AbstractConstraint;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', AbstractConstraint);


/***/ }),
/* 4 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Base": function() { return /* binding */ Base; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _wrapNativeSuper(Class) { var _cache = typeof Map === "function" ? new Map() : undefined; _wrapNativeSuper = function _wrapNativeSuper(Class) { if (Class === null || !_isNativeFunction(Class)) return Class; if (typeof Class !== "function") { throw new TypeError("Super expression must either be null or a function"); } if (typeof _cache !== "undefined") { if (_cache.has(Class)) return _cache.get(Class); _cache.set(Class, Wrapper); } function Wrapper() { return _construct(Class, arguments, _getPrototypeOf(this).constructor); } Wrapper.prototype = Object.create(Class.prototype, { constructor: { value: Wrapper, enumerable: false, writable: true, configurable: true } }); return _setPrototypeOf(Wrapper, Class); }; return _wrapNativeSuper(Class); }

function _construct(Parent, args, Class) { if (_isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _isNativeFunction(fn) { return Function.toString.call(fn).indexOf("[native code]") !== -1; }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }


/**
 * This is the base class from which all monster classes are derived.
 *
 * You can call the method via the monster namespace `new Monster.Types.Base()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.Base()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Base} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/base.js';
 * new Base()
 * </script>
 * ```
 *
 * The class was formerly called Object.
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var Base = /*#__PURE__*/function (_Object) {
  _inherits(Base, _Object);

  var _super = _createSuper(Base);

  function Base() {
    _classCallCheck(this, Base);

    return _super.apply(this, arguments);
  }

  _createClass(Base, [{
    key: "toString",
    value:
    /**
     *
     * @returns {string}
     */
    function toString() {
      return JSON.stringify(this);
    }
  }]);

  return Base;
}( /*#__PURE__*/_wrapNativeSuper(Object));

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', Base);


/***/ }),
/* 5 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "AbstractOperator": function() { return /* binding */ AbstractOperator; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _abstract_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(3);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * Operators allow you to link constraints together. for example, you can check whether a value is an object or an array. each operator has two operands that are linked together.
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary The abstract operator constraint
 */

var AbstractOperator = /*#__PURE__*/function (_AbstractConstraint) {
  _inherits(AbstractOperator, _AbstractConstraint);

  var _super = _createSuper(AbstractOperator);

  /**
   *
   * @param {AbstractConstraint} operantA
   * @param {AbstractConstraint} operantB
   * @throws {TypeError} "parameters must be from type AbstractConstraint"
   */
  function AbstractOperator(operantA, operantB) {
    var _this;

    _classCallCheck(this, AbstractOperator);

    _this = _super.call(this);

    if (!(operantA instanceof _abstract_js__WEBPACK_IMPORTED_MODULE_1__.AbstractConstraint) || !(operantB instanceof _abstract_js__WEBPACK_IMPORTED_MODULE_1__.AbstractConstraint)) {
      throw new TypeError("parameters must be from type AbstractConstraint");
    }

    _this.operantA = operantA;
    _this.operantB = operantB;
    return _this;
  }

  return _createClass(AbstractOperator);
}(_abstract_js__WEBPACK_IMPORTED_MODULE_1__.AbstractConstraint);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', AbstractOperator);


/***/ }),
/* 6 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "AndOperator": function() { return /* binding */ AndOperator; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _abstractoperator_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(5);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * The AndOperator is used to link several contraints. The constraint is fulfilled if all constraints of the operators are fulfilled.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Constraint.AndOperator();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {AndOperator} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/andoperator.js';
 * new AndOperator();
 * </script>
 * ```
 *
 * @example
 *
 * import {Valid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/valid.js';
 * import {Invalid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/invalid.js';
 * import {AndOperator} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/andoperator.js';
 *
 * new AndOperator(
 * new Valid(), new Valid()).isValid()
 * .then(()=>console.log(true))
 * .catch(()=>console.log(false));
 * // ↦ true
 *
 * new AndOperator(
 * new Invalid(), new Valid()).isValid()
 * .then(()=>console.log(true))
 * .catch(()=>console.log(false));
 * // ↦ false
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary A and operator constraint
 */

var AndOperator = /*#__PURE__*/function (_AbstractOperator) {
  _inherits(AndOperator, _AbstractOperator);

  var _super = _createSuper(AndOperator);

  function AndOperator() {
    _classCallCheck(this, AndOperator);

    return _super.apply(this, arguments);
  }

  _createClass(AndOperator, [{
    key: "isValid",
    value:
    /**
     * this method return a promise containing the result of the check.
     *
     * @param {*} value
     * @returns {Promise}
     */
    function isValid(value) {
      return Promise.all([this.operantA.isValid(value), this.operantB.isValid(value)]);
    }
  }]);

  return AndOperator;
}(_abstractoperator_js__WEBPACK_IMPORTED_MODULE_1__.AbstractOperator);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', AndOperator);


/***/ }),
/* 7 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Invalid": function() { return /* binding */ Invalid; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _abstract_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(3);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * The invalid constraint allows an always invalid query to be performed. this constraint is mainly intended for testing.
 *
 * You can call the method via the monster namespace `new Monster.Constraint.Invalid()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Constraint.Invalid();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Invalid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/invalid.js';
 * new Invalid();
 * </script>
 * ```
 *
 * @example
 *
 * import {Invalid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/invalid.js';
 *
 * new Invalid().isValid()
 * .then(()=>console.log(true))
 * .catch(()=>console.log(false));
 * // ↦ false
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary A constraint that always invalid
 */

var Invalid = /*#__PURE__*/function (_AbstractConstraint) {
  _inherits(Invalid, _AbstractConstraint);

  var _super = _createSuper(Invalid);

  function Invalid() {
    _classCallCheck(this, Invalid);

    return _super.apply(this, arguments);
  }

  _createClass(Invalid, [{
    key: "isValid",
    value:
    /**
     * this method return a rejected promise
     *
     * @param {*} value
     * @returns {Promise}
     */
    function isValid(value) {
      return Promise.reject(value);
    }
  }]);

  return Invalid;
}(_abstract_js__WEBPACK_IMPORTED_MODULE_1__.AbstractConstraint);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', Invalid);


/***/ }),
/* 8 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "IsArray": function() { return /* binding */ IsArray; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _abstract_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(3);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }




/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 * 
 * The uniform API of the constraints allows chains to be formed.
 * 
 * You can call the method via the monster namespace `new Monster.Constraint.IsObject()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Constraint.IsArray()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {IsArray} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/isarray.js';
 * console.log(new IsArray())
 * </script>
 * ```
 *
 * @example
 *
 * import {IsArray} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/isarray.js';
 *
 * new IsArray()
 * .isValid([])
 * .then(()=>console.log(true));
 * // ↦ true
 *
 * new IsArray()
 * .isValid(99)
 * .catch(e=>console.log(e));
 * // ↦ 99
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary A constraint to check if a value is an array
 */

var IsArray = /*#__PURE__*/function (_AbstractConstraint) {
  _inherits(IsArray, _AbstractConstraint);

  var _super = _createSuper(IsArray);

  function IsArray() {
    _classCallCheck(this, IsArray);

    return _super.apply(this, arguments);
  }

  _createClass(IsArray, [{
    key: "isValid",
    value:
    /**
     * this method return a promise containing the result of the check.
     *
     * @param {*} value
     * @returns {Promise}
     */
    function isValid(value) {
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(value)) {
        return Promise.resolve(value);
      }

      return Promise.reject(value);
    }
  }]);

  return IsArray;
}(_abstract_js__WEBPACK_IMPORTED_MODULE_2__.AbstractConstraint);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', IsArray);


/***/ }),
/* 9 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "isPrimitive": function() { return /* binding */ isPrimitive; },
/* harmony export */   "isBoolean": function() { return /* binding */ isBoolean; },
/* harmony export */   "isString": function() { return /* binding */ isString; },
/* harmony export */   "isObject": function() { return /* binding */ isObject; },
/* harmony export */   "isInstance": function() { return /* binding */ isInstance; },
/* harmony export */   "isArray": function() { return /* binding */ isArray; },
/* harmony export */   "isFunction": function() { return /* binding */ isFunction; },
/* harmony export */   "isIterable": function() { return /* binding */ isIterable; },
/* harmony export */   "isInteger": function() { return /* binding */ isInteger; },
/* harmony export */   "isSymbol": function() { return /* binding */ isSymbol; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }


/**
 * With this function you can check if a value is iterable.
 * 
 * This method is used in the library to have consistent names.
 *
 * You can call the method via the monster namespace `Monster.Types.isPrimitive()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isIterable(null) // ↦ false
 * Monster.Types.isIterable('hello') // ↦ true
 * Monster.Types.isIterable([]) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isIterable} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isIterable(null)  // ↦ false
 * isIterable('hello')  // ↦ true
 * isIterable([])  // ↦ true
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.2.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

function isIterable(value) {
  if (value === undefined) return false;
  if (value === null) return false;
  return typeof (value === null || value === void 0 ? void 0 : value[Symbol.iterator]) === 'function';
}
/**
 * Checks whether the value passed is a primitive (string, number, boolean, NaN, undefined, null or symbol)
 * 
 * This method is used in the library to have consistent names.
 *
 * You can call the method via the monster namespace `Monster.Types.isPrimitive()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isPrimitive('2') // ↦ false
 * Monster.Types.isPrimitive([]) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isPrimitive} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isPrimitive('2'))  // ↦ true
 * isPrimitive([]))  // ↦ false
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isPrimitive(value) {
  var type;

  if (value === undefined || value === null) {
    return true;
  }

  type = _typeof(value);

  if (type === 'string' || type === 'number' || type === 'boolean' || type === 'symbol') {
    return true;
  }

  return false;
}
/**
 * Checks whether the value passed is a symbol
 * 
 * This method is used in the library to have consistent names.
 *
 * You can call the method via the monster namespace `Monster.Types.isSymbol()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isSymbol('2') // ↦ false
 * Monster.Types.isSymbol(Symbol('test') // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isSymbol} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isSymbol(Symbol('a')))  // ↦ true
 * isSymbol([])  // ↦ false
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isSymbol(value) {
  return 'symbol' === _typeof(value) ? true : false;
}
/**
 * Checks whether the value passed is a boolean.
 * 
 * This method is used in the library to have consistent names.
 *
 * You can call the method via the monster namespace `Monster.Types.isBoolean()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isBoolean('2') // ↦ false
 * Monster.Types.isBoolean([]) // ↦ false
 * Monster.Types.isBoolean(true) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isBoolean} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isBoolean('2'))  // ↦ false
 * isBoolean([]))  // ↦ false
 * isBoolean(2>4))  // ↦ true
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isBoolean(value) {
  if (value === true || value === false) {
    return true;
  }

  return false;
}
/**
 * Checks whether the value passed is a string
 * 
 * This method is used in the library to have consistent names.
 *
 * You can call the method via the monster namespace `Monster.Types.isString()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isString('2') // ↦ true
 * Monster.Types.isString([]) // ↦ false
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isString} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isString('2'))  // ↦ true
 * isString([]))  // ↦ false
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isString(value) {
  if (value === undefined || typeof value !== 'string') {
    return false;
  }

  return true;
}
/**
 * Checks whether the value passed is a object
 * 
 * This method is used in the library to have consistent names.
 *
 * You can call the method via the monster namespace `Monster.Types.isObject()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isObject('2') // ↦ false
 * Monster.Types.isObject([]) // ↦ false
 * Monster.Types.isObject({}) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isObject} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isObject('2'))  // ↦ false
 * isObject([]))  // ↦ false
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isObject(value) {
  if (isArray(value)) return false;
  if (isPrimitive(value)) return false;

  if (_typeof(value) === 'object') {
    return true;
  }

  return false;
}
/**
 * Checks whether the value passed is a object and instance of instance.
 * 
 * This method is used in the library to have consistent names.
 *
 * you can call the method via the monster namespace `Monster.Types.isInstance()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isInstance('2') // ↦ false
 * Monster.Types.isInstance([]) // ↦ false
 * Monster.Types.isInstance({}) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isInstance} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isInstance('2'))  // ↦ false
 * isInstance([]))  // ↦ false
 * </script>
 * ```
 *
 * @param {*} value
 * @param {*} instance
 * @returns {boolean}
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isInstance(value, instance) {
  if (!isObject(value)) return false;
  if (!isFunction(instance)) return false;
  if (!instance.hasOwnProperty('prototype')) return false;
  return value instanceof instance ? true : false;
}
/**
 * Checks whether the value passed is a array
 * 
 * This method is used in the library to have consistent names. 
 *
 * you can call the method via the monster namespace `Monster.Types.isArray()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isArray('2') // ↦ false
 * Monster.Types.isArray([]) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isArray} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isArray('2'))  // ↦ false
 * isArray([]))  // ↦ true
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @see https://developer.mozilla.org/de/docs/Web/JavaScript/Reference/Global_Objects/Array/isArray
 */


function isArray(value) {
  return Array.isArray(value);
}
/**
 * Checks whether the value passed is a function
 * 
 * This method is used in the library to have consistent names. 
 *
 * you can call the method via the monster namespace `Monster.Types.isFunction()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isFunction(()=>{}) // ↦ true
 * Monster.Types.isFunction('2') // ↦ false
 * Monster.Types.isFunction([]) // ↦ false
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isFunction} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isFunction(()=>{}) // ↦ true
 * isFunction('2'))  // ↦ false
 * isFunction([]))  // ↦ false
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isFunction(value) {
  if (isArray(value)) return false;
  if (isPrimitive(value)) return false;

  if (typeof value === 'function') {
    return true;
  }

  return false;
}
/**
 * Checks whether the value passed is an integer.
 * 
 * This method is used in the library to have consistent names. 
 *
 * You can call the method via the monster namespace `Monster.Types.isFunction()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.isInteger(()=>{}) // ↦ true
 * Monster.Types.isInteger('2') // ↦ false
 * Monster.Types.isInteger(2) // ↦ true
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {isInteger} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 * isInteger(()=>{}) // ↦ true
 * isInteger('2'))  // ↦ false
 * isInteger(2))  // ↦ true
 * </script>
 * ```
 *
 * @param {*} value
 * @returns {boolean}
 * @since 1.4.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */


function isInteger(value) {
  return Number.isInteger(value);
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', isPrimitive, isBoolean, isString, isObject, isArray, isFunction, isIterable, isInteger, isSymbol);


/***/ }),
/* 10 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "IsObject": function() { return /* binding */ IsObject; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _abstract_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(3);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }




/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * You can call the method via the monster namespace `new Monster.Constraint.IsObject()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Constraint.IsObject())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {IsObject} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/isobject.js';
 * console.log(new IsObject())
 * </script>
 * ```
 *
 * @example
 *
 * import {IsObject} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/isobject.js';
 *
 * new IsObject()
 * .isValid({})
 * .then(()=>console.log(true));
 * // ↦ true
 *
 *
 * new IsObject()
 * .isValid(99)
 * .catch(e=>console.log(e));
 * // ↦ 99
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary A constraint to check if a value is an object
 */

var IsObject = /*#__PURE__*/function (_AbstractConstraint) {
  _inherits(IsObject, _AbstractConstraint);

  var _super = _createSuper(IsObject);

  function IsObject() {
    _classCallCheck(this, IsObject);

    return _super.apply(this, arguments);
  }

  _createClass(IsObject, [{
    key: "isValid",
    value:
    /**
     * this method return a promise containing the result of the check.
     *
     * @param {*} value
     * @returns {Promise}
     */
    function isValid(value) {
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(value)) {
        return Promise.resolve(value);
      }

      return Promise.reject(value);
    }
  }]);

  return IsObject;
}(_abstract_js__WEBPACK_IMPORTED_MODULE_2__.AbstractConstraint);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', IsObject);


/***/ }),
/* 11 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "OrOperator": function() { return /* binding */ OrOperator; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _abstractoperator_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(5);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * The OrOperator is used to link several constraints. The constraint is fulfilled if one of the constraints is fulfilled.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Constraint.OrOperator();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {OrOperator} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraint/oroperator.js';
 * new OrOperator();
 * </script>
 * ```
 *
 * @example
 *
 * import {Valid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/valid.js';
 * import {Invalid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/invalid.js';
 * import {OrOperator} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/oroperator.js';
 *
 * new OrOperator(
 * new Valid(), new Invalid()).isValid()
 * .then(()=>console.log(true))
 * .catch(()=>console.log(false));
 * // ↦ true
 *
 * new OrOperator(
 * new Invalid(), new Invalid()).isValid()
 * .then(()=>console.log(true))
 * .catch(()=>console.log(false));
 * // ↦ false
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary A or operator 
 */

var OrOperator = /*#__PURE__*/function (_AbstractOperator) {
  _inherits(OrOperator, _AbstractOperator);

  var _super = _createSuper(OrOperator);

  function OrOperator() {
    _classCallCheck(this, OrOperator);

    return _super.apply(this, arguments);
  }

  _createClass(OrOperator, [{
    key: "isValid",
    value:
    /**
     * this method return a promise containing the result of the check.
     *
     * @param {*} value
     * @returns {Promise}
     */
    function isValid(value) {
      var self = this;
      return new Promise(function (resolve, reject) {
        var a, b;
        self.operantA.isValid(value).then(function () {
          resolve();
        }).catch(function () {
          a = false;
          /** b has already been evaluated and was not true */

          if (b === false) {
            reject();
          }
        });
        self.operantB.isValid(value).then(function () {
          resolve();
        }).catch(function () {
          b = false;
          /** b has already been evaluated and was not true */

          if (a === false) {
            reject();
          }
        });
      });
    }
  }]);

  return OrOperator;
}(_abstractoperator_js__WEBPACK_IMPORTED_MODULE_1__.AbstractOperator);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', OrOperator);


/***/ }),
/* 12 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Valid": function() { return /* binding */ Valid; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _abstract_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(3);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * The valid constraint allows an always valid query to be performed. this constraint is mainly intended for testing.
 *
 * You can call the method via the monster namespace `new Monster.Constraint.Valid()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Constraint.Valid();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Valid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/valid.js';
 * new Valid();
 * </script>
 * ```
 *
 * @example
 *
 * import {Valid} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/constraints/valid.js';
 *
 * new Valid().isValid()
 * .then(()=>console.log(true))
 * .catch(()=>console.log(false));
 * // ↦ true
 *
 * @since 1.3.0
 * @copyright schukai GmbH
 * @memberOf Monster.Constraints
 * @summary A constraint that always valid
 */

var Valid = /*#__PURE__*/function (_AbstractConstraint) {
  _inherits(Valid, _AbstractConstraint);

  var _super = _createSuper(Valid);

  function Valid() {
    _classCallCheck(this, Valid);

    return _super.apply(this, arguments);
  }

  _createClass(Valid, [{
    key: "isValid",
    value:
    /**
     * this method return a promise containing the result of the check.
     *
     * @param {*} value
     * @returns {Promise}
     */
    function isValid(value) {
      return Promise.resolve(value);
    }
  }]);

  return Valid;
}(_abstract_js__WEBPACK_IMPORTED_MODULE_1__.AbstractConstraint);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Constraints', Valid);


/***/ }),
/* 13 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "PARENT": function() { return /* binding */ PARENT; },
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "buildMap": function() { return /* binding */ buildMap; },
/* harmony export */   "assembleParts": function() { return /* binding */ assembleParts; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);
/* harmony import */ var _util_clone_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(15);
/* harmony import */ var _pathfinder_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(18);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _wrapRegExp() { _wrapRegExp = function _wrapRegExp(re, groups) { return new BabelRegExp(re, undefined, groups); }; var _super = RegExp.prototype; var _groups = new WeakMap(); function BabelRegExp(re, flags, groups) { var _this = new RegExp(re, flags); _groups.set(_this, groups || _groups.get(re)); return _setPrototypeOf(_this, BabelRegExp.prototype); } _inherits(BabelRegExp, RegExp); BabelRegExp.prototype.exec = function (str) { var result = _super.exec.call(this, str); if (result) result.groups = buildGroups(result, this); return result; }; BabelRegExp.prototype[Symbol.replace] = function (str, substitution) { if (typeof substitution === "string") { var groups = _groups.get(this); return _super[Symbol.replace].call(this, str, substitution.replace(/\$<([^>]+)>/g, function (_, name) { return "$" + groups[name]; })); } else if (typeof substitution === "function") { var _this = this; return _super[Symbol.replace].call(this, str, function () { var args = arguments; if (_typeof(args[args.length - 1]) !== "object") { args = [].slice.call(args); args.push(buildGroups(args, _this)); } return substitution.apply(this, args); }); } else { return _super[Symbol.replace].call(this, str, substitution); } }; function buildGroups(result, re) { var g = _groups.get(re); return Object.keys(g).reduce(function (groups, name) { groups[name] = result[g[name]]; return groups; }, Object.create(null)); } return _wrapRegExp.apply(this, arguments); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }






/**
 * @type {string} parent symbol
 */

var PARENT = '^';
/**
 * With the help of the function `buildMap()`, maps can be easily created from data objects.
 *
 * Either a simple definition `a.b.c` or a template `${a.b.c}` can be specified as the path.
 * Key and value can be either a definition or a template. The key does not have to be defined.
 *
 * You can call the method via the monster namespace `Monster.Data.buildMap()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Data.buildMap())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {buildMap} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/buildmap.js';
 * console.log(buildMap())
 * </script>
 * ```
 *
 * The templates determine the appearance of the keys and the value of the map. Either a single value `id` can be taken or a composite key `${id} ${name}` can be used.
 *
 * If you want to access values of the parent data set, you have to use the `^` character `${id} ${^.name}`.
 *
 * @example
 *
 * import {buildMap} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/buildmap.js';
 * // a typical data structure as reported by an api
 *
 * let map;
 * let obj = {
 *     "data": [
 *         {
 *             "id": 10,
 *             "name": "Cassandra",
 *             "address": {
 *                 "street": "493-4105 Vulputate Street",
 *                 "city": "Saumur",
 *                 "zip": "52628"
 *             }
 *         },
 *         {
 *             "id": 20,
 *             "name": "Holly",
 *             "address": {
 *                 "street": "1762 Eget Rd.",
 *                 "city": "Schwalbach",
 *                 "zip": "952340"
 *             }
 *         },
 *         {
 *             "id": 30,
 *             "name": "Guy",
 *             "address": {
 *                 "street": "957-388 Sollicitudin Avenue",
 *                 "city": "Panchià",
 *                 "zip": "420729"
 *             }
 *         }
 *     ]
 * };
 *
 * // The function is passed this data structure and with the help of the selector `'data.*'` the data to be considered are selected.
 * // The key is given by a simple definition `'id'` and the value is given by a template `'${name} (${address.zip} ${address.city})'`.
 * map = buildMap(obj, 'data.*', '${name} (${address.zip} ${address.city})', 'id');
 * console.log(map);
 *
 * // ↦ Map(3) {
 * //  '10' => 'Cassandra (52628 Saumur)',
 * //  '20' => 'Holly (952340 Schwalbach)',
 * //  '30' => 'Guy (420729 Panchià)'
 * // }
 *
 * // If no key is specified, the key from the selection, here the array index, is taken.
 * map = buildMap(obj, 'data.*', '${name} (${address.zip} ${address.city})');
 * console.log(map);
 *
 * // ↦ Map(3) {
 * //  '0' => 'Cassandra (52628 Saumur)',
 * //  '1' => 'Holly (952340 Schwalbach)',
 * //  '2' => 'Guy (420729 Panchià)'
 * // }
 *
 * // a filter (function(value, key) {}) can be specified to accept only defined entries.
 * map = buildMap(obj, 'data.*', '${name} (${address.zip} ${address.city})', 'id', function (value, key) {
 *                return (value['id'] >= 20) ? true : false
 *            });
 * console.log(map);
 *
 * // ↦ Map(2) {
 * //  20 => 'Holly (952340 Schwalbach)',
 * //  30 => 'Guy (420729 Panchià)'
 * // }
 *
 * @param {*} subject
 * @param {string|Monster.Data~exampleSelectorCallback} selector
 * @param {string} [valueTemplate]
 * @param {string} [keyTemplate]
 * @param {Monster.Data~exampleFilterCallback} [filter]
 * @return {*}
 * @memberOf Monster.Data
 * @throws {TypeError} value is neither a string nor a function
 * @throws {TypeError} the selector callback must return a map
 */

function buildMap(subject, selector, valueTemplate, keyTemplate, filter) {
  return assembleParts(subject, selector, filter, function (v, k, m) {
    k = build(v, keyTemplate, k);
    v = build(v, valueTemplate);
    this.set(k, v);
  });
}
/**
 * @private
 * @param {*} subject
 * @param {string|Monster.Data~exampleSelectorCallback} selector
 * @param {Monster.Data~exampleFilterCallback} [filter]
 * @param {function} callback
 * @return {Map}
 * @throws {TypeError} selector is neither a string nor a function
 */


function assembleParts(subject, selector, filter, callback) {
  var result = new Map();
  var map;

  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isFunction)(selector)) {
    map = selector(subject);

    if (!(map instanceof Map)) {
      throw new TypeError('the selector callback must return a map');
    }
  } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isString)(selector)) {
    map = new Map();
    buildFlatMap.call(map, subject, selector);
  } else {
    throw new TypeError('selector is neither a string nor a function');
  }

  if (!(map instanceof Map)) {
    return result;
  }

  map.forEach(function (v, k, m) {
    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isFunction)(filter)) {
      if (filter.call(m, v, k) !== true) return;
    }

    callback.call(result, v, k, m);
  });
  return result;
}
/**
 * @private
 * @param subject
 * @param selector
 * @param key
 * @param parentMap
 * @return {*}
 */


function buildFlatMap(subject, selector, key, parentMap) {
  var result = this;
  var currentMap = new Map();
  var resultLength = result.size;
  if (key === undefined) key = [];
  var parts = selector.split(_pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.DELIMITER);
  var current = "",
      currentPath = [];

  do {
    current = parts.shift();
    currentPath.push(current);

    if (current === _pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.WILDCARD) {
      var finder = new _pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.Pathfinder(subject);
      var map = void 0;

      try {
        map = finder.getVia(currentPath.join(_pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.DELIMITER));
      } catch (e) {
        var a = e;
        map = new Map();
      }

      var _iterator = _createForOfIteratorHelper(map),
          _step;

      try {
        var _loop = function _loop() {
          var _step$value = _slicedToArray(_step.value, 2),
              k = _step$value[0],
              o = _step$value[1];

          var copyKey = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_3__.clone)(key);
          currentPath.map(function (a) {
            copyKey.push(a === _pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.WILDCARD ? k : a);
          });
          var kk = copyKey.join(_pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.DELIMITER);
          var sub = buildFlatMap.call(result, o, parts.join(_pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.DELIMITER), copyKey, o);

          if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(sub) && parentMap !== undefined) {
            sub[PARENT] = parentMap;
          }

          currentMap.set(kk, sub);
        };

        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          _loop();
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
  } while (parts.length > 0); // no set in child run


  if (resultLength === result.size) {
    var _iterator2 = _createForOfIteratorHelper(currentMap),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var _step2$value = _slicedToArray(_step2.value, 2),
            k = _step2$value[0],
            o = _step2$value[1];

        result.set(k, o);
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
  }

  return subject;
}
/**
 * With the help of this filter callback, values can be filtered out. Only if the filter function returns true, the value is taken for the map.
 *
 * @callback Monster.Data~exampleFilterCallback
 * @param {*} value Value
 * @param {string} key  Key
 * @memberOf Monster.Data
 * @see {@link Monster.Data.buildMap}
 */

/**
 * Alternatively to a string selector a callback can be specified. this must return a map.
 *
 * @example
 * import {buildMap} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/buildmap.js';
 *
 * let obj = {
 *                "data": [
 *                    {
 *                        "id": 10,
 *                        "name": "Cassandra",
 *                        "enrichment": {
 *                            variants: [
 *                                {
 *                                    sku: 1, label: "XXS", price: [
 *                                        {vk: '12.12 €'},
 *                                        {vk: '12.12 €'}
 *                                    ]
 *                                },
 *                                {
 *                                    sku: 2, label: "XS", price: [
 *                                        {vk: '22.12 €'},
 *                                        {vk: '22.12 €'}
 *                                    ]
 *                                },
 *                                {
 *                                    sku: 3, label: "S", price: [
 *                                        {vk: '32.12 €'},
 *                                        {vk: '32.12 €'}
 *                                    ]
 *                                },
 *                                {
 *                                    sku: 4, label: "L", price: [
 *                                        {vk: '42.12 €'},
 *                                        {vk: '42.12 €'}
 *                                    ]
 *                                }
 *                            ]
 *
 *                        }
 *                    },
 *                    {
 *                        "id": 20,
 *                        "name": "Yessey!",
 *                        "enrichment": {
 *                            variants: [
 *                                {
 *                                    sku: 1, label: "XXS", price: [
 *                                        {vk: '12.12 €'},
 *                                        {vk: '12.12 €'}
 *                                    ]
 *                                },
 *                                {
 *                                    sku: 2, label: "XS", price: [
 *                                        {vk: '22.12 €'},
 *                                        {vk: '22.12 €'}
 *                                    ]
 *                                },
 *                                {
 *                                    sku: 3, label: "S", price: [
 *                                        {vk: '32.12 €'},
 *                                        {vk: '32.12 €'}
 *                                    ]
 *                                },
 *                                {
 *                                    sku: 4, label: "L", price: [
 *                                        {vk: '42.12 €'},
 *                                        {vk: '42.12 €'}
 *                                    ]
 *                                }
 *                            ]
 *
 *                        }
 *                    }
 *                ]
 *            };
 *
 * let callback = function (subject) {
 *                let m = new Map;
 *
 *                for (const [i, b] of Object.entries(subject.data)) {
 *
 *                    let key1 = i;
 *
 *                    for (const [j, c] of Object.entries(b.enrichment.variants)) {
 *                        let key2 = j;
 *
 *                        for (const [k, d] of Object.entries(c.price)) {
 *
 *                            let key3 = k;
 *
 *                            d.name = b.name;
 *                            d.label = c.label;
 *                            d.id = [key1, key2, key3].join('.');
 *
 *                            m.set(d.id, d);
 *                        }
 *
 *                    }
 *                }
 *                return m;
 *            }
 *
 * let map = buildMap(obj, callback, '${name} ${vk}', '${id}')
 *
 * // ↦ Map(3) {
 * //  "0.0.0":"Cassandra 12.12 €",
 * //  "0.0.1":"Cassandra 12.12 €",
 * //  "0.1.0":"Cassandra 22.12 €",
 * //  "0.1.1":"Cassandra 22.12 €",
 * //  "0.2.0":"Cassandra 32.12 €",
 * //  "0.2.1":"Cassandra 32.12 €",
 * //  "0.3.0":"Cassandra 42.12 €",
 * //  "0.3.1":"Cassandra 42.12 €",
 * //  "1.0.0":"Yessey! 12.12 €",
 * //  "1.0.1":"Yessey! 12.12 €",
 * //  "1.1.0":"Yessey! 22.12 €",
 * //  "1.1.1":"Yessey! 22.12 €",
 * //  "1.2.0":"Yessey! 32.12 €",
 * //  "1.2.1":"Yessey! 32.12 €",
 * //  "1.3.0":"Yessey! 42.12 €",
 * //  "1.3.1":"Yessey! 42.12 €"
 * // }
 *
 * @callback Monster.Data~exampleSelectorCallback
 * @param {*} subject subject
 * @return Map
 * @since 1.17.0
 * @memberOf Monster.Data
 * @see {@link Monster.Data.buildMap}
 */

/**
 * @private
 * @param {*} subject
 * @param {string|undefined} definition
 * @param {*} defaultValue
 * @return {*}
 */


function build(subject, definition, defaultValue) {
  if (definition === undefined) return defaultValue ? defaultValue : subject;
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(definition);

  var regexp = /*#__PURE__*/_wrapRegExp(/(\$\{([a-z\^A-Z.\-_0-9]*)\})/gm, {
    placeholder: 1,
    path: 2
  });

  var array = _toConsumableArray(definition.matchAll(regexp));

  var finder = new _pathfinder_js__WEBPACK_IMPORTED_MODULE_4__.Pathfinder(subject);

  if (array.length === 0) {
    return finder.getVia(definition);
  }

  array.forEach(function (a) {
    var groups = a === null || a === void 0 ? void 0 : a['groups'];
    var placeholder = groups === null || groups === void 0 ? void 0 : groups['placeholder'];
    if (placeholder === undefined) return;
    var path = groups === null || groups === void 0 ? void 0 : groups['path'];
    var v = finder.getVia(path);
    if (v === undefined) v = defaultValue;
    definition = definition.replaceAll(placeholder, v);
  });
  return definition;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Data', buildMap);


/***/ }),
/* 14 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "validatePrimitive": function() { return /* binding */ validatePrimitive; },
/* harmony export */   "validateBoolean": function() { return /* binding */ validateBoolean; },
/* harmony export */   "validateString": function() { return /* binding */ validateString; },
/* harmony export */   "validateObject": function() { return /* binding */ validateObject; },
/* harmony export */   "validateInstance": function() { return /* binding */ validateInstance; },
/* harmony export */   "validateArray": function() { return /* binding */ validateArray; },
/* harmony export */   "validateFunction": function() { return /* binding */ validateFunction; },
/* harmony export */   "validateIterable": function() { return /* binding */ validateIterable; },
/* harmony export */   "validateInteger": function() { return /* binding */ validateInteger; },
/* harmony export */   "validateSymbol": function() { return /* binding */ validateSymbol; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);

/**
 * @author schukai GmbH
 */



/**
 * This method checks if the type matches the primitive type. this function is identical to isPrimitive() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validatePrimitive()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateIterable('2')) // ↦ TypeError
 * console.log(Monster.Types.validateIterable([])) // ↦ value
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateIterable} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateIterable('2'))  // ↦ TypeError
 * console.log(validateIterable([]))  // ↦ value
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.2.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a primitive
 * @see {@link isPrimitive}
 * @see {@link Monster.Types.isPrimitive}
 * @see {@link Monster.Types#isPrimitive}
 */

function validateIterable(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isIterable)(value)) {
    throw new TypeError('value is not iterable');
  }

  return value;
}
/**
 * This method checks if the type matches the primitive type. this function is identical to isPrimitive() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validatePrimitive()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validatePrimitive('2')) // ↦ value
 * console.log(Monster.Types.validatePrimitive([])) // ↦ TypeError
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validatePrimitive} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validatePrimitive('2'))  // ↦ value
 * console.log(validatePrimitive([]))  // ↦ TypeError
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a primitive
 * @see {@link isPrimitive}
 * @see {@link Monster.Types.isPrimitive}
 * @see {@link Monster.Types#isPrimitive}
 */


function validatePrimitive(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isPrimitive)(value)) {
    throw new TypeError('value is not a primitive');
  }

  return value;
}
/**
 * This method checks if the type matches the boolean type. this function is identical to isBoolean() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateBoolean()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateBoolean(true)) // ↦ value
 * console.log(Monster.Types.validateBoolean('2')) // ↦ TypeError
 * console.log(Monster.Types.validateBoolean([])) // ↦ TypeError
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateBoolean} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateBoolean(false))  // ↦ value
 * console.log(validateBoolean('2'))  // ↦ TypeError
 * console.log(validateBoolean([]))  // ↦ TypeError
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types

 * @throws {TypeError}  value is not primitive
 */


function validateBoolean(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isBoolean)(value)) {
    throw new TypeError('value is not a boolean');
  }

  return value;
}
/**
 * This method checks if the type matches the string type. this function is identical to isString() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateString()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateString('2')) // ↦ value
 * console.log(Monster.Types.validateString([])) // ↦ TypeError
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateString} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateString('2'))  // ↦ value
 * console.log(validateString([]))  // ↦ TypeError
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a string
 */


function validateString(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isString)(value)) {
    throw new TypeError('value is not a string');
  }

  return value;
}
/**
 * This method checks if the type matches the object type. this function is identical to isObject() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateObject()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateObject({})) // ↦ value
 * console.log(Monster.Types.validateObject('2')) // ↦ TypeError
 * console.log(Monster.Types.validateObject([])) // ↦ TypeError
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateObject} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateObject({}))  // ↦ value
 * console.log(validateObject('2'))  // ↦ TypeError
 * console.log(validateObject([]))  // ↦ TypeError
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a object
 */


function validateObject(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(value)) {
    throw new TypeError('value is not a object');
  }

  return value;
}
/**
 * This method checks if the type matches the object instance.
 *
 * You can call the method via the monster namespace `Monster.Types.validateInstance()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateInstance({}, Object)) // ↦ value
 * console.log(Monster.Types.validateInstance('2', Object)) // ↦ TypeError
 * console.log(Monster.Types.validateInstance([], Object)) // ↦ TypeError
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateInstance} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateInstance({}, Object)) // ↦ value
 * console.log(validateInstance('2', Object)) // ↦ TypeError
 * console.log(validateInstance([], Object)) // ↦ TypeError
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not an instance of
 */


function validateInstance(value, instance) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isInstance)(value, instance)) {
    var n = "";

    if ((0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(instance) || (0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isFunction)(instance)) {
      n = instance === null || instance === void 0 ? void 0 : instance['name'];
    }

    if (n) {
      n = " " + n;
    }

    throw new TypeError('value is not an instance of' + n);
  }

  return value;
}
/**
 * This method checks if the type matches the array type. this function is identical to isArray() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateArray()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateArray('2')) // ↦ TypeError
 * console.log(Monster.Types.validateArray([])) // ↦ value
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateArray} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateArray('2'))  // ↦ TypeError
 * console.log(validateArray([]))  // ↦ value
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not an array
 */


function validateArray(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(value)) {
    throw new TypeError('value is not an array');
  }

  return value;
}
/**
 * This method checks if the type matches the symbol type. this function is identical to isSymbol() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateSymbol()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateSymbol('2')) // ↦ TypeError
 * console.log(Monster.Types.validateSymbol([])) // ↦ value
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateSymbol} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateSymbol('2'))  // ↦ TypeError
 * console.log(validateSymbol())  // ↦ value
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not an symbol
 */


function validateSymbol(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isSymbol)(value)) {
    throw new TypeError('value is not an symbol');
  }

  return value;
}
/**
 * This method checks if the type matches the function type. this function is identical to isFunction() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateFunction()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateFunction(()=>{})) // ↦ value
 * console.log(Monster.Types.validateFunction('2')) // ↦ TypeError
 * console.log(Monster.Types.validateFunction([])) // ↦ TypeError
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateFunction} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateFunction(()=>{})) // ↦ value
 * console.log(validateFunction('2'))  // ↦ TypeError
 * console.log(validateFunction([]))  // ↦ TypeError
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a function
 */


function validateFunction(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isFunction)(value)) {
    throw new TypeError('value is not a function');
  }

  return value;
}
/**
 * This method checks if the type is an integer. this function is identical to isInteger() except that a TypeError is thrown.
 *
 * You can call the method via the monster namespace `Monster.Types.validateInteger()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.validateInteger(true)) // ↦ TypeError
 * console.log(Monster.Types.validateInteger('2')) // ↦ TypeError
 * console.log(Monster.Types.validateInteger(2)) // ↦ value
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {validateFunction} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/validate.js';
 * console.log(validateInteger(true)) // ↦ TypeError
 * console.log(validateInteger('2'))  // ↦ TypeError
 * console.log(validateInteger(2))  // ↦ value
 * </script>
 * ```
 *
 * @param {*} value
 * @return {*}
 * @since 1.4.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not an integer
 */


function validateInteger(value) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_1__.isInteger)(value)) {
    throw new TypeError('value is not an integer');
  }

  return value;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', validatePrimitive, validateBoolean, validateString, validateObject, validateArray, validateFunction, validateIterable, validateInteger);


/***/ }),
/* 15 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "clone": function() { return /* binding */ clone; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(16);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _types_typeof_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(17);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }






/**
 * With this function, objects can be cloned.
 * The entire object tree is run through.
 *
 * Proxy, Element, HTMLDocument and DocumentFragment instances are not cloned.
 * Global objects such as windows are also not cloned,
 *
 * If an object has a method `getClone()`, this method is used to create the clone.
 *
 * You can call the method via the monster namespace `Monster.Util.clone()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Util.clone({})
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {clone} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/util/clone.js';
 * clone({})
 * </script>
 * ```
 *
 * @param {*} obj object to be cloned
 * @returns {*}
 * @since 1.0.0
 * @memberOf Monster.Util
 * @copyright schukai GmbH
 * @throws {Error} unable to clone obj! its type isn't supported.
 */

function clone(obj) {
  // typeof null results in 'object'.  https://2ality.com/2013/10/typeof-null.html
  if (null === obj) {
    return obj;
  } // Handle the two simple types, null and undefined


  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isPrimitive)(obj)) {
    return obj;
  } // Handle the two simple types, null and undefined


  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isFunction)(obj)) {
    return obj;
  } // Handle Array


  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(obj)) {
    var copy = [];

    for (var i = 0, len = obj.length; i < len; i++) {
      copy[i] = clone(obj[i]);
    }

    return copy;
  }

  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(obj)) {
    // Handle Date
    if (obj instanceof Date) {
      var _copy = new Date();

      _copy.setTime(obj.getTime());

      return _copy;
    }
    /** Do not clone DOM nodes */


    if (typeof Element !== 'undefined' && obj instanceof Element) return obj;
    if (typeof HTMLDocument !== 'undefined' && obj instanceof HTMLDocument) return obj;
    if (typeof DocumentFragment !== 'undefined' && obj instanceof DocumentFragment) return obj;
    /** Do not clone global objects */

    if (obj === (0,_types_global_js__WEBPACK_IMPORTED_MODULE_1__.getGlobal)()) return obj;
    if (typeof globalContext !== 'undefined' && obj === globalContext) return obj;
    if (typeof window !== 'undefined' && obj === window) return obj;
    if (typeof document !== 'undefined' && obj === document) return obj;
    if (typeof navigator !== 'undefined' && obj === navigator) return obj;
    if (typeof JSON !== 'undefined' && obj === JSON) return obj; // Handle Proxy-Object

    try {
      // try/catch because possible: TypeError: Function has non-object prototype 'undefined' in instanceof check
      if (obj instanceof Proxy) {
        return obj;
      }
    } catch (e) {}

    return cloneObject(obj);
  }

  throw new Error("unable to clone obj! its type isn't supported.");
}
/**
 *
 * @param {object} obj
 * @returns {object}
 * @private
 */


function cloneObject(obj) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateObject)(obj);
  var constructor = obj === null || obj === void 0 ? void 0 : obj['constructor'];
  /** Object has clone method */

  if ((0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_3__.typeOf)(constructor) === 'function') {
    var prototype = constructor === null || constructor === void 0 ? void 0 : constructor.prototype;

    if (_typeof(prototype) === 'object') {
      if (prototype.hasOwnProperty('getClone') && (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_3__.typeOf)(obj.getClone) === 'function') {
        return obj.getClone();
      }
    }
  }

  var copy = {};

  if (typeof obj.constructor === 'function' && typeof obj.constructor.call === 'function') {
    copy = new obj.constructor();
  }

  for (var key in obj) {
    if (!obj.hasOwnProperty(key)) {
      continue;
    }

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isPrimitive)(obj[key])) {
      copy[key] = obj[key];
      continue;
    }

    copy[key] = clone(obj[key]);
  }

  return copy;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Util', clone);


/***/ }),
/* 16 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "getGlobal": function() { return /* binding */ getGlobal; },
/* harmony export */   "getGlobalObject": function() { return /* binding */ getGlobalObject; },
/* harmony export */   "getGlobalFunction": function() { return /* binding */ getGlobalFunction; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }



/**
 * @type {objec}
 * @private
 */

var globalReference;
/**
 * @private
 * @throws {Error} unsupported environment.
 */

(function () {
  if ((typeof globalThis === "undefined" ? "undefined" : _typeof(globalThis)) === 'object') {
    globalReference = globalThis;
    return;
  }

  if (typeof self !== 'undefined') {
    globalReference = self;
    return;
  } else if (typeof window !== 'undefined') {
    globalReference = window;
    return;
  }

  Object.defineProperty(Object.prototype, '__monster__', {
    get: function get() {
      return this;
    },
    configurable: true
  });

  if ((typeof __monster__ === "undefined" ? "undefined" : _typeof(__monster__)) === 'object') {
    __monster__.globalThis = __monster__;
    delete Object.prototype.__monster__;
    globalReference = globalThis;
    return;
  }

  try {
    globalReference = Function('return this')();
  } catch (e) {}

  throw new Error("unsupported environment.");
})();
/**
 * Return globalThis
 *
 * If globalThis is not available, it will be polyfilled
 *
 * @since 1.6.0
 * @memberOf Monster.Types
 * @returns {objec} globalThis
 */


function getGlobal() {
  return globalReference;
}
/**
 * Return global object or throw Error
 *
 * You can call the method via the monster namespace `Monster.Types.getGlobalObject()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Types.getGlobalObject('document') 
 * // ↦ { }
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getGlobalObject} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/global.js';
 * getGlobalObject('document') 
 * // ↦ { }
 * </script>
 * ```
 *
 * @since 1.6.0
 * @memberOf Monster.Types
 * @param {string} name
 * @returns {objec}
 * @throws {Error} the object is not defined
 * @throws {TypeError} value is not a object
 * @throws {TypeError} value is not a string
 */


function getGlobalObject(name) {
  var _globalReference;

  (0,_validate_js__WEBPACK_IMPORTED_MODULE_1__.validateString)(name);
  var o = (_globalReference = globalReference) === null || _globalReference === void 0 ? void 0 : _globalReference[name];
  if (typeof o === 'undefined') throw new Error('the object ' + name + ' is not defined');
  (0,_validate_js__WEBPACK_IMPORTED_MODULE_1__.validateObject)(o);
  return o;
}
/**
 * Return global function or throw Error
 *
 * You can call the method via the monster namespace `Monster.Types.getGlobalFunction()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.getGlobalFunction('parseInt')) // ↦ f parseInt() { }
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getGlobalFunction} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/global.js';
 * console.log(getGlobalFunction('parseInt')) // ↦ f parseInt() { }
 * </script>
 * ```
 *
 * @since 1.6.0
 * @memberOf Monster.Types
 * @param {string} name
 * @return {objec}
 * @throws {TypeError} value is not a function
 * @throws {Error} the function is not defined
 * @throws {TypeError} value is not a string
 */


function getGlobalFunction(name) {
  var _globalReference2;

  (0,_validate_js__WEBPACK_IMPORTED_MODULE_1__.validateString)(name);
  var f = (_globalReference2 = globalReference) === null || _globalReference2 === void 0 ? void 0 : _globalReference2[name];
  if (typeof f === 'undefined') throw new Error('the function ' + name + ' is not defined');
  (0,_validate_js__WEBPACK_IMPORTED_MODULE_1__.validateFunction)(f);
  return f;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', getGlobal, getGlobalObject, getGlobalFunction);


/***/ }),
/* 17 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "typeOf": function() { return /* binding */ typeOf; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);

/**
 * @author schukai GmbH
 */


/**
 * The built-in typeof method is known to have some historical weaknesses. This function tries to provide a better and more accurate result.
 *
 * You can call the method via the monster namespace `Monster.Types.typeOf()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.typeOf())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {typeOf} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/typeof.js';
 * console.log(typeOf())
 * </script>
 * ```
 *
 * @example
 *
 * import {typeOf} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/typeof.js';
 *
 * console.log(typeOf(undefined)); // ↦ undefined
 * console.log(typeOf("")); // ↦ string
 * console.log(typeOf(5)); // ↦ number
 * console.log(typeOf({})); // ↦ object
 * console.log(typeOf([])); // ↦ array
 * console.log(typeOf(new Map)); // ↦ map
 * console.log(typeOf(true)); // ↦ boolean
 *
 * @param {*} value
 * @return {string}
 * @since 1.7.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @throws {TypeError} value is not a primitive
 */

function typeOf(value) {
  var type = {}.toString.call(value).match(/\s([a-zA-Z]+)/)[1];

  if ('Object' === type) {
    var results = /^(class|function)\s+(\w+)/.exec(value.constructor.toString());
    type = results && results.length > 2 ? results[2] : '';
  }

  return type.toLowerCase();
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', typeOf);


/***/ }),
/* 18 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DELIMITER": function() { return /* binding */ DELIMITER; },
/* harmony export */   "WILDCARD": function() { return /* binding */ WILDCARD; },
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Pathfinder": function() { return /* binding */ Pathfinder; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _types_stack_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(19);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * path separator
 *
 * @private
 * @type {string}
 */

var DELIMITER = '.';
/**
 * @private
 * @type {string}
 */

var WILDCARD = '*';
/**
 * You can call the method via the monster namespace `new Monster.Data.Pathfinder()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Data.Pathfinder())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Pathfinder} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/pathfinder.js';
 * console.log(new Pathfinder())
 * </script>
 * ```
 *
 * With the help of the pathfinder, values can be read and written from an object construct.
 *
 * ```
 * new Pathfinder({
 * a: {
 *     b: {
 *         f: [
 *             {
 *                 g: false,
 *             }
 *         ],
 *     }
 * }
 * }).getVia("a.b.f.0.g"); // ↦ false
 * ```
 *
 * if a value is not present or has the wrong type, a corresponding exception is thrown.
 *
 * ```
 * new Pathfinder({}).getVia("a.b.f.0.g"); // ↦ Error
 * ```
 *
 * The `Pathfinder.exists()` method can be used to check whether access to the path is possible.
 *
 * ```
 * new Pathfinder({}).exists("a.b.f.0.g"); // ↦ false
 * ```
 *
 * pathfinder can also be used to build object structures. to do this, the `Pathfinder.setVia()` method must be used.
 *
 * ```
 * obj = {};
 * new Pathfinder(obj).setVia('a.b.0.c', true); // ↦ {a:{b:[{c:true}]}}
 * ```
 *
 * @example
 *
 * import {Pathfinder} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/pathfinder.js';
 *
 * let value = new Pathfinder({
 * a: {
 *     b: {
 *         f: [
 *             {
 *                 g: false,
 *             }
 *         ],
 *     }
 * }
 * }).getVia("a.b.f.0.g");
 *
 *  console.log(value);
 *  // ↦ false
 *
 * try {
 *   new Pathfinder({}).getVia("a.b.f.0.g");  
 * } catch(e) {
 *   console.log(e.toString());
 *   // ↦ Error: the journey is not at its end (b.f.0.g)
 * }
 *
 * @example
 *
 * import {Pathfinder} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/pathfinder.js';
 *
 * let p = new Pathfinder({
 *                a: {
 *                    x: [
 *                        {c: 1}, {c: 2}
 *                    ],
 *                    y: true
 *                },
 *                b: {
 *                    x: [
 *                        {c: 1, d: false}, {c: 2}
 *                    ],
 *                    y: true
 *                },
 *            });
 *
 * let r = p.getVia("*.x.*.c");
 * console.log(r);
 *
 * @since 1.4.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data
 */

var Pathfinder = /*#__PURE__*/function (_Base) {
  _inherits(Pathfinder, _Base);

  var _super = _createSuper(Pathfinder);

  /**
   * @param {array|object|Map|Set} value
   * @since 1.4.0
   * @throws  {Error} the parameter must not be a simple type
   **/
  function Pathfinder(object) {
    var _this;

    _classCallCheck(this, Pathfinder);

    _this = _super.call(this);

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isPrimitive)(object)) {
      throw new Error('the parameter must not be a simple type');
    }

    _this.object = object;
    _this.wildCard = WILDCARD;
    return _this;
  }
  /**
   * set wildcard
   *
   * @param {string} wildcard
   * @return {Pathfinder}
   * @since 1.7.0
   */


  _createClass(Pathfinder, [{
    key: "setWildCard",
    value: function setWildCard(wildcard) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(wildcard);
      this.wildCard = wildcard;
      return this;
    }
    /**
     *
     * @param {string} path
     * @since 1.4.0
     * @returns {*}
     * @throws {TypeError} unsupported type
     * @throws {Error} the journey is not at its end
     * @throws {TypeError} value is not a string
     * @throws {TypeError} value is not an integer
     * @throws {Error} unsupported action for this data type
     */

  }, {
    key: "getVia",
    value: function getVia(path) {
      return getValueViaPath.call(this, this.object, (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(path));
    }
    /**
     *
     * @param {string} path
     * @param {*} value
     * @returns {Pathfinder}
     * @since 1.4.0
     * @throws {TypeError} unsupported type
     * @throws {TypeError} value is not a string
     * @throws {TypeError} value is not an integer
     * @throws {Error} unsupported action for this data type
     */

  }, {
    key: "setVia",
    value: function setVia(path, value) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(path);
      setValueViaPath.call(this, this.object, path, value);
      return this;
    }
    /**
     * Delete Via Path
     *
     * @param {string} path
     * @returns {Pathfinder}
     * @since 1.6.0
     * @throws {TypeError} unsupported type
     * @throws {TypeError} value is not a string
     * @throws {TypeError} value is not an integer
     * @throws {Error} unsupported action for this data type
     */

  }, {
    key: "deleteVia",
    value: function deleteVia(path) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(path);
      deleteValueViaPath.call(this, this.object, path);
      return this;
    }
    /**
     *
     * @param {string} path
     * @return {bool}
     * @throws {TypeError} unsupported type
     * @throws {TypeError} value is not a string
     * @throws {TypeError} value is not an integer
     * @since 1.4.0
     */

  }, {
    key: "exists",
    value: function exists(path) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(path);

      try {
        getValueViaPath.call(this, this.object, path, true);
        return true;
      } catch (e) {}

      return false;
    }
  }]);

  return Pathfinder;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Data', Pathfinder);

/**
 *
 * @param {*} subject
 * @param {string} path
 * @param {string} check
 * @return {Map}
 * @throws {TypeError} unsupported type
 * @throws {Error} the journey is not at its end
 * @throws {Error} unsupported action for this data type
 * @private
 */

function iterate(subject, path, check) {
  var result = new Map();

  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(subject) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(subject)) {
    for (var _i = 0, _Object$entries = Object.entries(subject); _i < _Object$entries.length; _i++) {
      var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
          key = _Object$entries$_i[0],
          value = _Object$entries$_i[1];

      result.set(key, getValueViaPath.call(this, value, path, check));
    }
  } else {
    var _key = path.split(DELIMITER).shift();

    result.set(_key, getValueViaPath.call(this, subject, path, check));
  }

  return result;
}
/**
 *
 * @param {*} subject
 * @param [string} path
 * @param [boolean} check 
 * @returns {*}
 * @throws {TypeError} unsupported type
 * @throws {Error} the journey is not at its end
 * @throws {Error} unsupported action for this data type
 * @private
 */


function getValueViaPath(subject, path, check) {
  if (path === "") {
    return subject;
  }

  var parts = path.split(DELIMITER);
  var current = parts.shift();

  if (current === this.wildCard) {
    return iterate.call(this, subject, parts.join(DELIMITER), check);
  }

  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(subject) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(subject)) {
    var anchor;

    if (subject instanceof Map || subject instanceof WeakMap) {
      anchor = subject.get(current);
    } else if (subject instanceof Set || subject instanceof WeakSet) {
      var _ref;

      current = parseInt(current);
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInteger)(current);
      anchor = (_ref = _toConsumableArray(subject)) === null || _ref === void 0 ? void 0 : _ref[current];
    } else if (typeof WeakRef === 'function' && subject instanceof WeakRef) {
      throw Error('unsupported action for this data type');
    } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(subject)) {
      current = parseInt(current);
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInteger)(current);
      anchor = subject === null || subject === void 0 ? void 0 : subject[current];
    } else {
      anchor = subject === null || subject === void 0 ? void 0 : subject[current];
    }

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(anchor) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(anchor)) {
      return getValueViaPath.call(this, anchor, parts.join(DELIMITER), check);
    }

    if (parts.length > 0) {
      throw Error("the journey is not at its end (" + parts.join(DELIMITER) + ")");
    }

    if (check === true) {
      var descriptor = Object.getOwnPropertyDescriptor(Object.getPrototypeOf(subject), current);

      if (!subject.hasOwnProperty(current) && descriptor === undefined) {
        throw Error('unknown value');
      }
    }

    return anchor;
  }

  throw TypeError("unsupported type " + _typeof(subject));
}
/**
 *
 * @param object
 * @param path
 * @param value
 * @returns {void}
 * @throws {TypeError} unsupported type
 * @throws {TypeError} unsupported type
 * @throws {Error} the journey is not at its end
 * @throws {Error} unsupported action for this data type
 * @private
 */


function setValueViaPath(object, path, value) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(path);
  var parts = path.split(DELIMITER);
  var last = parts.pop();
  var subpath = parts.join(DELIMITER);
  var stack = new _types_stack_js__WEBPACK_IMPORTED_MODULE_3__.Stack();
  var current = subpath;

  while (true) {
    try {
      getValueViaPath.call(this, object, current, true);
      break;
    } catch (e) {}

    stack.push(current);
    parts.pop();
    current = parts.join(DELIMITER);
    if (current === "") break;
  }

  while (!stack.isEmpty()) {
    current = stack.pop();
    var obj = {};

    if (!stack.isEmpty()) {
      var n = stack.peek().split(DELIMITER).pop();

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isInteger)(parseInt(n))) {
        obj = [];
      }
    }

    setValueViaPath.call(this, object, current, obj);
  }

  var anchor = getValueViaPath.call(this, object, subpath);

  if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(object) && !(0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(object)) {
    throw TypeError("unsupported type: " + _typeof(object));
  }

  if (anchor instanceof Map || anchor instanceof WeakMap) {
    anchor.set(last, value);
  } else if (anchor instanceof Set || anchor instanceof WeakSet) {
    anchor.append(value);
  } else if (typeof WeakRef === 'function' && anchor instanceof WeakRef) {
    throw Error('unsupported action for this data type');
  } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(anchor)) {
    last = parseInt(last);
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInteger)(last);
    assignProperty(anchor, last, value);
  } else {
    assignProperty(anchor, last, value);
  }
}
/**
 * @private
 * @param {object} object
 * @param {string} key
 * @param {*} value
 */


function assignProperty(object, key, value) {
  if (!object.hasOwnProperty(key)) {
    object[key] = value;
    return;
  }

  if (value === undefined) {
    delete object[key];
  }

  object[key] = value;
}
/**
 *
 * @param object
 * @param path
 * @returns {void}
 * @throws {TypeError} unsupported type
 * @throws {TypeError} unsupported type
 * @throws {Error} the journey is not at its end
 * @throws {Error} unsupported action for this data type
 * @since 1.6.0
 * @private
 */


function deleteValueViaPath(object, path) {
  var parts = path.split(DELIMITER);
  var last = parts.pop();
  var subpath = parts.join(DELIMITER);
  var anchor = getValueViaPath.call(this, object, subpath);

  if (anchor instanceof Map) {
    anchor.delete(last);
  } else if (anchor instanceof Set || anchor instanceof WeakMap || anchor instanceof WeakSet || typeof WeakRef === 'function' && anchor instanceof WeakRef) {
    throw Error('unsupported action for this data type');
  } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(anchor)) {
    last = parseInt(last);
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInteger)(last);
    delete anchor[last];
  } else {
    delete anchor[last];
  }
}

/***/ }),
/* 19 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Stack": function() { return /* binding */ Stack; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * You can call the method via the monster namespace `new Monster.Types.Queue()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Types.Stack())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {ID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/stack.js';
 * console.log(new Stack())
 * </script>
 * ```
 *
 * @since 1.4.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var Stack = /*#__PURE__*/function (_Base) {
  _inherits(Stack, _Base);

  var _super = _createSuper(Stack);

  /**
   *
   */
  function Stack() {
    var _this;

    _classCallCheck(this, Stack);

    _this = _super.call(this);
    _this.data = [];
    return _this;
  }
  /**
   * @return {boolean}
   */


  _createClass(Stack, [{
    key: "isEmpty",
    value: function isEmpty() {
      return this.data.length === 0;
    }
    /**
     * looks at the object at the top of this stack without removing it from the stack.
     *
     * @return {*}
     */

  }, {
    key: "peek",
    value: function peek() {
      var _this$data;

      if (this.isEmpty()) {
        return undefined;
      }

      return (_this$data = this.data) === null || _this$data === void 0 ? void 0 : _this$data[this.data.length - 1];
    }
    /**
     * pushes an item onto the top of this stack.
     *
     * @param {*} value
     * @returns {Queue}
     */

  }, {
    key: "push",
    value: function push(value) {
      this.data.push(value);
      return this;
    }
    /**
     * remove all entries
     *
     * @returns {Queue}
     */

  }, {
    key: "clear",
    value: function clear() {
      this.data = [];
      return this;
    }
    /**
     * removes the object at the top of this stack and returns
     * that object as the value of this function. is the stack empty
     * the return value is undefined.
     *
     * @return {*}
     */

  }, {
    key: "pop",
    value: function pop() {
      if (this.isEmpty()) {
        return undefined;
      }

      return this.data.pop();
    }
  }]);

  return Stack;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', Stack);


/***/ }),
/* 20 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "diff": function() { return /* binding */ diff; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _types_typeof_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(17);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }




/**
 * With the diff function you can perform the change of one object to another. The result shows the changes of the second object to the first object.
 *
 * The operator `add` means that something has been added to the second object. `delete` means that something has been deleted from the second object compared to the first object.
 *
 * You can call the method via the monster namespace `Monster.Data.Diff()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Data.Diff(a, b)
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Diff} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/diff.js';
 * Diff(a, b)
 * </script>
 * ```
 *
 * @example
 *
 * import {Diff} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/diff.js';
 *
 * // given are two objects x and y.
 *
 * let x = {
 *     a: 1,
 *     b: "Hello!"
 * }
 *
 *  let y = {
 *     a: 2,
 *     c: true
 * }
 *
 * // These two objects can be compared with each other.
 *
 * console.log(Diff(x, y));
 *
 * // the result is then the following
 *
 * //
 * // [
 * // {
 * //        operator: 'update',
 * //        path: [ 'a' ],
 * //        first: { value: 1, type: 'number' },
 * //        second: { value: 2, type: 'number' }
 * //    },
 * // {
 * //        operator: 'delete',
 * //        path: [ 'b' ],
 * //        first: { value: 'Hello!', type: 'string' }
 * //    },
 * // {
 * //        operator: 'add',
 * //        path: [ 'c' ],
 * //        second: { value: true, type: 'boolean' }
 * //    }
 * // ]
 *
 * @param {*} first
 * @param {*} second
 * @return {array}
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data
 */

function diff(first, second) {
  return doDiff(first, second);
}
/**
 * @private
 * @param a
 * @param b
 * @param type
 * @return {Set<string>|Set<number>}
 */


function getKeys(a, b, type) {
  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(type)) {
    var keys = a.length > b.length ? new Array(a.length) : new Array(b.length);
    keys.fill(0);
    return new Set(keys.map(function (_, i) {
      return i;
    }));
  }

  return new Set(Object.keys(a).concat(Object.keys(b)));
}
/**
 * @private
 * @param a
 * @param b
 * @param path
 * @param diff
 * @return {array}
 */


function doDiff(a, b, path, diff) {
  var typeA = (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(a);
  var typeB = (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(b);
  var currPath = path || [];
  var currDiff = diff || [];

  if (typeA === typeB && (typeA === 'object' || typeA === 'array')) {
    getKeys(a, b, typeA).forEach(function (v) {
      if (!Object.prototype.hasOwnProperty.call(a, v)) {
        currDiff.push(buildResult(a[v], b[v], 'add', currPath.concat(v)));
      } else if (!Object.prototype.hasOwnProperty.call(b, v)) {
        currDiff.push(buildResult(a[v], b[v], 'delete', currPath.concat(v)));
      } else {
        doDiff(a[v], b[v], currPath.concat(v), currDiff);
      }
    });
  } else {
    var o = getOperator(a, b, typeA, typeB);

    if (o !== undefined) {
      currDiff.push(buildResult(a, b, o, path));
    }
  }

  return currDiff;
}
/**
 *
 * @param {*} a
 * @param {*} b
 * @param {string} operator
 * @param {array} path
 * @return {{path: array, operator: string}}
 * @private
 */


function buildResult(a, b, operator, path) {
  var result = {
    operator: operator,
    path: path
  };

  if (operator !== 'add') {
    result.first = {
      value: a,
      type: _typeof(a)
    };

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(a)) {
      var _Object$getPrototypeO, _Object$getPrototypeO2;

      var name = (_Object$getPrototypeO = Object.getPrototypeOf(a)) === null || _Object$getPrototypeO === void 0 ? void 0 : (_Object$getPrototypeO2 = _Object$getPrototypeO.constructor) === null || _Object$getPrototypeO2 === void 0 ? void 0 : _Object$getPrototypeO2.name;

      if (name !== undefined) {
        result.first.instance = name;
      }
    }
  }

  if (operator === 'add' || operator === 'update') {
    result.second = {
      value: b,
      type: _typeof(b)
    };

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(b)) {
      var _Object$getPrototypeO3, _Object$getPrototypeO4;

      var _name = (_Object$getPrototypeO3 = Object.getPrototypeOf(b)) === null || _Object$getPrototypeO3 === void 0 ? void 0 : (_Object$getPrototypeO4 = _Object$getPrototypeO3.constructor) === null || _Object$getPrototypeO4 === void 0 ? void 0 : _Object$getPrototypeO4.name;

      if (_name !== undefined) {
        result.second.instance = _name;
      }
    }
  }

  return result;
}
/**
 * @private
 * @param {*} a
 * @param {*} b
 * @return {boolean}
 */


function isNotEqual(a, b) {
  if (_typeof(a) !== _typeof(b)) {
    return true;
  }

  if (a instanceof Date && b instanceof Date) {
    return a.getTime() !== b.getTime();
  }

  return a !== b;
}
/**
 * @private
 * @param {*} a
 * @param {*} b
 * @return {string|undefined}
 */


function getOperator(a, b) {
  /**
   * @type {string|undefined}
   */
  var operator;
  /**
   * @type {string}
   */

  var typeA = _typeof(a);
  /**
   * @type {string}
   */


  var typeB = _typeof(b);

  if (typeA === 'undefined' && typeB !== 'undefined') {
    operator = 'add';
  } else if (typeA !== 'undefined' && typeB === 'undefined') {
    operator = 'delete';
  } else if (isNotEqual(a, b)) {
    operator = 'update';
  }

  return operator;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Data', diff);


/***/ }),
/* 21 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "extend": function() { return /* binding */ extend; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _types_typeof_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(17);

/**
 * @author schukai GmbH
 */




/**
 * Extend copies all enumerable own properties from one or
 * more source objects to a target object. It returns the modified target object.
 *
 * You can call the method via the monster namespace `Monster.Data.extend()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Data.extend(a, b)
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {extend} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/extend.js';
 * extend(a, b)
 * </script>
 * ```
 *
 * @param {object} target
 * @param {object}
 * @return {object}
 * @since 1.10.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data
 * @throws {Error} unsupported argument
 * @throws {Error} type mismatch
 */

function extend() {
  var o, i;

  for (i = 0; i < arguments.length; i++) {
    var a = arguments[i];

    if (!((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(a) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(a))) {
      throw new Error('unsupported argument ' + JSON.stringify(a));
    }

    if (o === undefined) {
      o = a;
      continue;
    }

    for (var k in a) {
      var _o;

      var v = a === null || a === void 0 ? void 0 : a[k];

      if (v === ((_o = o) === null || _o === void 0 ? void 0 : _o[k])) {
        continue;
      }

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(v) && (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(v) === 'object' || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(v)) {
        if (o[k] === undefined) {
          if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(v)) {
            o[k] = [];
          } else {
            o[k] = {};
          }
        } else {
          if ((0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(o[k]) !== (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(v)) {
            throw new Error("type mismatch: " + JSON.stringify(o[k]) + "(" + (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(o[k]) + ") != " + JSON.stringify(v) + "(" + (0,_types_typeof_js__WEBPACK_IMPORTED_MODULE_2__.typeOf)(v) + ")");
          }
        }

        o[k] = extend(o[k], v);
      } else {
        o[k] = v;
      }
    }
  }

  return o;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Data', extend);


/***/ }),
/* 22 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Pipe": function() { return /* binding */ Pipe; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);
/* harmony import */ var _transformer_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(23);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }





var DELIMITER = '|';
/**
 * The pipe class makes it possible to combine several processing steps.
 *
 * You can call the method via the monster namespace `new Monster.Data.Pipe()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Data.Pipe()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Pipe} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/pipe.js';
 * new Pipe()
 * </script>
 * ```
 *
 * A pipe consists of commands whose input and output are connected with the pipe symbol `|`.
 *
 * With the Pipe, processing steps can be combined. Here, the value of an object is accessed via the pathfinder (path command).
 * the word is then converted to uppercase letters and a prefix Hello is added. the two backslash safe the space char.
 *
 * @example
 * import {Pipe} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/pipe.js';
 *
 * let obj = {
 *    a: {
 *        b: {
 *            c: {
 *                d: "world"
 *            }
 *        }
 *    }
 * }
 *
 * console.log(new Pipe('path:a.b.c.d | toupper | prefix:Hello\\ ').run(obj));
 * // ↦ Hello WORLD
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data
 */

var Pipe = /*#__PURE__*/function (_Base) {
  _inherits(Pipe, _Base);

  var _super = _createSuper(Pipe);

  /**
   *
   * @param {string} pipe a pipe consists of commands whose input and output are connected with the pipe symbol `|`.
   * @throws {TypeError}
   */
  function Pipe(pipe) {
    var _this;

    _classCallCheck(this, Pipe);

    _this = _super.call(this);
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(pipe);
    _this.pipe = pipe.split(DELIMITER).map(function (v) {
      return new _transformer_js__WEBPACK_IMPORTED_MODULE_3__.Transformer(v);
    });
    return _this;
  }
  /**
   *
   * @param {string} name
   * @param {function} callback
   * @param {object} context
   * @returns {Transformer}
   * @throws {TypeError} value is not a string
   * @throws {TypeError} value is not a function
   */


  _createClass(Pipe, [{
    key: "setCallback",
    value: function setCallback(name, callback, context) {
      for (var _i = 0, _Object$entries = Object.entries(this.pipe); _i < _Object$entries.length; _i++) {
        var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
            t = _Object$entries$_i[1];

        t.setCallback(name, callback, context);
      }

      return this;
    }
    /**
     * run a pipe
     *
     * @param {*} value
     * @returns {*}
     */

  }, {
    key: "run",
    value: function run(value) {
      return this.pipe.reduce(function (accumulator, transformer, currentIndex, array) {
        return transformer.run(accumulator);
      }, value);
    }
  }]);

  return Pipe;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Data', Pipe);


/***/ }),
/* 23 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Transformer": function() { return /* binding */ Transformer; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(16);
/* harmony import */ var _types_id_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(24);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(14);
/* harmony import */ var _util_clone_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(15);
/* harmony import */ var _pathfinder_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(18);

/**
 * @author schukai GmbH
 */

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _wrapRegExp() { _wrapRegExp = function _wrapRegExp(re, groups) { return new BabelRegExp(re, undefined, groups); }; var _super = RegExp.prototype; var _groups = new WeakMap(); function BabelRegExp(re, flags, groups) { var _this = new RegExp(re, flags); _groups.set(_this, groups || _groups.get(re)); return _setPrototypeOf(_this, BabelRegExp.prototype); } _inherits(BabelRegExp, RegExp); BabelRegExp.prototype.exec = function (str) { var result = _super.exec.call(this, str); if (result) result.groups = buildGroups(result, this); return result; }; BabelRegExp.prototype[Symbol.replace] = function (str, substitution) { if (typeof substitution === "string") { var groups = _groups.get(this); return _super[Symbol.replace].call(this, str, substitution.replace(/\$<([^>]+)>/g, function (_, name) { return "$" + groups[name]; })); } else if (typeof substitution === "function") { var _this = this; return _super[Symbol.replace].call(this, str, function () { var args = arguments; if (_typeof(args[args.length - 1]) !== "object") { args = [].slice.call(args); args.push(buildGroups(args, _this)); } return substitution.apply(this, args); }); } else { return _super[Symbol.replace].call(this, str, substitution); } }; function buildGroups(result, re) { var g = _groups.get(re); return Object.keys(g).reduce(function (groups, name) { groups[name] = result[g[name]]; return groups; }, Object.create(null)); } return _wrapRegExp.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }









/**
 * The transformer class is a swiss army knife for manipulating values. especially in combination with the pipe, processing chains can be built up.
 *
 * You can call the method via the monster namespace `new Monster.Data.Transformer()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Data.Transformer()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Transformer} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/transformer.js';
 * new Transformer()
 * </script>
 * ```
 *
 * A simple example is the conversion of all characters to lowercase. for this purpose the command `tolower` must be used.
 *
 * ```
 * let t = new Transformer('tolower').run('ABC'); // ↦ abc
 * ```
 *
 * **all commands**
 *
 * in the following table all commands, parameters and existing aliases are described.
 *
 * | command      | parameter                  | alias                   | description                                                                                                                                                                                                                                                                                                                                                |
 * |:-------------|:---------------------------|:------------------------|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
 * | to-base64    |                            | base64, btob            | Converts the value to base64                                                                                                                                                                                                                                                                                                                               |
 * | from-base64  |                            | atob                    | Converts the value from base64                                                                                                                                                                                                                                                                                                                             |
 * | call         | function:param1:param2:... |                         | Calling a callback function. The function can be defined in three places: either globally, in the context `addCallback` or in the passed object                                                                                                                                                                                                            |
 * | default      | value:type                 | ??                      | If the value is undefined the first argument is returned, otherwise the value. The third optional parameter specifies the desired type. If no type is specified, string is used. Valid types are bool, string, int, float, undefined and object. An object default value must be specified as a base64 encoded json string. (since 1.12.0)                 |
 * | debug        |                            |                         | the passed value is output (console) and returned  |
 * | empty        |                            |                         | Return empty String ""                                                                                                                                                                                                                                                                                                                                     |
 * | first-key    | default                    |                         | Can be applied to objects and returns the value of the first key. All keys of the object are fetched and sorted.    (since 1.23.0)                                                                                                                                                                                                                         |
 * | fromjson     |                            |                         | Type conversion from a JSON string (since 1.12.0)                                                                                                                                                                                                                                                                                                          |
 * | if           | statement1:statement2      | ?                       | Is the ternary operator, the first parameter is the valid statement, the second is the false part. To use the current value in the queue, you can set the value keyword. On the other hand, if you want to have the static string "value", you have to put one backslash \\ in front of it and write value. the follow values are true: 'on', true, 'true'. If you want to have a space, you also have to write \\ in front of the space.  |
 * | index        | key:default                | property, key           | Fetches a value from an object, an array, a map or a set                                                                                                                                                                                                                                                                                                   |
 * | last-key     | default                    |                         | Can be applied to objects and returns the value of the last key. All keys of the object are fetched and sorted. (since 1.23.0)                                                                                                                                                                                                                             |
 * | length       |                            | count                   | Length of the string or entries of an array or object                                                                                                                                                                                                                                                                                                      |
 * | nop          |                            |                         | Do nothing                                                                                                                                                                                                                                                                                                                                                 |
 * | nth-key      | index:default              |                         | Can be applied to objects and returns the value of the nth key. All keys of the object are fetched and sorted. (since 1.23.0)                                                                                                                                                                                                                              |
 * | nth-last-key | index:default              |                         | Can be applied to objects and returns the value of the nth key from behind. All keys of the object are fetched and sorted. (since 1.23.0)                                                                                                                                                                                                                  |
 * | path         | path                       |                         | The access to an object is done via a Pathfinder object                                                                                                                                                                                                                                                                                                    |
 * | path-exists  | path                       |                         | Check if the specified path is available in the value (since 1.24.0)    |
 * | plaintext    |                            | plain                   | All HTML tags are removed (*)                                                                                                                                                                                                                                                                                                                              |
 * | prefix       | text                       |                         | Adds a prefix                                                                                                                                                                                                                                                                                                                                              |
 * | rawurlencode |                            |                         | URL coding                                                                                                                                                                                                                                                                                                                                                 |
 * | static       |                            | none                    | The Arguments value is used and passed to the value. Special characters \ <space> and : can be quotet by a preceding \.                                                                                                                                                                                                                                    |
 * | substring    | start:length               |                         | Returns a substring                                                                                                                                                                                                                                                                                                                                        |
 * | suffix       | text                       |                         | Adds a suffix                                                                                                                                                                                                                                                                                                                                              |
 * | tointeger    |                            |                         | Type conversion to an integer value                                                                                                                                                                                                                                                                                                                        |
 * | tojson       |                            |                         | Type conversion to a JSON string (since 1.8.0)                                                                                                                                                                                                                                                                                                             |
 * | tolower      |                            | strtolower, tolowercase | The input value is converted to lowercase letters                                                                                                                                                                                                                                                                                                          |
 * | tostring     |                            |                         | Type conversion to a string.                                                                                                                                                                                                                                                                                                                               |
 * | toupper      |                            | strtoupper, touppercase | The input value is converted to uppercase letters                                                                                                                                                                                                                                                                                                          |
 * | trim         |                            |                         | Remove spaces at the beginning and end                                                                                                                                                                                                                                                                                                                     |
 * | ucfirst      |                            |                         | First character large                                                                                                                                                                                                                                                                                                                                      |
 * | ucwords      |                            |                         | Any word beginning large                                                                                                                                                                                                                                                                                                                                   |
 * | undefined    |                            |                         | Return undefined                                                                                                                                                                                                                                                                                                                                           |
 * | uniqid       |                            |                         | Creates a string with a unique value (**)
 *
 *  (*) for this functionality the extension [jsdom](https://www.npmjs.com/package/jsdom) must be loaded in the nodejs context.
 *
 * ```
 *  // polyfill
 *  if (typeof window !== "object") {
 *     const {window} = new JSDOM('', {
 *         url: 'http://example.com/',
 *         pretendToBeVisual: true
 *     });
 * 
 *     [
 *         'self',
 *         'document',
 *         'Node',
 *         'Element',
 *         'HTMLElement',
 *         'DocumentFragment',
 *         'DOMParser',
 *         'XMLSerializer',
 *         'NodeFilter',
 *         'InputEvent',
 *         'CustomEvent'
 *     ].forEach(key => (global[key] = window[key]));
 * }
 * ```
 *
 * (**) for this command the crypt library is necessary in the nodejs context.
 *
 * ```
 * import * as Crypto from "@peculiar/webcrypto";
 * global['crypto'] = new Crypto.Crypto();
 * ```
 *
 * @example
 *
 * import {Transformer} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/data/transformer.js';
 *
 * const transformer = new Transformer("tolower")
 *
 * console.log(transformer.run("HELLO"))
 * // ↦ hello
 *
 * console.log(transformer.run("WORLD"))
 * // ↦ world
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Data
 */

var Transformer = /*#__PURE__*/function (_Base) {
  _inherits(Transformer, _Base);

  var _super = _createSuper(Transformer);

  /**
   *
   * @param {string} definition
   */
  function Transformer(definition) {
    var _this;

    _classCallCheck(this, Transformer);

    _this = _super.call(this);
    _this.args = disassemble(definition);
    _this.command = _this.args.shift();
    _this.callbacks = new Map();
    return _this;
  }
  /**
   *
   * @param {string} name
   * @param {function} callback
   * @param {object} context
   * @returns {Transformer}
   * @throws {TypeError} value is not a string
   * @throws {TypeError} value is not a function
   */


  _createClass(Transformer, [{
    key: "setCallback",
    value: function setCallback(name, callback, context) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(name);
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateFunction)(callback);

      if (context !== undefined) {
        (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateObject)(context);
      }

      this.callbacks.set(name, {
        callback: callback,
        context: context
      });
      return this;
    }
    /**
     *
     * @param {*} value
     * @returns {*}
     * @throws {Error} unknown command
     * @throws {TypeError} unsupported type
     * @throws {Error} type not supported
     */

  }, {
    key: "run",
    value: function run(value) {
      return transform.apply(this, [value]);
    }
  }]);

  return Transformer;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Data', Transformer);

/**
 *
 * @param {string} command
 * @returns {array}
 * @private
 */

function disassemble(command) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(command);
  var placeholder = new Map();

  var regex = /*#__PURE__*/_wrapRegExp(/((\\(.)){1})/mig, {
    pattern: 2,
    char: 3
  }); // The separator for args must be escaped
  // undefined string which should not occur normally and is also not a regex


  var result = command.matchAll(regex);

  var _iterator = _createForOfIteratorHelper(result),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var m = _step.value;
      var g = m === null || m === void 0 ? void 0 : m['groups'];

      if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(g)) {
        continue;
      }

      var p = g === null || g === void 0 ? void 0 : g['pattern'];
      var c = g === null || g === void 0 ? void 0 : g['char'];

      if (p && c) {
        var r = '__' + new _types_id_js__WEBPACK_IMPORTED_MODULE_3__.ID().toString() + '__';
        placeholder.set(r, c);
        command = command.replace(p, r);
      }
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  var parts = command.split(':');
  parts = parts.map(function (value) {
    var v = value.trim();

    var _iterator2 = _createForOfIteratorHelper(placeholder),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var k = _step2.value;
        v = v.replace(k[0], k[1]);
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    return v;
  });
  return parts;
}
/**
 * tries to make a string out of value and if this succeeds to return it back
 *
 * @param {*} value
 * @returns {string}
 * @private
 */


function convertToString(value) {
  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(value) && value.hasOwnProperty('toString')) {
    value = value.toString();
  }

  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
  return value;
}
/**
 *
 * @param {*} value
 * @returns {*}
 * @private
 * @throws {Error} unknown command
 * @throws {TypeError} unsupported type
 * @throws {Error} type not supported
 * @throws {Error} missing key parameter
 */


function transform(value) {
  var _callback;

  var console = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalObject)('console');
  var args = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_6__.clone)(this.args);
  var key, defaultValue;

  switch (this.command) {
    case 'static':
      return this.args.join(':');

    case 'tolower':
    case 'strtolower':
    case 'tolowercase':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      return value.toLowerCase();

    case 'toupper':
    case 'strtoupper':
    case 'touppercase':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      return value.toUpperCase();

    case 'tostring':
      return "" + value;

    case 'tointeger':
      var n = parseInt(value);
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateInteger)(n);
      return n;

    case 'tojson':
      return JSON.stringify(value);

    case 'fromjson':
      return JSON.parse(value);

    case 'trim':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      return value.trim();

    case 'rawurlencode':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      return encodeURIComponent(value).replace(/!/g, '%21').replace(/'/g, '%27').replace(/\(/g, '%28').replace(/\)/g, '%29').replace(/\*/g, '%2A');

    case 'call':
      /**
       * callback-definition
       * function callback(value, ...args) {
       *   return value;
       * }
       */
      var callback;
      var callbackName = args.shift();
      var context = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobal)();

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(value) && value.hasOwnProperty(callbackName)) {
        callback = value[callbackName];
      } else if (this.callbacks.has(callbackName)) {
        var s = this.callbacks.get(callbackName);
        callback = s === null || s === void 0 ? void 0 : s['callback'];
        context = s === null || s === void 0 ? void 0 : s['context'];
      } else if ((typeof window === "undefined" ? "undefined" : _typeof(window)) === 'object' && window.hasOwnProperty(callbackName)) {
        callback = window[callbackName];
      }

      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateFunction)(callback);
      args.unshift(value);
      return (_callback = callback).call.apply(_callback, [context].concat(_toConsumableArray(args)));

    case 'plain':
    case 'plaintext':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      var doc = new DOMParser().parseFromString(value, 'text/html');
      return doc.body.textContent || "";

    case 'if':
    case '?':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validatePrimitive)(value);
      var trueStatement = args.shift() || undefined;
      var falseStatement = args.shift() || undefined;

      if (trueStatement === 'value') {
        trueStatement = value;
      }

      if (trueStatement === '\\value') {
        trueStatement = 'value';
      }

      if (falseStatement === 'value') {
        falseStatement = value;
      }

      if (falseStatement === '\\value') {
        falseStatement = 'value';
      }

      var condition = value !== undefined && value !== '' && value !== 'off' && value !== 'false' && value !== false || value === 'on' || value === 'true' || value === true;
      return condition ? trueStatement : falseStatement;

    case 'ucfirst':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      var firstchar = value.charAt(0).toUpperCase();
      return firstchar + value.substr(1);

    case 'ucwords':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      return value.replace(/^([a-z\u00E0-\u00FC])|\s+([a-z\u00E0-\u00FC])/g, function (v) {
        return v.toUpperCase();
      });

    case 'count':
    case 'length':
      if (((0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isString)(value) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(value) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isArray)(value)) && value.hasOwnProperty('length')) {
        return value.length;
      }

      throw new TypeError("unsupported type " + _typeof(value));

    case 'to-base64':
    case 'btoa':
    case 'base64':
      return btoa(convertToString(value));

    case 'atob':
    case 'from-base64':
      return atob(convertToString(value));

    case 'empty':
      return '';

    case 'undefined':
      return undefined;

    case 'debug':
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(console)) {
        console.log(value);
      }

      return value;

    case 'prefix':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      var prefix = args === null || args === void 0 ? void 0 : args[0];
      return prefix + value;

    case 'suffix':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      var suffix = args === null || args === void 0 ? void 0 : args[0];
      return value + suffix;

    case 'uniqid':
      return new _types_id_js__WEBPACK_IMPORTED_MODULE_3__.ID().toString();

    case 'first-key':
    case 'last-key':
    case 'nth-last-key':
    case 'nth-key':
      if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(value)) {
        throw new Error("type not supported");
      }

      var keys = Object.keys(value).sort();

      if (this.command === 'first-key') {
        key = 0;
      } else if (this.command === 'last-key') {
        key = keys.length - 1;
      } else {
        key = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateInteger)(parseInt(args.shift()));

        if (this.command === 'nth-last-key') {
          key = keys.length - key - 1;
        }
      }

      defaultValue = args.shift() || '';
      var useKey = keys === null || keys === void 0 ? void 0 : keys[key];

      if (value !== null && value !== void 0 && value[useKey]) {
        return value === null || value === void 0 ? void 0 : value[useKey];
      }

      return defaultValue;

    case 'key':
    case 'property':
    case 'index':
      key = args.shift() || undefined;

      if (key === undefined) {
        throw new Error("missing key parameter");
      }

      defaultValue = args.shift() || undefined;

      if (value instanceof Map) {
        if (!value.has(key)) {
          return defaultValue;
        }

        return value.get(key);
      }

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isObject)(value) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_4__.isArray)(value)) {
        if (value !== null && value !== void 0 && value[key]) {
          return value === null || value === void 0 ? void 0 : value[key];
        }

        return defaultValue;
      }

      throw new Error("type not supported");

    case 'path-exists':
      key = args.shift();

      if (key === undefined) {
        throw new Error("missing key parameter");
      }

      return new _pathfinder_js__WEBPACK_IMPORTED_MODULE_7__.Pathfinder(value).exists(key);

    case 'path':
      key = args.shift();

      if (key === undefined) {
        throw new Error("missing key parameter");
      }

      var pf = new _pathfinder_js__WEBPACK_IMPORTED_MODULE_7__.Pathfinder(value);

      if (!pf.exists(key)) {
        return undefined;
      }

      return pf.getVia(key);

    case 'substring':
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateString)(value);
      var start = parseInt(args[0]) || 0;
      var end = (parseInt(args[1]) || 0) + start;
      return value.substring(start, end);

    case 'nop':
      return value;

    case '??':
    case 'default':
      if (value !== undefined && value !== null) {
        return value;
      }

      defaultValue = args.shift();
      var defaultType = args.shift();

      if (defaultType === undefined) {
        defaultType = 'string';
      }

      switch (defaultType) {
        case 'int':
        case 'integer':
          return parseInt(defaultValue);

        case 'float':
          return parseFloat(defaultValue);

        case 'undefined':
          return undefined;

        case 'bool':
        case 'boolean':
          defaultValue = defaultValue.toLowerCase();
          return defaultValue !== 'undefined' && defaultValue !== '' && defaultValue !== 'off' && defaultValue !== 'false' && defaultValue !== 'false' || defaultValue === 'on' || defaultValue === 'true' || defaultValue === 'true';

        case 'string':
          return "" + defaultValue;

        case "object":
          return JSON.parse(atob(defaultValue));
      }

      throw new Error("type not supported");

    default:
      throw new Error("unknown command " + this.command);
  }

  return value;
}

/***/ }),
/* 24 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "ID": function() { return /* binding */ ID; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }




/**
 * @private
 * @type {Map<string, integer>}
 */

var internalCounter = new Map();
/**
 * With the id class, sequences of ids can be created. for this purpose, an internal counter is incremented for each prefix.
 * thus, the first id with the prefix `myid` will be `myid1` and the second id `myid2`.
 * The ids are the same for every call, for example on a web page.
 *
 * So the ids can also be used for navigation. you just have to take care that the order stays the same.
 *
 * You can call the method via the monster namespace `new Monster.Types.ID()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Types.ID())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {ID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/id.js';
 * console.log(new ID())
 * </script>
 * ```
 *
 * As of version 1.6.0 there is the new RandomID. this ID class is continuous from now on.
 *
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @summary Automatic generation of ids
 */

var ID = /*#__PURE__*/function (_Base) {
  _inherits(ID, _Base);

  var _super = _createSuper(ID);

  /**
   * create new id with prefix
   *
   * @param {string} prefix
   */
  function ID(prefix) {
    var _this;

    _classCallCheck(this, ID);

    _this = _super.call(this);

    if (prefix === undefined) {
      prefix = "id";
    }

    (0,_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(prefix);

    if (!internalCounter.has(prefix)) {
      internalCounter.set(prefix, 1);
    }

    var count = internalCounter.get(prefix);
    _this.id = prefix + count;
    internalCounter.set(prefix, ++count);
    return _this;
  }
  /**
   * @return {string}
   */


  _createClass(ID, [{
    key: "toString",
    value: function toString() {
      return this.id;
    }
  }]);

  return ID;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', ID);


/***/ }),
/* 25 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "ATTRIBUTEPREFIX": function() { return /* binding */ ATTRIBUTEPREFIX; },
/* harmony export */   "Assembler": function() { return /* binding */ Assembler; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(16);
/* harmony import */ var _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(26);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * attribute prefix
 *
 * @type {string}
 * @memberOf Monster.DOM
 */

var ATTRIBUTEPREFIX = "data-monster-";
/**
 * you can call the method via the monster namespace `new Monster.DOM.Assembler()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.DOM.Assembler())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Assembler} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/assembler.js';
 * console.log(new Assembler())
 * </script>
 * ```
 *
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @summary Allows you to build an html fragment
 */

var Assembler = /*#__PURE__*/function (_Base) {
  _inherits(Assembler, _Base);

  var _super = _createSuper(Assembler);

  /**
   * @param {DocumentFragment} fragment
   * @throws {TypeError} value is not an instance of
   * @throws {TypeError} value is not a function
   * @throws {Error} the function is not defined
   */
  function Assembler(fragment) {
    var _this;

    _classCallCheck(this, Assembler);

    _this = _super.call(this);
    _this.attributePrefix = ATTRIBUTEPREFIX;
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInstance)(fragment, (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalFunction)('DocumentFragment'));
    _this.fragment = fragment;
    return _this;
  }
  /**
   *
   * @param {string} prefix
   * @returns {Assembler}
   * @throws {TypeError} value is not a string
   */


  _createClass(Assembler, [{
    key: "setAttributePrefix",
    value: function setAttributePrefix(prefix) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(prefix);
      this.attributePrefix = prefix;
      return this;
    }
    /**
     *
     * @returns {string}
     */

  }, {
    key: "getAttributePrefix",
    value: function getAttributePrefix() {
      return this.attributePrefix;
    }
    /**
     *
     * @param {ProxyObserver|undefined} data
     * @return {DocumentFragment}
     * @throws {TypeError} value is not an instance of
     */

  }, {
    key: "createDocumentFragment",
    value: function createDocumentFragment(data) {
      if (data === undefined) {
        data = new _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_3__.ProxyObserver({});
      }

      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInstance)(data, _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_3__.ProxyObserver);
      var fragment = this.fragment.cloneNode(true);
      return fragment;
    }
  }]);

  return Assembler;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.DOM', Assembler);


/***/ }),
/* 26 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "ProxyObserver": function() { return /* binding */ ProxyObserver; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _observer_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(27);
/* harmony import */ var _observerlist_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(31);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(14);
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(21);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }








/**
 * An observer manages a callback function
 *
 * You can call create the class via the monster namespace `new Monster.Types.ProxyObserver()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.ProxyObserver()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this class individually.
 *
 * ```
 * <script type="module">
 * import {ProxyObserver} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/proxyobserver.js';
 * new ProxyObserver()
 * </script>
 * ```
 *
 * with the ProxyObserver you can attach observer for observation. with each change at the object to be observed an update takes place.
 *
 * this also applies to nested objects.
 *
 * @example
 *
 * import {ProxyObserver} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/proxyobserver.js';
 * import {Observer} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/observer.js';
 * import {isObject} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/is.js';
 *
 * const o = new Observer(function () { 
 *   if (isObject(this) && this instanceof ProxyObserver) {
 *       // do something (this ist ProxyObserver)
 *       const subject = this.getSubject();
 *       console.log(subject);
 *   }
 * });
 *
 * let realSubject = {
 *   a: {
 *       b: {
 *           c: true
 *       },
 *       d: 9
 *   }
 * }
 *
 * const p = new ProxyObserver(realSubject);
 * p.attachObserver(o);
 * const s = p.getSubject();
 * s.a.b.c = false;
 *
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var ProxyObserver = /*#__PURE__*/function (_Base) {
  _inherits(ProxyObserver, _Base);

  var _super = _createSuper(ProxyObserver);

  /**
   *
   * @param {object} object
   * @throws {TypeError} value is not a object
   */
  function ProxyObserver(object) {
    var _this;

    _classCallCheck(this, ProxyObserver);

    _this = _super.call(this);
    _this.realSubject = (0,_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateObject)(object);
    _this.subject = new Proxy(object, getHandler.call(_assertThisInitialized(_this)));
    _this.objectMap = new WeakMap();

    _this.objectMap.set(_this.realSubject, _this.subject);

    _this.proxyMap = new WeakMap();

    _this.proxyMap.set(_this.subject, _this.realSubject);

    _this.observers = new _observerlist_js__WEBPACK_IMPORTED_MODULE_4__.ObserverList();
    return _this;
  }
  /**
   * get the real object
   *
   * changes to this object are not noticed by the observers, so you can make a large number of changes and inform the observers later.
   *
   * @returns {object}
   */


  _createClass(ProxyObserver, [{
    key: "getSubject",
    value: function getSubject() {
      return this.subject;
    }
    /**
     * @since 1.24.0
     * @param {Object} obj
     * @return {Monster.Types.ProxyObserver}
     */

  }, {
    key: "setSubject",
    value: function setSubject(obj) {
      var i,
          k = Object.keys(this.subject);

      for (i = 0; i < k.length; i++) {
        delete this.subject[k[i]];
      }

      this.subject = (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_6__.extend)(this.subject, obj);
      return this;
    }
    /**
     * get the proxied object
     *
     * @returns {object}
     */

  }, {
    key: "getRealSubject",
    value: function getRealSubject() {
      return this.realSubject;
    }
    /**
     * attach a new observer
     *
     * @param {Observer} observer
     * @returns {ProxyObserver}
     */

  }, {
    key: "attachObserver",
    value: function attachObserver(observer) {
      this.observers.attach(observer);
      return this;
    }
    /**
     * detach a observer
     *
     * @param {Observer} observer
     * @returns {ProxyObserver}
     */

  }, {
    key: "detachObserver",
    value: function detachObserver(observer) {
      this.observers.detach(observer);
      return this;
    }
    /**
     * notify all observer
     *
     * @returns {Promise}
     */

  }, {
    key: "notifyObservers",
    value: function notifyObservers() {
      return this.observers.notify(this);
    }
    /**
     * @param {Observer} observer
     * @returns {boolean}
     */

  }, {
    key: "containsObserver",
    value: function containsObserver(observer) {
      return this.observers.contains(observer);
    }
  }]);

  return ProxyObserver;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', ProxyObserver);

/**
 *
 * @returns {{defineProperty: (function(*=, *=, *=): *), setPrototypeOf: (function(*, *=): boolean), set: (function(*, *, *, *): boolean), get: ((function(*=, *=, *=): (undefined))|*), deleteProperty: ((function(*, *): (boolean))|*)}}
 * @private
 * @see {@link https://gitlab.schukai.com/-/snippets/49}
 */

function getHandler() {
  var proxy = this; // https://262.ecma-international.org/9.0/#sec-proxy-object-internal-methods-and-internal-slots

  var handler = {
    // https://262.ecma-international.org/9.0/#sec-proxy-object-internal-methods-and-internal-slots-get-p-receiver
    get: function get(target, key, receiver) {
      var value = Reflect.get(target, key, receiver);

      if (_typeof(key) === "symbol") {
        return value;
      }

      if ((0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isPrimitive)(value)) {
        return value;
      } // set value as proxy if object or array


      if ((0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isArray)(value) || (0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(value)) {
        if (proxy.objectMap.has(value)) {
          return proxy.objectMap.get(value);
        } else if (proxy.proxyMap.has(value)) {
          return value;
        } else {
          var p = new Proxy(value, handler);
          proxy.objectMap.set(value, p);
          proxy.proxyMap.set(p, value);
          return p;
        }
      }

      return value;
    },
    // https://262.ecma-international.org/9.0/#sec-proxy-object-internal-methods-and-internal-slots-set-p-v-receiver 
    set: function set(target, key, value, receiver) {
      if (proxy.proxyMap.has(value)) {
        value = proxy.proxyMap.get(value);
      }

      if (proxy.proxyMap.has(target)) {
        target = proxy.proxyMap.get(target);
      }

      var current = Reflect.get(target, key, receiver);

      if (proxy.proxyMap.has(current)) {
        current = proxy.proxyMap.get(current);
      }

      if (current === value) {
        return true;
      }

      var result;
      var descriptor = Reflect.getOwnPropertyDescriptor(target, key);

      if (descriptor === undefined) {
        descriptor = {
          writable: true,
          enumerable: true,
          configurable: true
        };
      }

      descriptor['value'] = value;
      result = Reflect.defineProperty(target, key, descriptor);

      if (_typeof(key) !== "symbol") {
        proxy.observers.notify(proxy);
      }

      return result;
    },
    // https://262.ecma-international.org/9.0/#sec-proxy-object-internal-methods-and-internal-slots-delete-p
    deleteProperty: function deleteProperty(target, key) {
      if (key in target) {
        delete target[key];

        if (_typeof(key) !== "symbol") {
          proxy.observers.notify(proxy);
        }

        return true;
      }

      return false;
    },
    // https://262.ecma-international.org/9.0/#sec-proxy-object-internal-methods-and-internal-slots-defineownproperty-p-desc
    defineProperty: function defineProperty(target, key, descriptor) {
      var result = Reflect.defineProperty(target, key, descriptor);

      if (_typeof(key) !== "symbol") {
        proxy.observers.notify(proxy);
      }

      return result;
    },
    // https://262.ecma-international.org/9.0/#sec-proxy-object-internal-methods-and-internal-slots-setprototypeof-v
    setPrototypeOf: function setPrototypeOf(target, key) {
      var result = Reflect.setPrototypeOf(object1, key);

      if (_typeof(key) !== "symbol") {
        proxy.observers.notify(proxy);
      }

      return result;
    }
  };
  return handler;
}

/***/ }),
/* 27 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Observer": function() { return /* binding */ Observer; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _tokenlist_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(28);
/* harmony import */ var _uniquequeue_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(29);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * An observer manages a callback function
 *
 * You can call the method via the monster namespace `new Monster.Types.Observer()`.
 *
 * ```
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.Observer()
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * import {Observer} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/observer.js';
 * new Observer()
 * ```
 *
 * The update method is called with the subject object as this pointer. For this reason the callback should not
 * be an arrow function, because it gets the this pointer of its own context.
 *
 * ```
 * new Observer(()=>{
 *     // this is not subject
 * })
 *
 * new Observer(function() {
 *     // this is subject
 * })
 * ```
 *
 * Additional arguments can be passed to the callback. To do this, simply specify them.
 *
 * ```
 * Observer(function(a, b, c) {
 *     console.log(a, b, c); // ↦ "a", 2, true 
 * }, "a", 2, true)
 * ```
 *
 * The callback function must have as many parameters as arguments are given.
 *
 * @example
 *
 * import {Observer} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/observer.js';
 *
 * const observer = new Observer(function(a, b, c) {
 *      console.log(this, a, b, c); // ↦ "a", 2, true 
 * }, "a", 2, true);
 *
 * observer.update({value:true}).then(()=>{});
 * // ↦ {value: true} "a" 2 true
 *
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var Observer = /*#__PURE__*/function (_Base) {
  _inherits(Observer, _Base);

  var _super = _createSuper(Observer);

  /**
   *
   * @param {function} callback
   * @param {*} args
   */
  function Observer(callback) {
    var _this;

    _classCallCheck(this, Observer);

    _this = _super.call(this);

    if (typeof callback !== 'function') {
      throw new Error("observer callback must be a function");
    }

    _this.callback = callback;

    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    _this.arguments = args;
    _this.tags = new _tokenlist_js__WEBPACK_IMPORTED_MODULE_3__.TokenList();
    _this.queue = new _uniquequeue_js__WEBPACK_IMPORTED_MODULE_4__.UniqueQueue();
    return _this;
  }
  /**
   *
   * @param {string} tag
   * @returns {Observer}
   */


  _createClass(Observer, [{
    key: "addTag",
    value: function addTag(tag) {
      this.tags.add(tag);
      return this;
    }
    /**
     *
     * @param {string} tag
     * @returns {Observer}
     */

  }, {
    key: "removeTag",
    value: function removeTag(tag) {
      this.tags.remove(tag);
      return this;
    }
    /**
     *
     * @returns {Array}
     */

  }, {
    key: "getTags",
    value: function getTags() {
      return this.tags.entries();
    }
    /**
     *
     * @param {string} tag
     * @returns {boolean}
     */

  }, {
    key: "hasTag",
    value: function hasTag(tag) {
      return this.tags.contains(tag);
    }
    /**
     *
     * @param {object} subject
     * @returns {Promise}
     */

  }, {
    key: "update",
    value: function update(subject) {
      var self = this;
      return new Promise(function (resolve, reject) {
        if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(subject)) {
          reject("subject must be an object");
          return;
        }

        self.queue.add(subject);
        setTimeout(function () {
          try {
            // the queue and the settimeout ensure that an object is not 
            // informed of the same change more than once.
            if (self.queue.isEmpty()) {
              resolve();
              return;
            }

            var s = self.queue.poll();
            var result = self.callback.apply(s, self.arguments);

            if ((0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(result) && result instanceof Promise) {
              result.then(resolve).catch(reject);
              return;
            }

            resolve(result);
          } catch (e) {
            reject(e);
          }
        }, 0);
      });
    }
  }]);

  return Observer;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', Observer);


/***/ }),
/* 28 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "TokenList": function() { return /* binding */ TokenList; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }





/**
 * A tokenlist allows you to manage tokens (individual character strings such as css classes in an attribute string).
 *
 * The tokenlist offers various functions to manipulate values. For example, you can add, remove or replace a class in a CSS list.
 *
 * You can call the method via the monster namespace `new Monster.Types.TokenList()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.TokenList("myclass row")
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {TokenList} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/tokenlist.js';
 * new TokenList("myclass row")
 * </script>
 * ```
 *
 * This class implements the [iteration protocol](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols).
 *
 * ```
 * typeof new TokenList("myclass row")[Symbol.iterator]; 
 * // ↦ "function"
 * ```
 *
 * @since 1.2.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var TokenList = /*#__PURE__*/function (_Base, _Symbol$iterator) {
  _inherits(TokenList, _Base);

  var _super = _createSuper(TokenList);

  /**
   *
   * @param {array|string|iteratable} init
   */
  function TokenList(init) {
    var _this;

    _classCallCheck(this, TokenList);

    _this = _super.call(this);
    _this.tokens = new Set();

    if (typeof init !== "undefined") {
      _this.add(init);
    }

    return _this;
  }
  /**
   * Iterator protocol
   *
   * @returns {Symbol.iterator}
   */


  _createClass(TokenList, [{
    key: "getIterator",
    value: function getIterator() {
      return this[Symbol.iterator]();
    }
    /**
     * Iterator
     *
     * @returns {{next: ((function(): ({value: *, done: boolean}))|*)}}
     */

  }, {
    key: _Symbol$iterator,
    value: function value() {
      // Use a new index for each iterator. This makes multiple
      // iterations over the iterable safe for non-trivial cases,
      // such as use of break or nested looping over the same iterable.
      var index = 0;
      var entries = this.entries();
      return {
        next: function next() {
          if (index < entries.length) {
            return {
              value: entries === null || entries === void 0 ? void 0 : entries[index++],
              done: false
            };
          } else {
            return {
              done: true
            };
          }
        }
      };
    }
    /**
     * Returns true if it contains token, otherwise false
     *
     * ```
     * new TokenList("start middle end").contains('start')); // ↦ true
     * new TokenList("start middle end").contains('end')); // ↦ true
     * new TokenList("start middle end").contains('xyz')); // ↦ false
     * new TokenList("start middle end").contains(['end','start','middle'])); // ↦ true
     * new TokenList("start middle end").contains(['end','start','xyz'])); // ↦ false
     * ```
     *
     * @param {array|string|iteratable} value
     * @returns {boolean}
     */

  }, {
    key: "contains",
    value: function contains(value) {
      var _this2 = this;

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isString)(value)) {
        value = value.trim();
        var counter = 0;
        value.split(" ").forEach(function (token) {
          if (_this2.tokens.has(token.trim()) === false) return false;
          counter++;
        });
        return counter > 0 ? true : false;
      }

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isIterable)(value)) {
        var _counter = 0;

        var _iterator = _createForOfIteratorHelper(value),
            _step;

        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var token = _step.value;
            (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(token);
            if (this.tokens.has(token.trim()) === false) return false;
            _counter++;
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }

        return _counter > 0 ? true : false;
      }

      return false;
    }
    /**
     * add tokens
     *
     * ```
     * new TokenList().add("abc xyz").toString(); // ↦ "abc xyz"
     * new TokenList().add(["abc","xyz"]).toString(); // ↦ "abc xyz"
     * new TokenList().add(undefined); // ↦ add nothing
     * ```
     *
     * @param {array|string|iteratable} value
     * @returns {TokenList}
     * @throws {TypeError} unsupported value
     */

  }, {
    key: "add",
    value: function add(value) {
      var _this3 = this;

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isString)(value)) {
        value.split(" ").forEach(function (token) {
          _this3.tokens.add(token.trim());
        });
      } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isIterable)(value)) {
        var _iterator2 = _createForOfIteratorHelper(value),
            _step2;

        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var token = _step2.value;
            (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(token);
            this.tokens.add(token.trim());
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      } else if (typeof value !== "undefined") {
        throw new TypeError("unsupported value");
      }

      return this;
    }
    /**
     * remove all tokens
     *
     * @returns {TokenList}
     */

  }, {
    key: "clear",
    value: function clear() {
      this.tokens.clear();
      return this;
    }
    /**
     * Removes token
     *
     * ```
     * new TokenList("abc xyz").remove("xyz").toString(); // ↦ "abc"
     * new TokenList("abc xyz").remove(["xyz"]).toString(); // ↦ "abc"
     * new TokenList("abc xyz").remove(undefined); // ↦ remove nothing
     * ```
     *
     * @param {array|string|iteratable} value
     * @returns {TokenList}
     * @throws {TypeError} unsupported value
     */

  }, {
    key: "remove",
    value: function remove(value) {
      var _this4 = this;

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isString)(value)) {
        value.split(" ").forEach(function (token) {
          _this4.tokens.delete(token.trim());
        });
      } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isIterable)(value)) {
        var _iterator3 = _createForOfIteratorHelper(value),
            _step3;

        try {
          for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
            var token = _step3.value;
            (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(token);
            this.tokens.delete(token.trim());
          }
        } catch (err) {
          _iterator3.e(err);
        } finally {
          _iterator3.f();
        }
      } else if (typeof value !== "undefined") {
        throw new TypeError("unsupported value", "types/tokenlist.js");
      }

      return this;
    }
    /**
     * this method replaces a token with a new token.
     *
     * if the passed token exists, it is replaced with newToken and TokenList is returned.
     * if the token does not exist, newToken is not set and TokenList is returned.
     *
     * @param {string} token
     * @param {string} newToken
     * @returns {TokenList}
     */

  }, {
    key: "replace",
    value: function replace(token, newToken) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(token);
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(newToken);

      if (!this.contains(token)) {
        return this;
      }

      var a = Array.from(this.tokens);
      var i = a.indexOf(token);
      if (i === -1) return this;
      a.splice(i, 1, newToken);
      this.tokens = new Set();
      this.add(a);
      return this;
    }
    /**
     * Removes token from string. If token doesn't exist it's added.
     *
     * ```
     * new TokenList("abc def ghi").toggle("def xyz").toString(); // ↦ "abc ghi xyz"
     * new TokenList("abc def ghi").toggle(["abc","xyz"]).toString(); // ↦ "def ghi xyz"
     * new TokenList().toggle(undefined); // ↦ nothing
     * ```
     *
     * @param {array|string|iteratable} value
     * @returns {boolean}
     * @throws {TypeError} unsupported value
     */

  }, {
    key: "toggle",
    value: function toggle(value) {
      var _this5 = this;

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isString)(value)) {
        value.split(" ").forEach(function (token) {
          toggleValue.call(_this5, token);
        });
      } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isIterable)(value)) {
        var _iterator4 = _createForOfIteratorHelper(value),
            _step4;

        try {
          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
            var token = _step4.value;
            toggleValue.call(this, token);
          }
        } catch (err) {
          _iterator4.e(err);
        } finally {
          _iterator4.f();
        }
      } else if (typeof value !== "undefined") {
        throw new TypeError("unsupported value", "types/tokenlist.js");
      }

      return this;
    }
    /**
     * returns an array with all tokens
     *
     * @returns {array}
     */

  }, {
    key: "entries",
    value: function entries() {
      return Array.from(this.tokens);
    }
    /**
     * executes the provided function with each value of the set
     *
     * @param {function} callback
     * @returns {TokenList}
     */

  }, {
    key: "forEach",
    value: function forEach(callback) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateFunction)(callback);
      this.tokens.forEach(callback);
      return this;
    }
    /**
     * returns the individual tokens separated by a blank character
     *
     * @returns {string}
     */

  }, {
    key: "toString",
    value: function toString() {
      return this.entries().join(' ');
    }
  }]);

  return TokenList;
}(_base_js__WEBPACK_IMPORTED_MODULE_3__.Base, Symbol.iterator);
/**
 * @private
 * @param token
 * @returns {toggleValue}
 * @throws {Error} must be called with TokenList.call
 */


function toggleValue(token) {
  if (!(this instanceof TokenList)) throw Error("must be called with TokenList.call");
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(token);
  token = token.trim();

  if (this.contains(token)) {
    this.remove(token);
    return this;
  }

  this.add(token);
  return this;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', TokenList);


/***/ }),
/* 29 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "UniqueQueue": function() { return /* binding */ UniqueQueue; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _queue_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(30);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }




/**
 * You can call the method via the monster namespace `new Monster.Types.Queue()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.UniqueQueue()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {UniqueQueue} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/uniquequeue.js';
 * new UniqueQueue()
 * </script>
 * ```
 *
 * @since 1.4.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @summary A queue for unique values
 */

var UniqueQueue = /*#__PURE__*/function (_Queue) {
  _inherits(UniqueQueue, _Queue);

  var _super = _createSuper(UniqueQueue);

  /**
   *
   */
  function UniqueQueue() {
    var _this;

    _classCallCheck(this, UniqueQueue);

    _this = _super.call(this);
    _this.unique = new WeakSet();
    return _this;
  }
  /**
   * Add a new element to the end of the queue.
   *
   * @param {object} value
   * @returns {Queue}
   * @throws {TypeError} value is not a object
   */


  _createClass(UniqueQueue, [{
    key: "add",
    value: function add(value) {
      (0,_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateObject)(value);

      if (!this.unique.has(value)) {
        this.unique.add(value);

        _get(_getPrototypeOf(UniqueQueue.prototype), "add", this).call(this, value);
      }

      return this;
    }
    /**
     * remove all entries
     *
     * @returns {Queue}
     */

  }, {
    key: "clear",
    value: function clear() {
      _get(_getPrototypeOf(UniqueQueue.prototype), "clear", this).call(this);

      this.unique = new WeakSet();
      return this;
    }
    /**
     * Remove the element at the front of the queue
     * If the queue is empty, return undefined.
     *
     * @return {object}
     */

  }, {
    key: "poll",
    value: function poll() {
      if (this.isEmpty()) {
        return undefined;
      }

      var value = this.data.shift();
      this.unique.delete(value);
      return value;
    }
  }]);

  return UniqueQueue;
}(_queue_js__WEBPACK_IMPORTED_MODULE_1__.Queue);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', UniqueQueue);


/***/ }),
/* 30 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Queue": function() { return /* binding */ Queue; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * You can create the instance via the monster namespace `new Monster.Types.Queue()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.Queue()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Queue} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/queue.js';
 * new Queue()
 * </script>
 * ```
 *
 * @example
 *
 * import {Queue} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/queue.js';
 *
 * const queue = new Queue;
 *
 * queue.add(2);
 * queue.add(true);
 * queue.add("Hello");
 * queue.add(4.5);
 *
 * console.log(queue.poll());
 * // ↦ 2
 * console.log(queue.poll());
 * // ↦ true
 * console.log(queue.poll());
 * // ↦ "Hello"
 * console.log(queue.poll());
 * // ↦ 4.5
 * console.log(queue.poll());
 * // ↦ undefined
 *
 *
 * @since 1.4.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @summary A Queue (Fifo)
 */

var Queue = /*#__PURE__*/function (_Base) {
  _inherits(Queue, _Base);

  var _super = _createSuper(Queue);

  /**
   *
   */
  function Queue() {
    var _this;

    _classCallCheck(this, Queue);

    _this = _super.call(this);
    _this.data = [];
    return _this;
  }
  /**
   * @return {boolean}
   */


  _createClass(Queue, [{
    key: "isEmpty",
    value: function isEmpty() {
      return this.data.length === 0;
    }
    /**
     * Read the element at the front of the queue without removing it.
     *
     * @return {*}
     */

  }, {
    key: "peek",
    value: function peek() {
      if (this.isEmpty()) {
        return undefined;
      }

      return this.data[0];
    }
    /**
     * Add a new element to the end of the queue.
     *
     * @param {*} value
     * @returns {Queue}
     */

  }, {
    key: "add",
    value: function add(value) {
      this.data.push(value);
      return this;
    }
    /**
     * remove all entries
     *
     * @returns {Queue}
     */

  }, {
    key: "clear",
    value: function clear() {
      this.data = [];
      return this;
    }
    /**
     * Remove the element at the front of the queue
     * If the queue is empty, return undefined.
     *
     * @return {*}
     */

  }, {
    key: "poll",
    value: function poll() {
      if (this.isEmpty()) {
        return undefined;
      }

      return this.data.shift();
    }
  }]);

  return Queue;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', Queue);


/***/ }),
/* 31 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "ObserverList": function() { return /* binding */ ObserverList; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _observer_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(27);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }





/**
 * With the help of the ObserverList class, observer can be managed.
 *
 * You can call the method via the monster namespace `new Monster.Types.ObserverList()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Types.ObserverList())
 * console.log(new Monster.Types.ObserverList())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {ObserverList} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/observerlist.js';
 * console.log(ObserverList())
 * console.log(ObserverList())
 * </script>
 * ```
 *
 * @since 1.0.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var ObserverList = /*#__PURE__*/function (_Base) {
  _inherits(ObserverList, _Base);

  var _super = _createSuper(ObserverList);

  /**
   *
   */
  function ObserverList() {
    var _this;

    _classCallCheck(this, ObserverList);

    _this = _super.call(this);
    _this.observers = [];
    return _this;
  }
  /**
   *
   * @param {Observer} observer
   * @return {ObserverList}
   * @throws {TypeError} value is not an instance of Observer
   */


  _createClass(ObserverList, [{
    key: "attach",
    value: function attach(observer) {
      (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(observer, _observer_js__WEBPACK_IMPORTED_MODULE_2__.Observer);
      this.observers.push(observer);
      return this;
    }
  }, {
    key: "detach",
    value:
    /**
     *
     * @param {Observer} observer
     * @return {ObserverList}
     * @throws {TypeError} value is not an instance of Observer
     */
    function detach(observer) {
      (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(observer, _observer_js__WEBPACK_IMPORTED_MODULE_2__.Observer);
      var i = 0,
          l = this.observers.length;

      for (; i < l; i++) {
        if (this.observers[i] === observer) {
          this.observers.splice(i, 1);
        }
      }

      return this;
    }
  }, {
    key: "contains",
    value:
    /**
     *
     * @param {Observer} observer
     * @return {boolean}
     * @throws {TypeError} value is not an instance of Observer
     */
    function contains(observer) {
      (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(observer, _observer_js__WEBPACK_IMPORTED_MODULE_2__.Observer);
      var i = 0,
          l = this.observers.length;

      for (; i < l; i++) {
        if (this.observers[i] === observer) {
          return true;
        }
      }

      return false;
    }
  }, {
    key: "notify",
    value:
    /**
     *
     * @param subject
     * @return {Promise}
     */
    function notify(subject) {
      var pomises = [];
      var i = 0,
          l = this.observers.length;

      for (; i < l; i++) {
        pomises.push(this.observers[i].update(subject));
      }

      return Promise.all(pomises);
    }
  }]);

  return ObserverList;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', ObserverList);


/***/ }),
/* 32 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "addToObjectLink": function() { return /* binding */ addToObjectLink; },
/* harmony export */   "removeObjectLink": function() { return /* binding */ removeObjectLink; },
/* harmony export */   "hasObjectLink": function() { return /* binding */ hasObjectLink; },
/* harmony export */   "findClosestByAttribute": function() { return /* binding */ findClosestByAttribute; },
/* harmony export */   "clearAttributeTokens": function() { return /* binding */ clearAttributeTokens; },
/* harmony export */   "replaceAttributeToken": function() { return /* binding */ replaceAttributeToken; },
/* harmony export */   "containsAttributeToken": function() { return /* binding */ containsAttributeToken; },
/* harmony export */   "removeAttributeToken": function() { return /* binding */ removeAttributeToken; },
/* harmony export */   "addAttributeToken": function() { return /* binding */ addAttributeToken; },
/* harmony export */   "toggleAttributeToken": function() { return /* binding */ toggleAttributeToken; },
/* harmony export */   "getLinkedObjects": function() { return /* binding */ getLinkedObjects; },
/* harmony export */   "findClosestObjectLink": function() { return /* binding */ findClosestObjectLink; },
/* harmony export */   "findClosestByClass": function() { return /* binding */ findClosestByClass; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(16);
/* harmony import */ var _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(28);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(33);

/**
 * @author schukai GmbH
 */






/**
 * Get the closest object link of a node
 *
 * if a node is specified without a object link, a recursive search upwards is performed until the corresponding
 * object link is found, or undefined is returned.
 *
 * you can call the method via the monster namespace `Monster.DOM.getUpdaterFromNode()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.DOM.findClosestObjectLink())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getUpdaterFromNode} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/updater.js';
 * console.log(findClosestObjectLink())
 * </script>
 * ```
 *
 * @param {HTMLElement} element
 * @return {HTMLElement|undefined}
 * @since 1.10.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {TypeError} value is not an instance of HTMLElement
 */

function findClosestObjectLink(element) {
  return findClosestByAttribute(element, _constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_OBJECTLINK);
}
/**
 * You can call the method via the monster namespace `new Monster.DOM.addToObjectLink()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.addToObjectLink();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {addToObjectLink} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * addToObjectLink();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {Symbol} symbol
 * @param {Object} object
 * @return {boolean}
 */


function addToObjectLink(element, symbol, object) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateSymbol)(symbol);

  if ((element === null || element === void 0 ? void 0 : element[symbol]) === undefined) {
    element[symbol] = new Set();
  }

  addAttributeToken(element, _constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_OBJECTLINK, symbol.toString());
  element[symbol].add(object);
  return element;
}
/**
 * You can call the method via the monster namespace `new Monster.DOM.removeObjectLink()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.removeObjectLink();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {removeObjectLink} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * removeObjectLink();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {Symbol} symbol
 * @return {boolean}
 */


function removeObjectLink(element, symbol) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateSymbol)(symbol);

  if ((element === null || element === void 0 ? void 0 : element[symbol]) === undefined) {
    return element;
  }

  removeAttributeToken(element, _constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_OBJECTLINK, symbol.toString());
  delete element[symbol];
  return element;
}
/**
 * You can call the method via the monster namespace `new Monster.DOM.hasObjectLink()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.hasObjectLink();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {hasObjectLink} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * hasObjectLink();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {Symbol} symbol
 * @return {boolean}
 */


function hasObjectLink(element, symbol) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateSymbol)(symbol);

  if ((element === null || element === void 0 ? void 0 : element[symbol]) === undefined) {
    return false;
  }

  return containsAttributeToken(element, _constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_OBJECTLINK, symbol.toString());
}
/**
 * The ObjectLink can be used to attach objects to HTMLElements. The elements are kept in a set under a unique
 * symbol and can be read via an iterator {@see {@link getLinkedObjects}}.
 *
 * In addition, elements with an objectLink receive the attribute `data-monster-objectlink`.
 *
 * With the method  {@see {@link addToObjectLink}} the objects can be added.
 *
 * You can call the method via the monster namespace `new Monster.DOM.getLinkedObjects()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.getLinkedObjects();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getLinkedObjects} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * getLinkedObjects();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {Symbol} symbol
 * @return {Iterator}
 * @throws {Error} there is no object link for symbol
 */


function getLinkedObjects(element, symbol) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateSymbol)(symbol);

  if ((element === null || element === void 0 ? void 0 : element[symbol]) === undefined) {
    throw new Error('there is no object link for ' + symbol.toString());
  }

  return element === null || element === void 0 ? void 0 : element[symbol][Symbol.iterator]();
}
/**
 * With this method tokens in an attribute can be switched on or off. For example, classes can be switched on and off in the elements class attribute.
 *
 * Tokens are always separated by a space.
 *
 * You can call the method via the monster namespace `new Monster.DOM.toggleAttributeToken()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.toggleAttributeToken();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {toggleAttributeToken} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * toggleAttributeToken();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @param {string} token
 * @return {HTMLElement}
 */


function toggleAttributeToken(element, key, token) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(token);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);

  if (!element.hasAttribute(key)) {
    element.setAttribute(key, token);
    return element;
  }

  element.setAttribute(key, new _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_2__.TokenList(element.getAttribute(key)).toggle(token).toString());
  return element;
}
/**
 * This method can be used to add a token to an attribute. Tokens are always separated by a space.
 *
 * You can call the method via the monster namespace `new Monster.DOM.addAttributeToken()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.addAttributeToken();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {addAttributeToken} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * addAttributeToken();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @param {string} token
 * @return {HTMLElement}
 */


function addAttributeToken(element, key, token) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(token);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);

  if (!element.hasAttribute(key)) {
    element.setAttribute(key, token);
    return element;
  }

  element.setAttribute(key, new _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_2__.TokenList(element.getAttribute(key)).add(token).toString());
  return element;
}
/**
 * This function can be used to remove tokens from an attribute.
 *
 * Tokens are always separated by a space.
 *
 * You can call the method via the monster namespace `new Monster.DOM.removeAttributeToken()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.removeAttributeToken();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {removeAttributeToken} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * removeAttributeToken();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @param {string} token
 * @return {HTMLElement}
 */


function removeAttributeToken(element, key, token) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(token);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);

  if (!element.hasAttribute(key)) {
    return element;
  }

  element.setAttribute(key, new _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_2__.TokenList(element.getAttribute(key)).remove(token).toString());
  return element;
}
/**
 * This method can be used to determine whether an attribute has a token.
 *
 * Tokens are always separated by a space.
 *
 * You can call the method via the monster namespace `new Monster.DOM.containsAttributeToken()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.containsAttributeToken();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {containsAttributeToken} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * containsAttributeToken();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @param {string} token
 * @return {boolean}
 */


function containsAttributeToken(element, key, token) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(token);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);

  if (!element.hasAttribute(key)) {
    return false;
  }

  return new _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_2__.TokenList(element.getAttribute(key)).contains(token);
}
/**
 * Tokens are always separated by a space.
 *
 * You can call the method via the monster namespace `new Monster.DOM.replaceAttributeToken()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.replaceAttributeToken();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {replaceAttributeToken} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * replaceAttributeToken();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @param {string} from
 * @param {string} to
 * @return {HTMLElement}
 */


function replaceAttributeToken(element, key, from, to) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(from);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(to);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);

  if (!element.hasAttribute(key)) {
    return element;
  }

  element.setAttribute(key, new _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_2__.TokenList(element.getAttribute(key)).replace(from, to).toString());
  return element;
}
/**
 * Tokens are always separated by a space.
 *
 * You can call the method via the monster namespace `new Monster.DOM.clearAttributeTokens()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.clearAttributeTokens();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {clearAttributeTokens} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * clearAttributeTokens();
 * </script>
 * ```
 *
 * @since 1.9.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @return {HTMLElement}
 */


function clearAttributeTokens(element, key) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, HTMLElement);
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);

  if (!element.hasAttribute(key)) {
    return element;
  }

  element.setAttribute(key, "");
  return element;
}
/**
 * This function searches, starting from an `HTMLElemement`, for the next element that has a certain attribute.
 *
 * ```html
 * <div data-my-attribute="2" id="2">
 *     <div id="1"></div>
 * </div>
 * ```
 *
 * ```javascript
 * // if no value is specified (undefined), then only the attribute is checked.
 * findClosestByAttribute(document.getElementById('1'),'data-my-attribute'); // ↦ node with id 2
 * findClosestByAttribute(document.getElementById('2'),'data-my-attribute'); // ↦ node with id 2
 *
 * // if a value is specified, for example an empty string, then the name and the value are checked.
 * findClosestByAttribute(document.getElementById('1'),'data-my-attribute', '');  // ↦ undefined
 * findClosestByAttribute(document.getElementById('1'),'data-my-attribute', '2'); // ↦ node with id 2
 * ```
 *
 * You can call the method via the monster namespace `new Monster.DOM.findClosestByAttribute()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.findClosestByAttribute();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {findClosestByAttribute} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * findClosestByAttribute();
 * </script>
 * ```
 *
 * @since 1.14.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} key
 * @param {string|undefined} value
 * @return {HTMLElement|undefined}
 * @summary find closest node
 */


function findClosestByAttribute(element, key, value) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, (0,_types_global_js__WEBPACK_IMPORTED_MODULE_1__.getGlobalFunction)('HTMLElement'));

  if (element.hasAttribute(key)) {
    if (value === undefined) {
      return element;
    }

    if (element.getAttribute(key) === value) {
      return element;
    }
  }

  var selector = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key);
  if (value !== undefined) selector += "=" + (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(value);
  var result = element.closest('[' + selector + ']');

  if (result instanceof HTMLElement) {
    return result;
  }

  return undefined;
}
/**
 * This function searches, starting from an `HTMLElemement`, for the next element that has a certain attribute.
 *
 * ```html
 * <div class="myclass" id="2">
 *     <div id="1"></div>
 * </div>
 * ```
 *
 * ```javascript
 * // if no value is specified (undefined), then only the attribute is checked.
 * findClosestByClass(document.getElementById('1'),'myclass'); // ↦ node with id 2
 * findClosestByClass(document.getElementById('2'),'myclass'); // ↦ node with id 2
 * ```
 *
 * You can call the method via the monster namespace `new Monster.DOM.findClosestByClass()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.findClosestByClass();
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {findClosestByClass} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/attributes.js';
 * findClosestByClass();
 * </script>
 * ```
 *
 * @since 1.27.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @param {HTMLElement} element
 * @param {string} className
 * @return {HTMLElement|undefined}
 * @summary find closest node
 */


function findClosestByClass(element, className) {
  var _element$classList;

  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(element, (0,_types_global_js__WEBPACK_IMPORTED_MODULE_1__.getGlobalFunction)('HTMLElement'));

  if (element !== null && element !== void 0 && (_element$classList = element.classList) !== null && _element$classList !== void 0 && _element$classList.contains((0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(className))) {
    return element;
  }

  var result = element.closest('.' + className);

  if (result instanceof HTMLElement) {
    return result;
  }

  return undefined;
} // exports


(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.DOM', findClosestByClass, getLinkedObjects, addToObjectLink, removeObjectLink, findClosestByAttribute, hasObjectLink, clearAttributeTokens, replaceAttributeToken, containsAttributeToken, removeAttributeToken, addAttributeToken, toggleAttributeToken);


/***/ }),
/* 33 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "ATTRIBUTE_HIDDEN": function() { return /* binding */ ATTRIBUTE_HIDDEN; },
/* harmony export */   "ATTRIBUTE_EXPORTPARTS": function() { return /* binding */ ATTRIBUTE_EXPORTPARTS; },
/* harmony export */   "ATTRIBUTE_ENTERKEYHINT": function() { return /* binding */ ATTRIBUTE_ENTERKEYHINT; },
/* harmony export */   "ATTRIBUTE_DRAGGABLE": function() { return /* binding */ ATTRIBUTE_DRAGGABLE; },
/* harmony export */   "ATTRIBUTE_DIR": function() { return /* binding */ ATTRIBUTE_DIR; },
/* harmony export */   "ATTRIBUTE_CONTENTEDITABLE": function() { return /* binding */ ATTRIBUTE_CONTENTEDITABLE; },
/* harmony export */   "ATTRIBUTE_AUTOFOCUS": function() { return /* binding */ ATTRIBUTE_AUTOFOCUS; },
/* harmony export */   "ATTRIBUTE_AUTOCAPITALIZE": function() { return /* binding */ ATTRIBUTE_AUTOCAPITALIZE; },
/* harmony export */   "ATTRIBUTE_ACCESSKEY": function() { return /* binding */ ATTRIBUTE_ACCESSKEY; },
/* harmony export */   "TAG_SCRIPT": function() { return /* binding */ TAG_SCRIPT; },
/* harmony export */   "TAG_LINK": function() { return /* binding */ TAG_LINK; },
/* harmony export */   "ATTRIBUTE_INPUTMODE": function() { return /* binding */ ATTRIBUTE_INPUTMODE; },
/* harmony export */   "ATTRIBUTE_IS": function() { return /* binding */ ATTRIBUTE_IS; },
/* harmony export */   "ATTRIBUTE_ITEMPROP": function() { return /* binding */ ATTRIBUTE_ITEMPROP; },
/* harmony export */   "ATTRIBUTE_ITEMID": function() { return /* binding */ ATTRIBUTE_ITEMID; },
/* harmony export */   "ATTRIBUTE_ITEMREF": function() { return /* binding */ ATTRIBUTE_ITEMREF; },
/* harmony export */   "ATTRIBUTE_ITEMSCOPE": function() { return /* binding */ ATTRIBUTE_ITEMSCOPE; },
/* harmony export */   "TAG_STYLE": function() { return /* binding */ TAG_STYLE; },
/* harmony export */   "ATTRIBUTE_ITEMTYPE": function() { return /* binding */ ATTRIBUTE_ITEMTYPE; },
/* harmony export */   "ATTRIBUTE_HREF": function() { return /* binding */ ATTRIBUTE_HREF; },
/* harmony export */   "ATTRIBUTE_LANG": function() { return /* binding */ ATTRIBUTE_LANG; },
/* harmony export */   "ATTRIBUTE_PART": function() { return /* binding */ ATTRIBUTE_PART; },
/* harmony export */   "ATTRIBUTE_SLOT": function() { return /* binding */ ATTRIBUTE_SLOT; },
/* harmony export */   "ATTRIBUTE_SPELLCHECK": function() { return /* binding */ ATTRIBUTE_SPELLCHECK; },
/* harmony export */   "ATTRIBUTE_SRC": function() { return /* binding */ ATTRIBUTE_SRC; },
/* harmony export */   "ATTRIBUTE_TABINDEX": function() { return /* binding */ ATTRIBUTE_TABINDEX; },
/* harmony export */   "ATTRIBUTE_TRANSLATE": function() { return /* binding */ ATTRIBUTE_TRANSLATE; },
/* harmony export */   "ATTRIBUTE_NONCE": function() { return /* binding */ ATTRIBUTE_NONCE; },
/* harmony export */   "ATTRIBUTE_TYPE": function() { return /* binding */ ATTRIBUTE_TYPE; },
/* harmony export */   "ATTRIBUTE_TITLE": function() { return /* binding */ ATTRIBUTE_TITLE; },
/* harmony export */   "ATTRIBUTE_CLASS": function() { return /* binding */ ATTRIBUTE_CLASS; },
/* harmony export */   "ATTRIBUTE_ID": function() { return /* binding */ ATTRIBUTE_ID; },
/* harmony export */   "ATTRIBUTE_PREFIX": function() { return /* binding */ ATTRIBUTE_PREFIX; },
/* harmony export */   "ATTRIBUTE_OPTIONS": function() { return /* binding */ ATTRIBUTE_OPTIONS; },
/* harmony export */   "DEFAULT_THEME": function() { return /* binding */ DEFAULT_THEME; },
/* harmony export */   "ATTRIBUTE_THEME_PREFIX": function() { return /* binding */ ATTRIBUTE_THEME_PREFIX; },
/* harmony export */   "ATTRIBUTE_ROLE": function() { return /* binding */ ATTRIBUTE_ROLE; },
/* harmony export */   "ATTRIBUTE_THEME_NAME": function() { return /* binding */ ATTRIBUTE_THEME_NAME; },
/* harmony export */   "ATTRIBUTE_UPDATER_ATTRIBUTES": function() { return /* binding */ ATTRIBUTE_UPDATER_ATTRIBUTES; },
/* harmony export */   "ATTRIBUTE_UPDATER_REPLACE": function() { return /* binding */ ATTRIBUTE_UPDATER_REPLACE; },
/* harmony export */   "ATTRIBUTE_UPDATER_INSERT": function() { return /* binding */ ATTRIBUTE_UPDATER_INSERT; },
/* harmony export */   "ATTRIBUTE_UPDATER_INSERT_REFERENCE": function() { return /* binding */ ATTRIBUTE_UPDATER_INSERT_REFERENCE; },
/* harmony export */   "ATTRIBUTE_UPDATER_REMOVE": function() { return /* binding */ ATTRIBUTE_UPDATER_REMOVE; },
/* harmony export */   "ATTRIBUTE_UPDATER_BIND": function() { return /* binding */ ATTRIBUTE_UPDATER_BIND; },
/* harmony export */   "ATTRIBUTE_OBJECTLINK": function() { return /* binding */ ATTRIBUTE_OBJECTLINK; },
/* harmony export */   "ATTRIBUTE_DISABLED": function() { return /* binding */ ATTRIBUTE_DISABLED; },
/* harmony export */   "ATTRIBUTE_ERRORMESSAGE": function() { return /* binding */ ATTRIBUTE_ERRORMESSAGE; },
/* harmony export */   "ATTRIBUTE_VALUE": function() { return /* binding */ ATTRIBUTE_VALUE; },
/* harmony export */   "objectUpdaterLinkSymbol": function() { return /* binding */ objectUpdaterLinkSymbol; },
/* harmony export */   "ATTRIBUTE_TEMPLATE_PREFIX": function() { return /* binding */ ATTRIBUTE_TEMPLATE_PREFIX; },
/* harmony export */   "ATTRIBUTE_UPDATER_SELECT_THIS": function() { return /* binding */ ATTRIBUTE_UPDATER_SELECT_THIS; },
/* harmony export */   "ATTRIBUTE_OPTIONS_SELECTOR": function() { return /* binding */ ATTRIBUTE_OPTIONS_SELECTOR; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);



/**
 * @author schukai GmbH
 */

/**
 * default theme
 * @memberOf Monster.DOM
 * @type {string}
 */

var DEFAULT_THEME = 'monster';
/**
 * @memberOf Monster.DOM
 * @since 1.8.0
 * @type {string}
 */

var ATTRIBUTE_PREFIX = 'data-monster-';
/**
 * This is the name of the attribute to pass options to a control
 *
 * @memberOf Monster.DOM
 * @since 1.8.0
 * @type {string}
 */

var ATTRIBUTE_OPTIONS = ATTRIBUTE_PREFIX + 'options';
/**
 * This is the name of the attribute to pass options to a control
 *
 * @memberOf Monster.DOM
 * @since 1.30.0
 * @type {string}
 */

var ATTRIBUTE_OPTIONS_SELECTOR = ATTRIBUTE_PREFIX + 'options-selector';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */

var ATTRIBUTE_THEME_PREFIX = ATTRIBUTE_PREFIX + 'theme-';
/**
 * @memberOf Monster.DOM
 * @type {string}
 */

var ATTRIBUTE_THEME_NAME = ATTRIBUTE_THEME_PREFIX + 'name';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */

var ATTRIBUTE_UPDATER_ATTRIBUTES = ATTRIBUTE_PREFIX + 'attributes';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.27.1
 */

var ATTRIBUTE_UPDATER_SELECT_THIS = ATTRIBUTE_PREFIX + 'select-this';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */

var ATTRIBUTE_UPDATER_REPLACE = ATTRIBUTE_PREFIX + 'replace';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */

var ATTRIBUTE_UPDATER_INSERT = ATTRIBUTE_PREFIX + 'insert';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */

var ATTRIBUTE_UPDATER_INSERT_REFERENCE = ATTRIBUTE_PREFIX + 'insert-reference';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.8.0
 */

var ATTRIBUTE_UPDATER_REMOVE = ATTRIBUTE_PREFIX + 'remove';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.9.0
 */

var ATTRIBUTE_UPDATER_BIND = ATTRIBUTE_PREFIX + 'bind';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.27.0
 */

var ATTRIBUTE_TEMPLATE_PREFIX = ATTRIBUTE_PREFIX + 'template-prefix';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.14.0
 */

var ATTRIBUTE_ROLE = ATTRIBUTE_PREFIX + 'role';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.24.0
 */

var ATTRIBUTE_DISABLED = 'disabled';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.24.0
 */

var ATTRIBUTE_VALUE = 'value';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.9.0
 */

var ATTRIBUTE_OBJECTLINK = ATTRIBUTE_PREFIX + 'objectlink';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.24.0
 */

var ATTRIBUTE_ERRORMESSAGE = ATTRIBUTE_PREFIX + 'error';
/**
 * @memberOf Monster.DOM
 * @type {symbol}
 * @since 1.24.0
 */

var objectUpdaterLinkSymbol = Symbol('monsterUpdater');
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var TAG_SCRIPT = 'script';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var TAG_STYLE = 'style';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var TAG_LINK = 'link';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ID = 'id';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_CLASS = 'class';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_TITLE = 'title';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_SRC = 'src';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_HREF = 'href';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_TYPE = 'type';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_NONCE = 'nonce';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_TRANSLATE = 'translate';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_TABINDEX = 'tabindex';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_SPELLCHECK = 'spellcheck';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_SLOT = 'slot';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_PART = 'part';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_LANG = 'lang';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ITEMTYPE = 'itemtype';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ITEMSCOPE = 'itemscope';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ITEMREF = 'itemref';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ITEMID = 'itemid';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ITEMPROP = 'itemprop';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_IS = 'is';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_INPUTMODE = 'inputmode';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ACCESSKEY = 'accesskey';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_AUTOCAPITALIZE = 'autocapitalize';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_AUTOFOCUS = 'autofocus';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_CONTENTEDITABLE = 'contenteditable';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_DIR = 'dir';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_DRAGGABLE = 'draggable';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_ENTERKEYHINT = 'enterkeyhint';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_EXPORTPARTS = 'exportparts';
/**
 * @memberOf Monster.DOM
 * @type {string}
 * @since 1.25.0
 */

var ATTRIBUTE_HIDDEN = 'hidden';


/***/ }),
/* 34 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_1__.Monster; },
/* harmony export */   "CustomControl": function() { return /* binding */ CustomControl; }
/* harmony export */ });
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(21);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2);
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(33);
/* harmony import */ var _customelement_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(35);


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }


/**
 * @author schukai GmbH
 */




/**
 * @private
 * @type {symbol}
 */

var attachedInternalSymbol = Symbol('attachedInternal');
/**
 * To define a new HTML control we need the power of CustomElement
 *
 * IMPORTANT: after defining a `CustomElement`, the `registerCustomElement` method must be called
 * with the new class name. only then will the tag defined via the `getTag` method be made known to the DOM.
 *
 * <img src="./images/customcontrol-class.png">
 *
 * This control uses `attachInternals()` to integrate the control into a form.
 * If the target environment does not support this method, the [polyfill](https://www.npmjs.com/package/element-internals-polyfill ) can be used.
 *
 * You can create the object via the function `document.createElement()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * document.createElement('monster-')
 * </script>
 * ```
 *
 * @startuml customcontrol-class.png
 * skinparam monochrome true
 * skinparam shadowing false
 * HTMLElement <|-- CustomElement
 * CustomElement <|-- CustomControl
 * @enduml
 *
 * @summary A base class for customcontrols based on CustomElement
 * @see {@link https://www.npmjs.com/package/element-internals-polyfill}
 * @see {@link https://github.com/WICG/webcomponents}
 * @see {@link https://html.spec.whatwg.org/multipage/custom-elements.html#custom-elements}
 * @since 1.14.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 */

var CustomControl = /*#__PURE__*/function (_CustomElement) {
  _inherits(CustomControl, _CustomElement);

  var _super = _createSuper(CustomControl);

  /**
   * IMPORTANT: CustomControls instances are not created via the constructor, but either via a tag in the HTML or via <code>document.createElement()</code>.
   *
   * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
   * @summary create new Instance
   */
  function CustomControl() {
    var _this;

    _classCallCheck(this, CustomControl);

    _this = _super.call(this);

    if (typeof _this['attachInternals'] === 'function') {
      /**
       * currently only supported by chrome
       * @property {Object}
       * @private
       */
      _this[attachedInternalSymbol] = _this.attachInternals();
    }

    initObserver.call(_assertThisInitialized(_this));
    return _this;
  }
  /**
   * This method determines which attributes are to be monitored by `attributeChangedCallback()`.
   *
   * @return {string[]}
   * @since 1.15.0
   */


  _createClass(CustomControl, [{
    key: "defaults",
    get:
    /**
     * Derived classes can override and extend this method as follows.
     *
     * ```
     * get defaults() {
     *    return extends{}, super.defaults, {
     *        myValue:true
     *    });
     * }
     * ```
     *
     * @see {@link https://html.spec.whatwg.org/multipage/custom-elements.html#custom-elements-face-example}
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals}
     * @return {object}
     * @since 1.14.0
     */
    function get() {
      return (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_0__.extend)({}, _get(_getPrototypeOf(CustomControl.prototype), "defaults", this));
    }
    /**
     * Must be overridden by a derived class and return the value of the control.
     *
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @since 1.14.0
     * @throws {Error} the value getter must be overwritten by the derived class
     */

  }, {
    key: "value",
    get: function get() {
      throw Error('the value getter must be overwritten by the derived class');
    }
    /**
     * Must be overridden by a derived class and return the value of the control.
     *
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @param {*} value
     * @since 1.14.0
     * @throws {Error} the value setter must be overwritten by the derived class
     */
    ,
    set: function set(value) {
      throw Error('the value setter must be overwritten by the derived class');
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {NodeList}
     * @since 1.14.0
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/labels}
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "labels",
    get: function get() {
      var _getInternal$call;

      return (_getInternal$call = getInternal.call(this)) === null || _getInternal$call === void 0 ? void 0 : _getInternal$call.labels;
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {string|null}
     */

  }, {
    key: "name",
    get: function get() {
      return this.getAttribute('name');
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {string}
     */

  }, {
    key: "type",
    get: function get() {
      return this.constructor.getTag();
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {ValidityState}
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/ValidityState}
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/validity}
     */

  }, {
    key: "validity",
    get: function get() {
      var _getInternal$call2;

      return (_getInternal$call2 = getInternal.call(this)) === null || _getInternal$call2 === void 0 ? void 0 : _getInternal$call2.validity;
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {string}
     * @since 1.14.0
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/validationMessage
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "validationMessage",
    get: function get() {
      var _getInternal$call3;

      return (_getInternal$call3 = getInternal.call(this)) === null || _getInternal$call3 === void 0 ? void 0 : _getInternal$call3.validationMessage;
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {boolean}
     * @since 1.14.0
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/willValidate
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "willValidate",
    get: function get() {
      var _getInternal$call4;

      return (_getInternal$call4 = getInternal.call(this)) === null || _getInternal$call4 === void 0 ? void 0 : _getInternal$call4.willValidate;
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {CustomStateSet}
     * @since 1.14.0
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/states
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "states",
    get: function get() {
      var _getInternal$call5;

      return (_getInternal$call5 = getInternal.call(this)) === null || _getInternal$call5 === void 0 ? void 0 : _getInternal$call5.states;
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {HTMLFontElement|null}
     * @since 1.14.0
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/form
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "form",
    get: function get() {
      var _getInternal$call6;

      return (_getInternal$call6 = getInternal.call(this)) === null || _getInternal$call6 === void 0 ? void 0 : _getInternal$call6.form;
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * ```
     * // Use the control's name as the base name for submitted data
     * const n = this.getAttribute('name');
     * const entries = new FormData();
     * entries.append(n + '-first-name', this.firstName_);
     * entries.append(n + '-last-name', this.lastName_);
     * this.setFormValue(entries);
     * ```
     *
     * @param {File|string|FormData} value
     * @param {File|string|FormData} state
     * @since 1.14.0
     * @return {undefined}
     * @throws {DOMException} NotSupportedError
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/setFormValue
     */

  }, {
    key: "setFormValue",
    value: function setFormValue(value, state) {
      getInternal.call(this).setFormValue(value, state);
    }
    /**
     *
     * @param {object} flags
     * @param {string|undefined} message
     * @param {HTMLElement} anchor
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/setValidity
     * @since 1.14.0
     * @return {undefined}
     * @throws {DOMException} NotSupportedError
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "setValidity",
    value: function setValidity(flags, message, anchor) {
      getInternal.call(this).setValidity(flags, message, anchor);
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/checkValidity
     * @since 1.14.0
     * @return {boolean}
     * @throws {DOMException} NotSupportedError
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     */

  }, {
    key: "checkValidity",
    value: function checkValidity() {
      var _getInternal$call7;

      return (_getInternal$call7 = getInternal.call(this)) === null || _getInternal$call7 === void 0 ? void 0 : _getInternal$call7.checkValidity();
    }
    /**
     * This is a method of [internal api](https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals)
     *
     * @return {boolean}
     * @since 1.14.0
     * @see https://developer.mozilla.org/en-US/docs/Web/API/ElementInternals/reportValidity
     * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
     * @throws {DOMException} NotSupportedError
     */

  }, {
    key: "reportValidity",
    value: function reportValidity() {
      var _getInternal$call8;

      return (_getInternal$call8 = getInternal.call(this)) === null || _getInternal$call8 === void 0 ? void 0 : _getInternal$call8.reportValidity();
    }
  }], [{
    key: "observedAttributes",
    get: function get() {
      var list = _get(_getPrototypeOf(CustomControl), "observedAttributes", this);

      list.push(_constants_js__WEBPACK_IMPORTED_MODULE_2__.ATTRIBUTE_VALUE);
      return list;
    }
    /**
     *
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals}
     * @since 1.14.0
     * @return {boolean}
     */

  }, {
    key: "formAssociated",
    get: function get() {
      return true;
    }
  }]);

  return CustomControl;
}(_customelement_js__WEBPACK_IMPORTED_MODULE_3__.CustomElement);
/**
 * @private
 * @return {object}
 * @throws {Error} the ElementInternals is not supported and a polyfill is necessary
 * @this CustomControl
 */


function getInternal() {
  var self = this;

  if (!(attachedInternalSymbol in this)) {
    throw new Error('ElementInternals is not supported and a polyfill is necessary');
  }

  return this[attachedInternalSymbol];
}
/**
 * @private
 * @return {object}
 * @this CustomControl
 */


function initObserver() {
  var self = this; // value

  self[_customelement_js__WEBPACK_IMPORTED_MODULE_3__.attributeObserverSymbol]['value'] = function () {
    self.setOption('value', self.getAttribute('value'));
  };
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_1__.assignToNamespace)('Monster.DOM', CustomControl);


/***/ }),
/* 35 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_3__.Monster; },
/* harmony export */   "registerCustomElement": function() { return /* binding */ registerCustomElement; },
/* harmony export */   "CustomElement": function() { return /* binding */ CustomElement; },
/* harmony export */   "initMethodSymbol": function() { return /* binding */ initMethodSymbol; },
/* harmony export */   "assembleMethodSymbol": function() { return /* binding */ assembleMethodSymbol; },
/* harmony export */   "assignUpdaterToElement": function() { return /* binding */ assignUpdaterToElement; },
/* harmony export */   "attributeObserverSymbol": function() { return /* binding */ attributeObserverSymbol; },
/* harmony export */   "getSlottedElements": function() { return /* binding */ getSlottedElements; }
/* harmony export */ });
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(21);
/* harmony import */ var _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(2);
/* harmony import */ var _types_dataurl_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(36);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(16);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(9);
/* harmony import */ var _types_observer_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(27);
/* harmony import */ var _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(26);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(14);
/* harmony import */ var _util_clone_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(15);
/* harmony import */ var _attributes_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(32);
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(33);
/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(38);
/* harmony import */ var _updater_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(40);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _wrapNativeSuper(Class) { var _cache = typeof Map === "function" ? new Map() : undefined; _wrapNativeSuper = function _wrapNativeSuper(Class) { if (Class === null || !_isNativeFunction(Class)) return Class; if (typeof Class !== "function") { throw new TypeError("Super expression must either be null or a function"); } if (typeof _cache !== "undefined") { if (_cache.has(Class)) return _cache.get(Class); _cache.set(Class, Wrapper); } function Wrapper() { return _construct(Class, arguments, _getPrototypeOf(this).constructor); } Wrapper.prototype = Object.create(Class.prototype, { constructor: { value: Wrapper, enumerable: false, writable: true, configurable: true } }); return _setPrototypeOf(Wrapper, Class); }; return _wrapNativeSuper(Class); }

function _construct(Parent, args, Class) { if (_isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _isNativeFunction(fn) { return Function.toString.call(fn).indexOf("[native code]") !== -1; }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
















/**
 * @memberOf Monster.DOM
 * @type {symbol}
 */

var initMethodSymbol = Symbol('initMethodSymbol');
/**
 * @memberOf Monster.DOM
 * @type {symbol}
 */

var assembleMethodSymbol = Symbol('assembleMethodSymbol');
/**
 * this symbol holds the attribute observer callbacks. The key is the attribute name.
 * @memberOf Monster.DOM
 * @type {symbol}
 */

var attributeObserverSymbol = Symbol('attributeObserver');
/**
 * HTMLElement
 * @external HTMLElement
 * @see https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement
 *
 * @startuml customelement-sequencediagram.png
 * skinparam monochrome true
 * skinparam shadowing false
 *
 * autonumber
 *
 * Script -> DOM: element = document.createElement('my-element')
 * DOM -> CustomElement: constructor()
 * CustomElement -> CustomElement: [initMethodSymbol]()
 *
 * CustomElement --> DOM: Element
 * DOM --> Script : element
 *
 *
 * Script -> DOM: document.querySelector('body').append(element)
 *
 * DOM -> CustomElement : connectedCallback()
 *
 * note right CustomElement: is only called at\nthe first connection
 * CustomElement -> CustomElement : [assembleMethodSymbol]()
 *
 * ... ...
 *
 * autonumber
 *
 * Script -> DOM: document.querySelector('monster-confirm-button').parentNode.removeChild(element)
 * DOM -> CustomElement: disconnectedCallback()
 *
 *
 * @enduml
 *
 * @startuml customelement-class.png
 * skinparam monochrome true
 * skinparam shadowing false
 * HTMLElement <|-- CustomElement
 * @enduml
 */

/**
 * To define a new HTML element we need the power of CustomElement
 *
 * IMPORTANT: after defining a `CustomElement`, the `registerCustomElement` method must be called
 * with the new class name. only then will the tag defined via the `getTag` method be made known to the DOM.
 *
 * <img src="./images/customelement-class.png">
 *
 * You can create the object via the function `document.createElement()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * document.createElement('monster-')
 * </script>
 * ```
 *
 * ## Interaction
 *
 * <img src="./images/customelement-sequencediagram.png">
 *
 * ## Styling
 *
 * For optimal display of custom-elements the pseudo-class :defined can be used.
 *
 * To prevent the custom elements from being displayed and flickering until the control is registered, it is recommended to create a css directive.
 *
 * In the simplest case, you can simply hide the control.
 *
 * ```
 * <style>
 *
 * my-custom-element:not(:defined) {
 *     display: none;
 * }
 *
 * my-custom-element:defined {
 *     display: flex;
 * }
 *
 * </style>
 * ```
 *
 * Alternatively you can also display a loader
 *
 * ```
 * my-custom-element:not(:defined) {
 *            display: flex;
 *            box-shadow: 0 4px 10px 0 rgba(33, 33, 33, 0.15);
 *            border-radius: 4px;
 *            height: 200px;
 *            position: relative;
 *            overflow: hidden;
 *        }
 *
 * my-custom-element:not(:defined)::before {
 *            content: '';
 *            display: block;
 *            position: absolute;
 *            left: -150px;
 *            top: 0;
 *            height: 100%;
 *            width: 150px;
 *            background: linear-gradient(to right, transparent 0%, #E8E8E8 50%, transparent 100%);
 *            animation: load 1s cubic-bezier(0.4, 0.0, 0.2, 1) infinite;
 *        }
 *
 * @keyframes load {
 *            from {
 *                left: -150px;
 *            }
 *            to   {
 *                left: 100%;
 *            }
 *        }
 *
 * my-custom-element:defined {
 *           display: flex;
 *       }
 * ```
 *
 * @example
 *
 * // In the example the the user can use his own template by creating a template in the DOM with the ID `my-custom-element`.
 * // You can also specify a theme (for example `mytheme`), then it will search for the ID `my-custom-element-mytheme` and
 * // if not available for the ID `my-custom-element`.
 *
 * class MyCustomElement extends CustomElement {
 * 
 *    static getTag() {
 *        return "my-custom-element"
 *    }
 *
 * }
 *
 * // ↦ <my-custom-element></my-custom-element>
 *
 * @see https://github.com/WICG/webcomponents
 * @see https://html.spec.whatwg.org/multipage/custom-elements.html#custom-elements
 * @since 1.7.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @extends external:HTMLElement
 * @summary A base class for HTML5 customcontrols
 */

var CustomElement = /*#__PURE__*/function (_HTMLElement) {
  _inherits(CustomElement, _HTMLElement);

  var _super = _createSuper(CustomElement);

  /**
   * A new object is created. First the `initOptions` method is called. Here the
   * options can be defined in derived classes. Subsequently, the shadowRoot is initialized.
   *
   * @throws {Error} the options attribute does not contain a valid json definition.
   * @since 1.7.0
   */
  function CustomElement() {
    var _this;

    _classCallCheck(this, CustomElement);

    _this = _super.call(this);
    _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol] = new _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_8__.ProxyObserver({
      'options': (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_1__.extend)({}, _this.defaults, getOptionsFromAttributes.call(_assertThisInitialized(_this)), getOptionsFromScriptTag.call(_assertThisInitialized(_this)))
    });
    _this[attributeObserverSymbol] = {};
    initOptionObserver.call(_assertThisInitialized(_this));

    _this[initMethodSymbol]();

    return _this;
  }
  /**
   * This method determines which attributes are to be monitored by `attributeChangedCallback()`.
   *
   * @return {string[]}
   * @since 1.15.0
   */


  _createClass(CustomElement, [{
    key: "defaults",
    get:
    /**
     * Derived classes can override and extend this method as follows.
     *
     * ```
     * get defaults() {
     *    return Object.assign({}, super.defaults, {
     *        myValue:true
     *    });
     * }
     * ```
     *
     * to set the options via the html tag the attribute data-monster-options must be set.
     * As value a JSON object with the desired values must be defined.
     *
     * Since 1.18.0 the JSON can be specified as a DataURI.
     *
     * ```
     * new Monster.Types.DataUrl(btoa(JSON.stringify({
     *        shadowMode: 'open',
     *        delegatesFocus: true,
     *        templates: {
     *            main: undefined
     *        }
     *    })),'application/json',true).toString()
     * ```
     * 
     * The attribute data-monster-options-selector can be used to access a script tag that contains additional configuration.
     * 
     * As value a selector must be specified, which belongs to a script tag and contains the configuration as json.
     * 
     * ```
     * <script id="id-for-this-config" type="application/json">
     *    {
     *        "config-key": "config-value"
     *    }
     * </script>
     * ```
     * 
     *
     * @property {boolean} disabled=false Object The Boolean disabled attribute, when present, makes the element not mutable, focusable, or even submitted with the form.
     * @property {string} shadowMode=open `open` Elements of the shadow root are accessible from JavaScript outside the root, for example using. `close` Denies access to the node(s) of a closed shadow root from JavaScript outside it
     * @property {Boolean} delegatesFocus=true A boolean that, when set to true, specifies behavior that mitigates custom element issues around focusability. When a non-focusable part of the shadow DOM is clicked, the first focusable part is given focus, and the shadow host is given any available :focus styling.
     * @property {Object} templates Templates
     * @property {string} templates.main=undefined Main template
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/Element/attachShadow
     * @since 1.8.0
     */
    function get() {
      return {
        ATTRIBUTE_DISABLED: this.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED),
        shadowMode: 'open',
        delegatesFocus: true,
        templates: {
          main: undefined
        }
      };
    }
    /**
     * There is no check on the name by this class. the developer is responsible for assigning an appropriate tag.
     * if the name is not valid, registerCustomElement() will issue an error
     *
     * @link https://html.spec.whatwg.org/multipage/custom-elements.html#valid-custom-element-name
     * @return {string}
     * @throws {Error} the method getTag must be overwritten by the derived class.
     * @since 1.7.0
     */

  }, {
    key: "attachObserver",
    value:
    /**
     * attach a new observer
     *
     * @param {Observer} observer
     * @returns {CustomElement}
     */
    function attachObserver(observer) {
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].attachObserver(observer);
      return this;
    }
    /**
     * detach a observer
     *
     * @param {Observer} observer
     * @returns {CustomElement}
     */

  }, {
    key: "detachObserver",
    value: function detachObserver(observer) {
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].detachObserver(observer);
      return this;
    }
    /**
     * @param {Observer} observer
     * @returns {ProxyObserver}
     */

  }, {
    key: "containsObserver",
    value: function containsObserver(observer) {
      return this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].containsObserver(observer);
    }
    /**
     * nested options can be specified by path `a.b.c`
     *
     * @param {string} path
     * @param {*} defaultValue
     * @return {*}
     * @since 1.10.0
     */

  }, {
    key: "getOption",
    value: function getOption(path, defaultValue) {
      var value;

      try {
        value = new _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__.Pathfinder(this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].getRealSubject()['options']).getVia(path);
      } catch (e) {}

      if (value === undefined) return defaultValue;
      return value;
    }
    /**
     * Set option and inform elements
     *
     * @param {string} path
     * @param {*} value
     * @return {CustomElement}
     * @since 1.14.0
     */

  }, {
    key: "setOption",
    value: function setOption(path, value) {
      new _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__.Pathfinder(this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].getSubject()['options']).setVia(path, value);
      return this;
    }
    /**
     * @since 1.15.0
     * @param {string|object} options
     * @return {CustomElement}
     */

  }, {
    key: "setOptions",
    value: function setOptions(options) {
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(options)) {
        options = parseOptionsJSON.call(this, options);
      }

      var self = this;
      (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_1__.extend)(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].getSubject()['options'], self.defaults, options);
      return self;
    }
    /**
     * Is called once via the constructor
     *
     * @return {CustomElement}
     * @since 1.8.0
     */

  }, {
    key: initMethodSymbol,
    value: function value() {
      return this;
    }
    /**
     * Is called once when the object is included in the DOM for the first time.
     *
     * @return {CustomElement}
     * @since 1.8.0
     */

  }, {
    key: assembleMethodSymbol,
    value: function value() {
      var self = this;
      var elements, nodeList;

      if (self.getOption('shadowMode', false) !== false) {
        try {
          initShadowRoot.call(self);
          elements = self.shadowRoot.childNodes;
        } catch (e) {}

        try {
          initCSSStylesheet.call(this);
        } catch (e) {
          (0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.addAttributeToken)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_ERRORMESSAGE, e.toString());
        }
      }

      if (!(elements instanceof NodeList)) {
        if (!(elements instanceof NodeList)) {
          initHtmlContent.call(this);
          elements = this.childNodes;
        }
      }

      try {
        nodeList = new Set([].concat(_toConsumableArray(elements), _toConsumableArray(getSlottedElements.call(self))));
      } catch (e) {
        nodeList = elements;
      }

      assignUpdaterToElement.call(self, nodeList, (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_10__.clone)(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].getRealSubject()['options']));
      return self;
    }
    /**
     * Called every time the element is inserted into the DOM. Useful for running setup code, such as
     * fetching resources or rendering. Generally, you should try to delay work until this time.
     *
     * @return {void}
     * @since 1.7.0
     */

  }, {
    key: "connectedCallback",
    value: function connectedCallback() {
      var self = this;

      if (!(0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.hasObjectLink)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.objectUpdaterLinkSymbol)) {
        self[assembleMethodSymbol]();
      }
    }
    /**
     * Called every time the element is removed from the DOM. Useful for running clean up code.
     *
     * @return {void}
     * @since 1.7.0
     */

  }, {
    key: "disconnectedCallback",
    value: function disconnectedCallback() {}
    /**
     * The custom element has been moved into a new document (e.g. someone called document.adoptNode(el)).
     *
     * @return {void}
     * @since 1.7.0
     */

  }, {
    key: "adoptedCallback",
    value: function adoptedCallback() {}
    /**
     * Called when an observed attribute has been added, removed, updated, or replaced. Also called for initial
     * values when an element is created by the parser, or upgraded. Note: only attributes listed in the observedAttributes
     * property will receive this callback.
     *
     * @param {string} attrName
     * @param {string} oldVal
     * @param {string} newVal
     * @return {void}
     * @since 1.15.0
     */

  }, {
    key: "attributeChangedCallback",
    value: function attributeChangedCallback(attrName, oldVal, newVal) {
      var _self$attributeObserv;

      var self = this;
      var callback = (_self$attributeObserv = self[attributeObserverSymbol]) === null || _self$attributeObserv === void 0 ? void 0 : _self$attributeObserv[attrName];

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isFunction)(callback)) {
        callback.call(self, newVal, oldVal);
      }
    }
    /**
     *
     * @param {Node} node
     * @return {boolean}
     * @throws {TypeError} value is not an instance of
     * @since 1.19.0
     */

  }, {
    key: "hasNode",
    value: function hasNode(node) {
      var self = this;

      if (containChildNode.call(self, (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_9__.validateInstance)(node, Node))) {
        return true;
      }

      if (!(self.shadowRoot instanceof ShadowRoot)) {
        return false;
      }

      return containChildNode.call(self.shadowRoot, node);
    }
  }], [{
    key: "observedAttributes",
    get: function get() {
      return [_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS, _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED];
    }
  }, {
    key: "getTag",
    value: function getTag() {
      throw new Error("the method getTag must be overwritten by the derived class.");
    }
    /**
     * At this point a `CSSStyleSheet` object can be returned. If the environment does not
     * support a constructor, then an object can also be built using the following detour.
     *
     * If `undefined` is returned then the shadowRoot does not get a stylesheet.
     *
     * ```
     * const doc = document.implementation.createHTMLDocument('title');
     *
     * let style = doc.createElement("style");
     * style.innerHTML="p{color:red;}";
     *
     * // WebKit Hack
     * style.appendChild(document.createTextNode(""));
     * // Add the <style> element to the page
     * doc.head.appendChild(style);
     * return doc.styleSheets[0];
     * ;
     * ```
     *
     * @return {CSSStyleSheet|CSSStyleSheet[]|string|undefined}
     */

  }, {
    key: "getCSSStyleSheet",
    value: function getCSSStyleSheet() {
      return undefined;
    }
  }]);

  return CustomElement;
}( /*#__PURE__*/_wrapNativeSuper(HTMLElement));
/**
 * @private
 * @param {String|undefined} query
 * @param {String|undefined|null} name name of the slot (if the parameter is undefined, all slots are searched, if the parameter has the value null, all slots without a name are searched. if a string is specified, the slots with this name are searched.)
 * @return {*}
 * @this CustomElement
 * @since 1.23.0
 * @throws {Error} query must be a string
 */


function getSlottedElements(query, name) {
  var self = this;
  var result = new Set();

  if (!(self.shadowRoot instanceof ShadowRoot)) {
    return result;
  }

  var selector = 'slot';

  if (name !== undefined) {
    if (name === null) {
      selector += ':not([name])';
    } else {
      selector += '[name=' + (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_9__.validateString)(name) + ']';
    }
  }

  var slots = self.shadowRoot.querySelectorAll(selector);

  for (var _i = 0, _Object$entries = Object.entries(slots); _i < _Object$entries.length; _i++) {
    var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
        slot = _Object$entries$_i[1];

    slot.assignedElements().forEach(function (node) {
      if (!(node instanceof HTMLElement)) return;

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(query)) {
        node.querySelectorAll(query).forEach(function (n) {
          result.add(n);
        });

        if (node.matches(query)) {
          result.add(node);
        }
      } else if (query !== undefined) {
        throw new Error('query must be a string');
      } else {
        result.add(node);
      }
    });
  }

  return result;
}
/**
 * @this CustomElement
 * @private
 * @param {Node} node
 * @return {boolean}
 */


function containChildNode(node) {
  var self = this;

  if (self.contains(node)) {
    return true;
  }

  for (var _i2 = 0, _Object$entries2 = Object.entries(self.childNodes); _i2 < _Object$entries2.length; _i2++) {
    var _Object$entries2$_i = _slicedToArray(_Object$entries2[_i2], 2),
        e = _Object$entries2$_i[1];

    if (e.contains(node)) {
      return true;
    }

    containChildNode.call(e, node);
  }

  return false;
}
/**
 * @since 1.15.0
 * @private
 * @this CustomElement
 */


function initOptionObserver() {
  var self = this;
  var lastDisabledValue = undefined;
  self.attachObserver(new _types_observer_js__WEBPACK_IMPORTED_MODULE_7__.Observer(function () {
    var flag = self.getOption('disabled');

    if (flag === lastDisabledValue) {
      return;
    }

    lastDisabledValue = flag;

    if (!(self.shadowRoot instanceof ShadowRoot)) {
      return;
    }

    var query = 'button, command, fieldset, keygen, optgroup, option, select, textarea, input, [data-monster-objectlink]';
    var elements = self.shadowRoot.querySelectorAll(query);
    var nodeList;

    try {
      nodeList = new Set([].concat(_toConsumableArray(elements), _toConsumableArray(getSlottedElements.call(self, query))));
    } catch (e) {
      nodeList = elements;
    }

    for (var _i3 = 0, _arr2 = _toConsumableArray(nodeList); _i3 < _arr2.length; _i3++) {
      var element = _arr2[_i3];

      if (flag === true) {
        element.setAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED, '');
      } else {
        element.removeAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED);
      }
    }
  }));
  self.attachObserver(new _types_observer_js__WEBPACK_IMPORTED_MODULE_7__.Observer(function () {
    // not initialised
    if (!(0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.hasObjectLink)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.objectUpdaterLinkSymbol)) {
      return;
    } // inform every element


    var updaters = (0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.getLinkedObjects)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.objectUpdaterLinkSymbol);

    var _iterator = _createForOfIteratorHelper(updaters),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var list = _step.value;

        var _iterator2 = _createForOfIteratorHelper(list),
            _step2;

        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var updater = _step2.value;
            var d = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_10__.clone)(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].getRealSubject()['options']);
            Object.assign(updater.getSubject(), d);
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  })); // disabled

  self[attributeObserverSymbol][_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED] = function () {
    if (self.hasAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED)) {
      self.setOption(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED, true);
    } else {
      self.setOption(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_DISABLED, undefined);
    }
  }; // data-monster-options


  self[attributeObserverSymbol][_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS] = function () {
    var options = getOptionsFromAttributes.call(self);

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isObject)(options)) {
      self.setOptions(options);
    }
  };
}
/**
 * @private
 * @return {object}
 * @throws {TypeError} value is not a object
 */


function getOptionsFromScriptTag() {
  var self = this;

  if (!self.hasAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS_SELECTOR)) {
    return {};
  }

  var node = document.querySelector(self.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS_SELECTOR));

  if (!(node instanceof HTMLScriptElement)) {
    (0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.addAttributeToken)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_ERRORMESSAGE, 'the selector ' + _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS_SELECTOR + ' for options was specified (' + self.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS_SELECTOR) + ') but not found.');
    return {};
  }

  var obj = {};

  try {
    obj = parseOptionsJSON.call(this, node.textContent.trim());
  } catch (e) {
    (0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.addAttributeToken)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_ERRORMESSAGE, 'when analyzing the configuration from the script tag there was an error. ' + e);
  }

  return obj;
}
/**
 * @private
 * @return {object}
 */


function getOptionsFromAttributes() {
  var self = this;

  if (this.hasAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS)) {
    try {
      return parseOptionsJSON.call(self, this.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS));
    } catch (e) {
      (0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.addAttributeToken)(self, _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_ERRORMESSAGE, 'the options attribute ' + _constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS + ' does not contain a valid json definition (actual: ' + this.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_12__.ATTRIBUTE_OPTIONS) + ').' + e);
    }
  }

  return {};
}
/**
 * @private
 * @param data
 * @return {Object}
 */


function parseOptionsJSON(data) {
  var self = this,
      obj = {};

  if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(data)) {
    return obj;
  } // the configuration can be specified as a data url.


  try {
    var dataUrl = (0,_types_dataurl_js__WEBPACK_IMPORTED_MODULE_4__.parseDataURL)(data);
    data = dataUrl.content;
  } catch (e) {}

  try {
    var _obj = JSON.parse(data);

    return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_9__.validateObject)(_obj);
  } catch (e) {
    throw e;
  }

  return obj;
}
/**
 * @private
 * @return {initHtmlContent}
 */


function initHtmlContent() {
  try {
    var template = (0,_template_js__WEBPACK_IMPORTED_MODULE_13__.findDocumentTemplate)(this.constructor.getTag());
    this.appendChild(template.createDocumentFragment());
  } catch (e) {
    var html = this.getOption('templates.main', '');

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(html) && html.length > 0) {
      this.innerHTML = html;
    }
  }

  return this;
}
/**
 * @private
 * @return {CustomElement}
 * @memberOf Monster.DOM
 * @this CustomElement
 * @since 1.16.0
 * @throws {TypeError} value is not an instance of
 */


function initCSSStylesheet() {
  var self = this;

  if (!(this.shadowRoot instanceof ShadowRoot)) {
    return self;
  }

  var styleSheet = this.constructor.getCSSStyleSheet();

  if (styleSheet instanceof CSSStyleSheet) {
    if (styleSheet.cssRules.length > 0) {
      this.shadowRoot.adoptedStyleSheets = [styleSheet];
    }
  } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isArray)(styleSheet)) {
    var assign = [];

    var _iterator3 = _createForOfIteratorHelper(styleSheet),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var s = _step3.value;

        if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(s)) {
          var trimedStyleSheet = s.trim();

          if (trimedStyleSheet !== '') {
            var style = document.createElement('style');
            style.innerHTML = trimedStyleSheet;
            self.shadowRoot.prepend(style);
          }

          continue;
        }

        (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_9__.validateInstance)(s, CSSStyleSheet);

        if (s.cssRules.length > 0) {
          assign.push(s);
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }

    if (assign.length > 0) {
      this.shadowRoot.adoptedStyleSheets = assign;
    }
  } else if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(styleSheet)) {
    var _trimedStyleSheet = styleSheet.trim();

    if (_trimedStyleSheet !== '') {
      var _style = document.createElement('style');

      _style.innerHTML = styleSheet;
      self.shadowRoot.prepend(_style);
    }
  }

  return self;
}
/**
 * @private
 * @return {CustomElement}
 * @throws {Error} html is not set.
 * @see https://developer.mozilla.org/en-US/docs/Web/API/Element/attachShadow
 * @memberOf Monster.DOM
 * @since 1.8.0
 */


function initShadowRoot() {
  var template, html;

  try {
    template = (0,_template_js__WEBPACK_IMPORTED_MODULE_13__.findDocumentTemplate)(this.constructor.getTag());
  } catch (e) {
    html = this.getOption('templates.main', '');

    if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_6__.isString)(html) || html === undefined || html === "") {
      throw new Error("html is not set.");
    }
  }

  this.attachShadow({
    mode: this.getOption('shadowMode', 'open'),
    delegatesFocus: this.getOption('delegatesFocus', true)
  });

  if (template instanceof _template_js__WEBPACK_IMPORTED_MODULE_13__.Template) {
    this.shadowRoot.appendChild(template.createDocumentFragment());
    return this;
  }

  this.shadowRoot.innerHTML = html;
  return this;
}
/**
 * This method registers a new element. The string returned by `CustomElement.getTag()` is used as the tag.
 *
 * @param {CustomElement} element
 * @return {void}
 * @since 1.7.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {DOMException} Failed to execute 'define' on 'CustomElementRegistry': is not a valid custom element name
 */


function registerCustomElement(element) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_9__.validateFunction)(element);
  (0,_types_global_js__WEBPACK_IMPORTED_MODULE_5__.getGlobalObject)('customElements').define(element.getTag(), element);
}
/**
 *
 * @param element
 * @param object
 * @return {Promise[]}
 * @since 1.23.0
 * @memberOf Monster.DOM
 */


function assignUpdaterToElement(elements, object) {
  var updaters = new Set();

  if (elements instanceof NodeList) {
    elements = new Set(_toConsumableArray(elements));
  }

  var result = [];
  elements.forEach(function (element) {
    if (!(element instanceof HTMLElement)) return;
    if (element instanceof HTMLTemplateElement) return;
    var u = new _updater_js__WEBPACK_IMPORTED_MODULE_14__.Updater(element, object);
    updaters.add(u);
    result.push(u.run().then(function () {
      return u.enableEventProcessing();
    }));
  });

  if (updaters.size > 0) {
    (0,_attributes_js__WEBPACK_IMPORTED_MODULE_11__.addToObjectLink)(this, _constants_js__WEBPACK_IMPORTED_MODULE_12__.objectUpdaterLinkSymbol, updaters);
  }

  return result;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_3__.assignToNamespace)('Monster.DOM', CustomElement, registerCustomElement, assignUpdaterToElement);


/***/ }),
/* 36 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _base_js__WEBPACK_IMPORTED_MODULE_1__.Monster; },
/* harmony export */   "parseDataURL": function() { return /* binding */ parseDataURL; },
/* harmony export */   "DataUrl": function() { return /* binding */ DataUrl; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _mediatype_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(37);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(14);


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }


/**
 * @author schukai GmbH
 */





/**
 * @private
 * @type {symbol}
 */

var internal = Symbol('internal');
/**
 * You can create an object via the monster namespace `new Monster.Types.DataUrl()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.DataUrl()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {DataUrl} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/dataurl.js';
 * new DataUrl()
 * </script>
 * ```
 *
 * @since 1.8.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @see https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URIs
 * @see https://datatracker.ietf.org/doc/html/rfc2397
 */

var DataUrl = /*#__PURE__*/function (_Base) {
  _inherits(DataUrl, _Base);

  var _super = _createSuper(DataUrl);

  /**
   *
   * @param {String} content
   * @param {String|Monster.Types.MediaType} mediatype
   * @param {boolean} base64=true
   */
  function DataUrl(content, mediatype, base64) {
    var _this;

    _classCallCheck(this, DataUrl);

    _this = _super.call(this);

    if ((0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isString)(mediatype)) {
      mediatype = (0,_mediatype_js__WEBPACK_IMPORTED_MODULE_3__.parseMediaType)(mediatype);
    }

    _this[internal] = {
      content: (0,_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(content),
      mediatype: (0,_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInstance)(mediatype, _mediatype_js__WEBPACK_IMPORTED_MODULE_3__.MediaType),
      base64: (0,_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateBoolean)(base64 === undefined ? true : base64)
    };
    return _this;
  }

  _createClass(DataUrl, [{
    key: "content",
    get: function get() {
      return this[internal].base64 ? atob(this[internal].content) : this[internal].content;
    }
  }, {
    key: "mediatype",
    get: function get() {
      return this[internal].mediatype;
    }
    /**
     *
     * @return {string}
     * @see https://datatracker.ietf.org/doc/html/rfc2397
     */

  }, {
    key: "toString",
    value: function toString() {
      var content = this[internal].content;

      if (this[internal].base64 === true) {
        content = ';base64,' + content;
      } else {
        content = ',' + encodeURIComponent(content);
      }

      return 'data:' + this[internal].mediatype.toString() + content;
    }
  }]);

  return DataUrl;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);
/**
 * You can call the function via the monster namespace `Monster.Types.parseDataURL()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.parseDataURL())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {parseDataURL} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/dataurl.js';
 * console.log(parseDataURL())
 * </script>
 * ```
 *
 * Specification:
 *
 * ```
 * dataurl    := "data:" [ mediatype ] [ ";base64" ] "," data
 * mediatype  := [ type "/" subtype ] *( ";" parameter )
 * data       := *urlchar
 * parameter  := attribute "=" value
 * ```
 *
 * @param {String} dataurl
 * @return {Monster.Types.DataUrl}
 * @see https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URIs
 * @see https://datatracker.ietf.org/doc/html/rfc2397
 * @throws {TypeError} incorrect or missing data protocol
 * @throws {TypeError} malformed data url
 * @memberOf Monster.Types
 */


function parseDataURL(dataurl) {
  (0,_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(dataurl);
  dataurl = dataurl.trim();

  if (dataurl.substring(0, 5) !== 'data:') {
    throw new TypeError('incorrect or missing data protocol');
  }

  dataurl = dataurl.substring(5);
  var p = dataurl.indexOf(',');

  if (p === -1) {
    throw new TypeError('malformed data url');
  }

  var content = dataurl.substring(p + 1);
  var mediatypeAndBase64 = dataurl.substring(0, p).trim();
  var mediatype = 'text/plain;charset=US-ASCII';
  var base64Flag = false;

  if (mediatypeAndBase64 !== "") {
    mediatype = mediatypeAndBase64;

    if (mediatypeAndBase64.endsWith('base64')) {
      var i = mediatypeAndBase64.lastIndexOf(';');
      mediatype = mediatypeAndBase64.substring(0, i);
      base64Flag = true;
    } else {
      content = decodeURIComponent(content);
    }

    mediatype = (0,_mediatype_js__WEBPACK_IMPORTED_MODULE_3__.parseMediaType)(mediatype);
  } else {
    content = decodeURIComponent(content);
  }

  return new DataUrl(content, mediatype, base64Flag);
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', parseDataURL, DataUrl);


/***/ }),
/* 37 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _base_js__WEBPACK_IMPORTED_MODULE_1__.Monster; },
/* harmony export */   "parseMediaType": function() { return /* binding */ parseMediaType; },
/* harmony export */   "MediaType": function() { return /* binding */ MediaType; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _wrapRegExp() { _wrapRegExp = function _wrapRegExp(re, groups) { return new BabelRegExp(re, undefined, groups); }; var _super = RegExp.prototype; var _groups = new WeakMap(); function BabelRegExp(re, flags, groups) { var _this = new RegExp(re, flags); _groups.set(_this, groups || _groups.get(re)); return _setPrototypeOf(_this, BabelRegExp.prototype); } _inherits(BabelRegExp, RegExp); BabelRegExp.prototype.exec = function (str) { var result = _super.exec.call(this, str); if (result) result.groups = buildGroups(result, this); return result; }; BabelRegExp.prototype[Symbol.replace] = function (str, substitution) { if (typeof substitution === "string") { var groups = _groups.get(this); return _super[Symbol.replace].call(this, str, substitution.replace(/\$<([^>]+)>/g, function (_, name) { return "$" + groups[name]; })); } else if (typeof substitution === "function") { var _this = this; return _super[Symbol.replace].call(this, str, function () { var args = arguments; if (_typeof(args[args.length - 1]) !== "object") { args = [].slice.call(args); args.push(buildGroups(args, _this)); } return substitution.apply(this, args); }); } else { return _super[Symbol.replace].call(this, str, substitution); } }; function buildGroups(result, re) { var g = _groups.get(re); return Object.keys(g).reduce(function (groups, name) { groups[name] = result[g[name]]; return groups; }, Object.create(null)); } return _wrapRegExp.apply(this, arguments); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }


/**
 * @author schukai GmbH
 */




/**
 * @private
 * @type {symbol}
 */

var internal = Symbol('internal');
/**
 * @typedef {Object} Parameter
 * @property {string} key
 * @property {string} value
 * @memberOf Monster.Types
 */

/**
 * You can create an object via the monster namespace `new Monster.Types.MediaType()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Types.MediaType())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {MediaType} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/mediatype.js';
 * console.log(new MediaType())
 * </script>
 * ```
 *
 * @since 1.8.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var MediaType = /*#__PURE__*/function (_Base) {
  _inherits(MediaType, _Base);

  var _super = _createSuper(MediaType);

  /**
   *
   * @param {String} type
   * @param {String} subtype
   * @param {Monster.Types.Parameter[]} parameter
   */
  function MediaType(type, subtype, parameter) {
    var _this;

    _classCallCheck(this, MediaType);

    _this = _super.call(this);
    _this[internal] = {
      type: (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(type).toLowerCase(),
      subtype: (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(subtype).toLowerCase(),
      parameter: []
    };

    if (parameter !== undefined) {
      _this[internal]['parameter'] = (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateArray)(parameter);
    }

    return _this;
  }
  /**
   * @return {String}
   */


  _createClass(MediaType, [{
    key: "type",
    get: function get() {
      return this[internal].type;
    }
    /**
     * @return {String}
     */

  }, {
    key: "subtype",
    get: function get() {
      return this[internal].subtype;
    }
    /**
     * @return {Monster.Types.Parameter[]}
     */

  }, {
    key: "parameter",
    get:
    /**
     *
     *
     * @return {Map}
     */
    function get() {
      var result = new Map();
      this[internal]['parameter'].forEach(function (p) {
        var value = p.value; // internally special values are partly stored with quotes, this function removes them.

        if (value.startsWith('"') && value.endsWith('"')) {
          value = value.substring(1, value.length - 1);
        }

        result.set(p.key, value);
      });
      return result;
    }
    /**
     *
     * @return {string}
     */

  }, {
    key: "toString",
    value: function toString() {
      var parameter = [];

      var _iterator = _createForOfIteratorHelper(this[internal].parameter),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var a = _step.value;
          parameter.push(a.key + '=' + a.value);
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }

      return this[internal].type + '/' + this[internal].subtype + (parameter.length > 0 ? ';' + parameter.join(';') : '');
    }
  }]);

  return MediaType;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);
/**
 * You can call the function via the monster namespace `Monster.Types.parseMediaType()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.Types.parseMediaType())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {parseMediaType} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/dataurl.js';
 * console.log(parseMediaType())
 * </script>
 * ```
 *
 * Specification:
 *
 * ```
 * dataurl    := "data:" [ mediatype ] [ ";base64" ] "," data
 * mediatype  := [ type "/" subtype ] *( ";" parameter )
 * data       := *urlchar
 * parameter  := attribute "=" value
 * ```
 *
 * @param {String} mediatype
 * @return {Monster.Types.MediaType}
 * @see https://datatracker.ietf.org/doc/html/rfc2045#section-5.1
 * @throws {TypeError} the mimetype can not be parsed
 * @throws {TypeError} blank value is not allowed
 * @throws {TypeError} malformed data url
 * @memberOf Monster.Types
 */


function parseMediaType(mediatype) {
  var regex = /*#__PURE__*/_wrapRegExp(/([A-Za-z]+|\*)\/(([a-zA-Z0-9.\+_\-]+)|\*|)(\s*;\s*([a-zA-Z0-9]+)\s*(=\s*("?[A-Za-z0-9_\-]+"?))?)*/g, {
    type: 1,
    subtype: 2,
    parameter: 4
  });

  var result = regex.exec((0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(mediatype));
  var groups = result === null || result === void 0 ? void 0 : result['groups'];

  if (groups === undefined) {
    throw new TypeError('the mimetype can not be parsed');
  }

  var type = groups === null || groups === void 0 ? void 0 : groups['type'];
  var subtype = groups === null || groups === void 0 ? void 0 : groups['subtype'];
  var parameter = groups === null || groups === void 0 ? void 0 : groups['parameter'];

  if (subtype === "" || type === "") {
    throw new TypeError('blank value is not allowed');
  }

  return new MediaType(type, subtype, parseParameter(parameter));
}
/**
 * @private
 * @since 1.18.0
 * @param {String} parameter
 * @return {Monster.Types.Parameter[]|undefined}
 * @memberOf Monster.Types
 */


function parseParameter(parameter) {
  if (!(0,_is_js__WEBPACK_IMPORTED_MODULE_2__.isString)(parameter)) {
    return undefined;
  }

  var result = [];
  parameter.split(';').forEach(function (entry) {
    entry = entry.trim();

    if (entry === "") {
      return;
    }

    var kv = entry.split('=');
    var key = (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(kv === null || kv === void 0 ? void 0 : kv[0]).trim();
    var value = (0,_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(kv === null || kv === void 0 ? void 0 : kv[1]).trim(); // if values are quoted, they remain so internally

    result.push({
      key: key,
      value: value
    });
  });
  return result;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', parseMediaType, MediaType);


/***/ }),
/* 38 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Template": function() { return /* binding */ Template; },
/* harmony export */   "findDocumentTemplate": function() { return /* binding */ findDocumentTemplate; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(16);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(33);
/* harmony import */ var _theme_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(39);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }







/**
 * you can call the method via the monster namespace `new Monster.DOM.Template()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.Template()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Template} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/template.js';
 * new Template()
 * </script>
 * ```
 *
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @summary A template class
 */

var Template = /*#__PURE__*/function (_Base) {
  _inherits(Template, _Base);

  var _super = _createSuper(Template);

  /**
   *
   * @param {HTMLTemplateElement} template
   * @throws {TypeError} value is not an instance of
   * @throws {TypeError} value is not a function
   * @throws {Error} the function is not defined
   */
  function Template(template) {
    var _this;

    _classCallCheck(this, Template);

    _this = _super.call(this);
    var HTMLTemplateElement = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalFunction)('HTMLTemplateElement');
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(template, HTMLTemplateElement);
    _this.template = template;
    return _this;
  }
  /**
   *
   * @returns {HTMLTemplateElement}
   */


  _createClass(Template, [{
    key: "getTemplateElement",
    value: function getTemplateElement() {
      return this.template;
    }
    /**
     *
     * @return {DocumentFragment}
     * @throws {TypeError} value is not an instance of
     */

  }, {
    key: "createDocumentFragment",
    value: function createDocumentFragment() {
      return this.template.content.cloneNode(true);
    }
  }]);

  return Template;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);
/**
 * This method loads a template with the given ID and returns it.
 *
 * To do this, it first reads the theme of the document and looks for the `data-monster-theme-name` attribute in the HTML tag.
 *
 * ```
 * <html data-monster-theme-name="my-theme">
 * ```
 *
 * If no theme was specified, the default theme is `monster`.
 *
 * Now it is looked if there is a template with the given ID and theme `id-theme` and if yes it is returned.
 * If there is no template a search for a template with the given ID `id` is done. If this is also not found, an error is thrown.
 *
 * You can call the method via the monster namespace `Monster.DOM.findDocumentTemplate()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.DOM.findDocumentTemplate()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {findTemplate} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/template.js';
 * findDocumentTemplate()
 * </script>
 * ```
 *
 * @example
 *
 * import { findDocumentTemplate } from "https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/template.js";
 *
 * const template = document.createElement("template");
 * template.id = "myTemplate";
 * template.innerHTML = "<p>my default template</p>";
 * document.body.appendChild(template);
 *
 * const themedTemplate = document.createElement("template");
 * themedTemplate.id = "myTemplate-myTheme";
 * themedTemplate.innerHTML = "<p>my themed template</p>";
 * document.body.appendChild(themedTemplate);
 *
 * // loads the temple and since no theme is set the default template
 * const template1 = findDocumentTemplate("myTemplate");
 * console.log(template1.createDocumentFragment());
 * // ↦ '<p>my default template</p>'
 *
 * // now we set our own theme
 * document
 * .querySelector("html")
 * .setAttribute("data-monster-theme-name", "myTheme");
 *
 * // now we don't get the default template,
 * // but the template with the theme in the id
 * const template2 = findDocumentTemplate("myTemplate");
 * console.log(template2.createDocumentFragment());
 * // ↦ '<p>my themed template</p>'
 *
 * @param {string} id
 * @param {Node} currentNode
 * @return {Monster.DOM.Template}
 * @since 1.7.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {Error} template id not found.
 * @throws {TypeError} value is not a string
 */


function findDocumentTemplate(id, currentNode) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(id);
  var document = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalObject)('document');
  var HTMLTemplateElement = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalFunction)('HTMLTemplateElement');
  var DocumentFragment = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalFunction)('DocumentFragment');
  var Document = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalFunction)('Document');
  var prefixID;

  if (!(currentNode instanceof Document || currentNode instanceof DocumentFragment)) {
    if (currentNode instanceof Node) {
      if (currentNode.hasAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_TEMPLATE_PREFIX)) {
        prefixID = currentNode.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_TEMPLATE_PREFIX);
      }

      currentNode = currentNode.getRootNode();

      if (!(currentNode instanceof Document || currentNode instanceof DocumentFragment)) {
        currentNode = currentNode.ownerDocument;
      }
    }

    if (!(currentNode instanceof Document || currentNode instanceof DocumentFragment)) {
      currentNode = document;
    }
  }

  var template;
  var theme = (0,_theme_js__WEBPACK_IMPORTED_MODULE_5__.getDocumentTheme)();

  if (prefixID) {
    var themedPrefixID = prefixID + '-' + id + '-' + theme.getName(); // current + themedPrefixID

    template = currentNode.getElementById(themedPrefixID);

    if (template instanceof HTMLTemplateElement) {
      return new Template(template);
    } // document + themedPrefixID


    template = document.getElementById(themedPrefixID);

    if (template instanceof HTMLTemplateElement) {
      return new Template(template);
    }
  }

  var themedID = id + '-' + theme.getName(); // current + themedID

  template = currentNode.getElementById(themedID);

  if (template instanceof HTMLTemplateElement) {
    return new Template(template);
  } // document + themedID


  template = document.getElementById(themedID);

  if (template instanceof HTMLTemplateElement) {
    return new Template(template);
  } // current + ID


  template = currentNode.getElementById(id);

  if (template instanceof HTMLTemplateElement) {
    return new Template(template);
  } // document + ID


  template = document.getElementById(id);

  if (template instanceof HTMLTemplateElement) {
    return new Template(template);
  }

  throw new Error("template " + id + " not found.");
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.DOM', Template, findDocumentTemplate);


/***/ }),
/* 39 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Theme": function() { return /* binding */ Theme; },
/* harmony export */   "getDocumentTheme": function() { return /* binding */ getDocumentTheme; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(16);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(33);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * You can call the method via the monster namespace `new Monster.DOM.Theme()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.DOM.Theme())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Theme} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/theme.js';
 * console.log(new Theme())
 * </script>
 * ```
 *
 * @example
 *
 * import {getDocumentTheme} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/theme.js';
 *
 * const theme = getDocumentTheme();
 * console.log(theme.getName());
 * // ↦ monster
 *
 * @since 1.7.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @summary A theme class
 */

var Theme = /*#__PURE__*/function (_Base) {
  _inherits(Theme, _Base);

  var _super = _createSuper(Theme);

  /**
   *
   * @param name
   * @throws {TypeError} value is not a string
   */
  function Theme(name) {
    var _this;

    _classCallCheck(this, Theme);

    _this = _super.call(this);
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(name);
    _this.name = name;
    return _this;
  }
  /**
   *
   * @returns {string}
   */


  _createClass(Theme, [{
    key: "getName",
    value: function getName() {
      return this.name;
    }
  }]);

  return Theme;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);
/**
 * The theming used in the document can be defined via the html-tag.
 * The theming is specified via the attribute `data-monster-theme-name`.
 *
 * As name for a theme all characters are valid, which are also allowed for a HTMLElement-ID.
 *
 * ```
 * <html data-monster-theme-name="my-theme">
 * ```
 *
 * the default theme name is `monster`.
 *
 * @return {Theme}
 * @memberOf Monster.DOM
 * @since 1.7.0
 */


function getDocumentTheme() {
  var document = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalObject)('document');
  var name = _constants_js__WEBPACK_IMPORTED_MODULE_4__.DEFAULT_THEME;
  var element = document.querySelector('html');

  if (element instanceof HTMLElement) {
    var theme = element.getAttribute(_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_THEME_NAME);

    if (theme) {
      name = theme;
    }
  }

  return new Theme(name);
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.DOM', Theme, getDocumentTheme);


/***/ }),
/* 40 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_5__.Monster; },
/* harmony export */   "Updater": function() { return /* binding */ Updater; }
/* harmony export */ });
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _data_diff_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20);
/* harmony import */ var _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18);
/* harmony import */ var _data_pipe_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(22);
/* harmony import */ var _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(33);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(4);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(9);
/* harmony import */ var _types_observer_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(27);
/* harmony import */ var _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(26);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(14);
/* harmony import */ var _util_clone_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(15);
/* harmony import */ var _util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(41);
/* harmony import */ var _events_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(42);
/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(38);
/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(43);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

















/**
 * The updater class connects an object with the dom. In this way, structures and contents in the DOM can be programmatically adapted via attributes.
 *
 * For example, to include a string from an object, the attribute `data-monster-replace` can be used.
 * a further explanation can be found under {@tutorial dom-based-templating-implementation}.
 *
 * Changes to attributes are made only when the direct values are changed. If you want to assign changes to other values
 * as well, you have to insert the attribute `data-monster-select-this`. This should be done with care, as it can reduce performance.
 *
 * You can create an object of this class using the monster namespace `new Monster.DOM.Updater()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.Updater()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Updater} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/updater.js';
 * new Updater()
 * </script>
 * ```
 *
 * @example
 *
 * import {Updater} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/updater.js';
 *
 * // First we prepare the html document.
 * // This is done here via script, but can also be inserted into the document as pure html.
 * // To do this, simply insert the tag <h1 data-monster-replace="path:headline"></h1>.
 * const body = document.querySelector('body');
 * const headline = document.createElement('h1');
 * headline.setAttribute('data-monster-replace','path:headline')
 * body.appendChild(headline);
 *
 * // the data structure
 * let obj = {
 *    headline: "Hello World",
 * };
 *
 * // Now comes the real magic. we pass the updater the parent HTMLElement
 * // and the desired data structure.
 * const updater = new Updater(body, obj);
 * updater.run();
 *
 * // Now you can change the data structure and the HTML will follow these changes.
 * const subject = updater.getSubject();
 * subject['headline'] = "Hello World!"
 *
 * @since 1.8.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {Error} the value is not iterable
 * @throws {Error} pipes are not allowed when cloning a node.
 * @throws {Error} no template was found with the specified key.
 * @throws {Error} the maximum depth for the recursion is reached.
 * @throws {TypeError} value is not a object
 * @throws {TypeError} value is not an instance of HTMLElement
 * @summary The updater class connects an object with the dom
 */

var Updater = /*#__PURE__*/function (_Base) {
  _inherits(Updater, _Base);

  var _super = _createSuper(Updater);

  /**
   * @since 1.8.0
   * @param {HTMLElement} element
   * @param {object|ProxyObserver|undefined} subject
   * @throws {TypeError} value is not a object
   * @throws {TypeError} value is not an instance of HTMLElement
   * @see {@link Monster.DOM.findDocumentTemplate}
   */
  function Updater(element, subject) {
    var _this;

    _classCallCheck(this, Updater);

    _this = _super.call(this);
    /**
     * @type {HTMLElement}
     */

    if (subject === undefined) subject = {};

    if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_7__.isInstance)(subject, _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_9__.ProxyObserver)) {
      subject = new _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_9__.ProxyObserver(subject);
    }

    _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol] = {
      element: (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_10__.validateInstance)(element, HTMLElement),
      last: {},
      callbacks: new Map(),
      eventTypes: ['keyup', 'click', 'change', 'drop', 'touchend', 'input'],
      subject: subject
    };

    _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].callbacks.set('checkstate', getCheckStateCallback.call(_assertThisInitialized(_this)));

    _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.attachObserver(new _types_observer_js__WEBPACK_IMPORTED_MODULE_8__.Observer(function () {
      var s = _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getRealSubject();

      var diffResult = (0,_data_diff_js__WEBPACK_IMPORTED_MODULE_1__.diff)(_this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].last, s);
      _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].last = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(s);

      for (var _i = 0, _Object$entries = Object.entries(diffResult); _i < _Object$entries.length; _i++) {
        var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
            change = _Object$entries$_i[1];

        removeElement.call(_assertThisInitialized(_this), change);
        insertElement.call(_assertThisInitialized(_this), change);
        updateContent.call(_assertThisInitialized(_this), change);
        updateAttributes.call(_assertThisInitialized(_this), change);
      }
    }));

    return _this;
  }
  /**
   * Defaults: 'keyup', 'click', 'change', 'drop', 'touchend'
   *
   * @see {@link https://developer.mozilla.org/de/docs/Web/Events}
   * @since 1.9.0
   * @param {Array} types
   * @return {Updater}
   */


  _createClass(Updater, [{
    key: "setEventTypes",
    value: function setEventTypes(types) {
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].eventTypes = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_10__.validateArray)(types);
      return this;
    }
    /**
     * With this method, the eventlisteners are hooked in and the magic begins.
     *
     * ```
     * updater.run().then(() => {
     *   updater.enableEventProcessing();
     * });
     * ```
     *
     * @since 1.9.0
     * @return {Updater}
     * @throws {Error} the bind argument must start as a value with a path
     */

  }, {
    key: "enableEventProcessing",
    value: function enableEventProcessing() {
      this.disableEventProcessing();

      var _iterator = _createForOfIteratorHelper(this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].eventTypes),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var type = _step.value;
          // @see https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener
          this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element.addEventListener(type, getControlEventHandler.call(this), {
            capture: true,
            passive: true
          });
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }

      return this;
    }
    /**
     * This method turns off the magic or who loves it more profane it removes the eventListener.
     *
     * @since 1.9.0
     * @return {Updater}
     */

  }, {
    key: "disableEventProcessing",
    value: function disableEventProcessing() {
      var _iterator2 = _createForOfIteratorHelper(this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].eventTypes),
          _step2;

      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
          var type = _step2.value;
          this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element.removeEventListener(type, getControlEventHandler.call(this));
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }

      return this;
    }
    /**
     * The run method must be called for the update to start working.
     * The method ensures that changes are detected.
     *
     * ```
     * updater.run().then(() => {
     *   updater.enableEventProcessing();
     * });
     * ```
     *
     * @summary Let the magic begin
     * @return {Promise}
     */

  }, {
    key: "run",
    value: function run() {
      // the key __init__has no further meaning and is only 
      // used to create the diff for empty objects.
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].last = {
        '__init__': true
      };
      return this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.notifyObservers();
    }
    /**
     * Gets the values of bound elements and changes them in subject
     *
     * @since 1.27.0
     * @return {Monster.DOM.Updater}
     */

  }, {
    key: "retrieve",
    value: function retrieve() {
      retrieveFromBindings.call(this);
      return this;
    }
    /**
     * If you have passed a ProxyObserver in the constructor, you will get the object that the ProxyObserver manages here.
     * However, if you passed a simple object, here you will get a proxy for that object.
     *
     * For changes the ProxyObserver must be used.
     *
     * @since 1.8.0
     * @return {Proxy}
     */

  }, {
    key: "getSubject",
    value: function getSubject() {
      return this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getSubject();
    }
    /**
     * This method can be used to register commands that can be called via call: instruction.
     * This can be used to provide a pipe with its own functionality.
     *
     * @param {string} name
     * @param {function} callback
     * @returns {Transformer}
     * @throws {TypeError} value is not a string
     * @throws {TypeError} value is not a function
     */

  }, {
    key: "setCallback",
    value: function setCallback(name, callback) {
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].callbacks.set(name, callback);
      return this;
    }
  }]);

  return Updater;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_6__.Base);
/**
 * @private
 * @since 1.9.0
 * @return {function
 * @this Updater
 */


function getCheckStateCallback() {
  var self = this;
  return function (current) {
    // this is a reference to the current object (therefore no array function here)
    if (this instanceof HTMLInputElement) {
      if (['radio', 'checkbox'].indexOf(this.type) !== -1) {
        return this.value + "" === current + "" ? 'true' : undefined;
      }
    } else if (this instanceof HTMLOptionElement) {
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_7__.isArray)(current) && current.indexOf(this.value) !== -1) {
        return 'true';
      }

      return undefined;
    }
  };
}
/**
 * @private
 */


var symbol = Symbol('EventHandler');
/**
 * @private
 * @return {function}
 * @this Updater
 * @throws {Error} the bind argument must start as a value with a path
 */

function getControlEventHandler() {
  var self = this;

  if (self[symbol]) {
    return self[symbol];
  }
  /**
   * @throws {Error} the bind argument must start as a value with a path.
   * @throws {Error} unsupported object
   * @param {Event} event
   */


  self[symbol] = function (event) {
    var element = (0,_events_js__WEBPACK_IMPORTED_MODULE_13__.findTargetElementFromEvent)(event, _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_BIND);

    if (element === undefined) {
      return;
    }

    retrieveAndSetValue.call(self, element);
  };

  return self[symbol];
}
/**
 * @throws {Error} the bind argument must start as a value with a path
 * @param {HTMLElement} element
 * @return void
 * @memberOf Monster.DOM
 * @private
 */


function retrieveAndSetValue(element) {
  var _element$constructor, _Object$getOwnPropert;

  var self = this;
  var pathfinder = new _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__.Pathfinder(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getSubject());
  var path = element.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_BIND);

  if (path.indexOf('path:') !== 0) {
    throw new Error('the bind argument must start as a value with a path');
  }

  path = path.substr(5);
  var value;

  if (element instanceof HTMLInputElement) {
    switch (element.type) {
      case 'checkbox':
        value = element.checked ? element.value : undefined;
        break;

      default:
        value = element.value;
        break;
    }
  } else if (element instanceof HTMLTextAreaElement) {
    value = element.value;
  } else if (element instanceof HTMLSelectElement) {
    switch (element.type) {
      case 'select-one':
        value = element.value;
        break;

      case 'select-multiple':
        value = element.value;
        var options = element === null || element === void 0 ? void 0 : element.selectedOptions;
        if (options === undefined) options = element.querySelectorAll(":scope option:checked");
        value = Array.from(options).map(function (_ref) {
          var value = _ref.value;
          return value;
        });
        break;
    } // values from customelements 

  } else if (element !== null && element !== void 0 && (_element$constructor = element.constructor) !== null && _element$constructor !== void 0 && _element$constructor.prototype && !!((_Object$getOwnPropert = Object.getOwnPropertyDescriptor(element.constructor.prototype, 'value')) !== null && _Object$getOwnPropert !== void 0 && _Object$getOwnPropert['get']) || element.hasOwnProperty('value')) {
    value = element === null || element === void 0 ? void 0 : element['value'];
  } else {
    throw new Error("unsupported object");
  }

  var copy = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getRealSubject());
  var pf = new _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__.Pathfinder(copy);
  pf.setVia(path, value);
  var diffResult = (0,_data_diff_js__WEBPACK_IMPORTED_MODULE_1__.diff)(copy, self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getRealSubject());

  if (diffResult.length > 0) {
    pathfinder.setVia(path, value);
  }
}
/**
 * @since 1.27.0
 * @return void
 * @private
 */


function retrieveFromBindings() {
  var self = this;

  if (self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element.matches('[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_BIND + ']')) {
    retrieveAndSetValue.call(self, element);
  }

  var _iterator3 = _createForOfIteratorHelper(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element.querySelectorAll('[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_BIND + ']').entries()),
      _step3;

  try {
    for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
      var _step3$value = _slicedToArray(_step3.value, 2),
          _element = _step3$value[1];

      retrieveAndSetValue.call(self, _element);
    }
  } catch (err) {
    _iterator3.e(err);
  } finally {
    _iterator3.f();
  }
}
/**
 * @private
 * @since 1.8.0
 * @param {object} change
 * @return {void}
 */


function removeElement(change) {
  var self = this;

  var _iterator4 = _createForOfIteratorHelper(self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element.querySelectorAll(':scope [' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REMOVE + ']').entries()),
      _step4;

  try {
    for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
      var _step4$value = _slicedToArray(_step4.value, 2),
          _element2 = _step4$value[1];

      _element2.parentNode.removeChild(_element2);
    }
  } catch (err) {
    _iterator4.e(err);
  } finally {
    _iterator4.f();
  }
}
/**
 * @private
 * @since 1.8.0
 * @param {object} change
 * @return {void}
 * @throws {Error} the value is not iterable
 * @throws {Error} pipes are not allowed when cloning a node.
 * @throws {Error} no template was found with the specified key.
 * @throws {Error} the maximum depth for the recursion is reached.
 * @this Updater
 */


function insertElement(change) {
  var self = this;
  var subject = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getRealSubject();
  var document = (0,_util_js__WEBPACK_IMPORTED_MODULE_15__.getDocument)();
  var mem = new WeakSet();
  var wd = 0;
  var container = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element;

  while (true) {
    var found = false;
    wd++;
    var p = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(change === null || change === void 0 ? void 0 : change['path']);
    if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_7__.isArray)(p)) return self;

    while (p.length > 0) {
      var current = p.join('.');
      var iterator = new Set();
      var query = '[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_INSERT + '*="path:' + current + '"]';
      var e = container.querySelectorAll(query);

      if (e.length > 0) {
        iterator = new Set(_toConsumableArray(e));
      }

      if (container.matches(query)) {
        iterator.add(container);
      }

      var _iterator5 = _createForOfIteratorHelper(iterator.entries()),
          _step5;

      try {
        var _loop = function _loop() {
          var _step5$value = _slicedToArray(_step5.value, 2),
              containerElement = _step5$value[1];

          if (mem.has(containerElement)) return "continue";
          mem.add(containerElement);
          found = true;
          var attributes = containerElement.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_INSERT);
          var def = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(attributes);
          var i = def.indexOf(' ');
          var key = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(def.substr(0, i));
          var refPrefix = key + '-';
          var cmd = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(def.substr(i)); // this case is actually excluded by the query but is nevertheless checked again here

          if (cmd.indexOf('|') > 0) {
            throw new Error("pipes are not allowed when cloning a node.");
          }

          var pipe = new _data_pipe_js__WEBPACK_IMPORTED_MODULE_3__.Pipe(cmd);
          self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].callbacks.forEach(function (f, n) {
            pipe.setCallback(n, f);
          });
          var value = void 0;

          try {
            containerElement.removeAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE);
            value = pipe.run(subject);
          } catch (e) {
            containerElement.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE, e.message);
          }

          var dataPath = cmd.split(':').pop();
          var insertPoint = void 0;

          if (containerElement.hasChildNodes()) {
            insertPoint = containerElement.lastChild;
          }

          if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_7__.isIterable)(value)) {
            throw new Error('the value is not iterable');
          }

          var available = new Set();

          for (var _i2 = 0, _Object$entries2 = Object.entries(value); _i2 < _Object$entries2.length; _i2++) {
            var _Object$entries2$_i = _slicedToArray(_Object$entries2[_i2], 2),
                _i3 = _Object$entries2$_i[0],
                obj = _Object$entries2$_i[1];

            var ref = refPrefix + _i3;
            var currentPath = dataPath + "." + _i3;
            available.add(ref);
            var refElement = containerElement.querySelector('[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_INSERT_REFERENCE + '="' + ref + '"]');

            if (refElement instanceof HTMLElement) {
              insertPoint = refElement;
              continue;
            }

            appendNewDocumentFragment(containerElement, key, ref, currentPath);
          }

          var nodes = containerElement.querySelectorAll('[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_INSERT_REFERENCE + '*="' + refPrefix + '"]');

          for (var _i4 = 0, _Object$entries3 = Object.entries(nodes); _i4 < _Object$entries3.length; _i4++) {
            var _Object$entries3$_i = _slicedToArray(_Object$entries3[_i4], 2),
                node = _Object$entries3$_i[1];

            if (!available.has(node.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_INSERT_REFERENCE))) {
              try {
                containerElement.removeChild(node);
              } catch (e) {
                containerElement.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE, (containerElement.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE) + ", " + e.message).trim());
              }
            }
          }
        };

        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
          var _ret = _loop();

          if (_ret === "continue") continue;
        }
      } catch (err) {
        _iterator5.e(err);
      } finally {
        _iterator5.f();
      }

      p.pop();
    }

    if (found === false) break;

    if (wd++ > 200) {
      throw new Error('the maximum depth for the recursion is reached.');
    }
  }
}
/**
 *
 * @private
 * @since 1.8.0
 * @param {HTMLElement} container
 * @param {string} key
 * @param {string} ref
 * @param {string} path
 * @throws {Error} no template was found with the specified key.
 */


function appendNewDocumentFragment(container, key, ref, path) {
  var template = (0,_template_js__WEBPACK_IMPORTED_MODULE_14__.findDocumentTemplate)(key, container);
  var nodes = template.createDocumentFragment();

  for (var _i5 = 0, _Object$entries4 = Object.entries(nodes.childNodes); _i5 < _Object$entries4.length; _i5++) {
    var _Object$entries4$_i = _slicedToArray(_Object$entries4[_i5], 2),
        node = _Object$entries4$_i[1];

    if (node instanceof HTMLElement) {
      applyRecursive(node, key, path);
      node.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_INSERT_REFERENCE, ref);
    }

    container.appendChild(node);
  }
}
/**
 * @private
 * @since 1.10.0
 * @param {HTMLElement} node
 * @param {string} key
 * @param {string} path
 * @return {void}
 */


function applyRecursive(node, key, path) {
  if (node instanceof HTMLElement) {
    if (node.hasAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REPLACE)) {
      var value = node.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REPLACE);
      node.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REPLACE, value.replaceAll("path:" + key, "path:" + path));
    }

    if (node.hasAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_ATTRIBUTES)) {
      var _value = node.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_ATTRIBUTES);

      node.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_ATTRIBUTES, _value.replaceAll("path:" + key, "path:" + path));
    }

    for (var _i6 = 0, _Object$entries5 = Object.entries(node.childNodes); _i6 < _Object$entries5.length; _i6++) {
      var _Object$entries5$_i = _slicedToArray(_Object$entries5[_i6], 2),
          child = _Object$entries5$_i[1];

      applyRecursive(child, key, path);
    }
  }
}
/**
 * @private
 * @since 1.8.0
 * @param {object} change
 * @return {void}
 * @this Updater
 */


function updateContent(change) {
  var self = this;
  var subject = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getRealSubject();
  var p = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(change === null || change === void 0 ? void 0 : change['path']);
  runUpdateContent.call(this, this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element, p, subject);
  var slots = this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element.querySelectorAll('slot');

  if (slots.length > 0) {
    for (var _i7 = 0, _Object$entries6 = Object.entries(slots); _i7 < _Object$entries6.length; _i7++) {
      var _Object$entries6$_i = _slicedToArray(_Object$entries6[_i7], 2),
          slot = _Object$entries6$_i[1];

      for (var _i8 = 0, _Object$entries7 = Object.entries(slot.assignedNodes()); _i8 < _Object$entries7.length; _i8++) {
        var _Object$entries7$_i = _slicedToArray(_Object$entries7[_i8], 2),
            _element3 = _Object$entries7$_i[1];

        runUpdateContent.call(this, _element3, p, subject);
      }
    }
  }
}
/**
 * @private
 * @since 1.8.0
 * @param {HTMLElement} container
 * @param {array} parts
 * @param {object} subject
 * @return {void}
 */


function runUpdateContent(container, parts, subject) {
  var _this2 = this;

  if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_7__.isArray)(parts)) return;
  if (!(container instanceof HTMLElement)) return;
  parts = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(parts);
  var mem = new WeakSet();

  while (parts.length > 0) {
    var current = parts.join('.');
    parts.pop(); // Unfortunately, static data is always changed as well, since it is not possible to react to changes here.

    var query = '[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REPLACE + '^="path:' + current + '"], [' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REPLACE + '^="static:"]';
    var e = container.querySelectorAll('' + query);
    var iterator = new Set(_toConsumableArray(e));

    if (container.matches(query)) {
      iterator.add(container);
    }
    /**
     * @type {HTMLElement} element
     */


    var _iterator6 = _createForOfIteratorHelper(iterator.entries()),
        _step6;

    try {
      var _loop2 = function _loop2() {
        var _step6$value = _slicedToArray(_step6.value, 1),
            element = _step6$value[0];

        if (mem.has(element)) return {
          v: void 0
        };
        mem.add(element);
        var attributes = element.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_REPLACE);
        var cmd = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(attributes);
        var pipe = new _data_pipe_js__WEBPACK_IMPORTED_MODULE_3__.Pipe(cmd);

        _this2[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].callbacks.forEach(function (f, n) {
          pipe.setCallback(n, f);
        });

        var value = void 0;

        try {
          element.removeAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE);
          value = pipe.run(subject);
        } catch (e) {
          element.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE, e.message);
        }

        if (value instanceof HTMLElement) {
          while (element.firstChild) {
            element.removeChild(element.firstChild);
          }

          try {
            element.appendChild(value);
          } catch (e) {
            element.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE, (element.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE) + ", " + e.message).trim());
          }
        } else {
          element.innerHTML = value;
        }
      };

      for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
        var _ret2 = _loop2();

        if (_typeof(_ret2) === "object") return _ret2.v;
      }
    } catch (err) {
      _iterator6.e(err);
    } finally {
      _iterator6.f();
    }
  }
}
/**
 * @private
 * @since 1.8.0
 * @param {string} path
 * @param {object} change
 * @return {void}
 */


function updateAttributes(change) {
  var subject = this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].subject.getRealSubject();
  var p = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(change === null || change === void 0 ? void 0 : change['path']);
  runUpdateAttributes.call(this, this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].element, p, subject);
}
/**
 * @private
 * @param {HTMLElement} container
 * @param {array} parts
 * @param {object} subject
 * @return {void}
 * @this Updater
 */


function runUpdateAttributes(container, parts, subject) {
  var _this3 = this;

  var self = this;
  if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_7__.isArray)(parts)) return;
  parts = (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_11__.clone)(parts);
  var mem = new WeakSet();

  while (parts.length > 0) {
    var current = parts.join('.');
    parts.pop();
    var iterator = new Set();
    var query = '[' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_SELECT_THIS + '], [' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_ATTRIBUTES + '*="path:' + current + '"], [' + _dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_ATTRIBUTES + '^="static:"]';
    var e = container.querySelectorAll(query);

    if (e.length > 0) {
      iterator = new Set(_toConsumableArray(e));
    }

    if (container.matches(query)) {
      iterator.add(container);
    }

    var _iterator7 = _createForOfIteratorHelper(iterator.entries()),
        _step7;

    try {
      var _loop3 = function _loop3() {
        var _step7$value = _slicedToArray(_step7.value, 1),
            element = _step7$value[0];

        if (mem.has(element)) return {
          v: void 0
        };
        mem.add(element);
        var attributes = element.getAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_UPDATER_ATTRIBUTES);

        var _loop4 = function _loop4() {
          var _Object$entries8$_i = _slicedToArray(_Object$entries8[_i9], 2),
              def = _Object$entries8$_i[1];

          def = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(def);
          var i = def.indexOf(' ');
          var name = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(def.substr(0, i));
          var cmd = (0,_util_trimspaces_js__WEBPACK_IMPORTED_MODULE_12__.trimSpaces)(def.substr(i));
          var pipe = new _data_pipe_js__WEBPACK_IMPORTED_MODULE_3__.Pipe(cmd);
          self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol].callbacks.forEach(function (f, n) {
            pipe.setCallback(n, f, element);
          });
          var value = void 0;

          try {
            element.removeAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE);
            value = pipe.run(subject);
          } catch (e) {
            element.setAttribute(_dom_constants_js__WEBPACK_IMPORTED_MODULE_4__.ATTRIBUTE_ERRORMESSAGE, e.message);
          }

          if (value === undefined) {
            element.removeAttribute(name);
          } else if (element.getAttribute(name) !== value) {
            element.setAttribute(name, value);
          }

          handleInputControlAttributeUpdate.call(_this3, element, name, value);
        };

        for (var _i9 = 0, _Object$entries8 = Object.entries(attributes.split(',')); _i9 < _Object$entries8.length; _i9++) {
          _loop4();
        }
      };

      for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
        var _ret3 = _loop3();

        if (_typeof(_ret3) === "object") return _ret3.v;
      }
    } catch (err) {
      _iterator7.e(err);
    } finally {
      _iterator7.f();
    }
  }
}
/**
 * @private
 * @param {HTMLElement|*} element
 * @param {string} name
 * @param {string|number|undefined} value
 * @return {void}
 * @this Updater
 */


function handleInputControlAttributeUpdate(element, name, value) {
  var self = this;

  if (element instanceof HTMLSelectElement) {
    switch (element.type) {
      case 'select-multiple':
        for (var _i10 = 0, _Object$entries9 = Object.entries(element.options); _i10 < _Object$entries9.length; _i10++) {
          var _Object$entries9$_i = _slicedToArray(_Object$entries9[_i10], 2),
              index = _Object$entries9$_i[0],
              opt = _Object$entries9$_i[1];

          if (value.indexOf(opt.value) !== -1) {
            opt.selected = true;
          } else {
            opt.selected = false;
          }
        }

        break;

      case 'select-one':
        // Only one value may be selected
        for (var _i11 = 0, _Object$entries10 = Object.entries(element.options); _i11 < _Object$entries10.length; _i11++) {
          var _Object$entries10$_i = _slicedToArray(_Object$entries10[_i11], 2),
              _index = _Object$entries10$_i[0],
              _opt = _Object$entries10$_i[1];

          if (_opt.value === value) {
            element.selectedIndex = _index;
            break;
          }
        }

        break;
    }
  } else if (element instanceof HTMLInputElement) {
    switch (element.type) {
      case 'radio':
        if (name === 'checked') {
          if (value !== undefined) {
            element.checked = true;
          } else {
            element.checked = false;
          }
        }

        break;

      case 'checkbox':
        if (name === 'checked') {
          if (value !== undefined) {
            element.checked = true;
          } else {
            element.checked = false;
          }
        }

        break;

      case 'text':
      default:
        if (name === 'value') {
          element.value = value === undefined ? "" : value;
        }

        break;
    }
  } else if (element instanceof HTMLTextAreaElement) {
    if (name === 'value') {
      element.value = value === undefined ? "" : value;
    }
  }
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_5__.assignToNamespace)('Monster.DOM', Updater);


/***/ }),
/* 41 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "trimSpaces": function() { return /* binding */ trimSpaces; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_id_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(24);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _wrapRegExp() { _wrapRegExp = function _wrapRegExp(re, groups) { return new BabelRegExp(re, undefined, groups); }; var _super = RegExp.prototype; var _groups = new WeakMap(); function BabelRegExp(re, flags, groups) { var _this = new RegExp(re, flags); _groups.set(_this, groups || _groups.get(re)); return _setPrototypeOf(_this, BabelRegExp.prototype); } _inherits(BabelRegExp, RegExp); BabelRegExp.prototype.exec = function (str) { var result = _super.exec.call(this, str); if (result) result.groups = buildGroups(result, this); return result; }; BabelRegExp.prototype[Symbol.replace] = function (str, substitution) { if (typeof substitution === "string") { var groups = _groups.get(this); return _super[Symbol.replace].call(this, str, substitution.replace(/\$<([^>]+)>/g, function (_, name) { return "$" + groups[name]; })); } else if (typeof substitution === "function") { var _this = this; return _super[Symbol.replace].call(this, str, function () { var args = arguments; if (_typeof(args[args.length - 1]) !== "object") { args = [].slice.call(args); args.push(buildGroups(args, _this)); } return substitution.apply(this, args); }); } else { return _super[Symbol.replace].call(this, str, substitution); } }; function buildGroups(result, re) { var g = _groups.get(re); return Object.keys(g).reduce(function (groups, name) { groups[name] = result[g[name]]; return groups; }, Object.create(null)); } return _wrapRegExp.apply(this, arguments); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }





/**
 * This special trim function allows to trim spaces that have been protected by a special escape character.
 *
 * You can call the method via the monster namespace `Monster.Util.trimSpaces()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Util.trimSpaces(" hello ")
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {trimSpaces} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/util/trimspaces.js';
 * trimSpaces(' hello \\ ')
 * </script>
 * ```
 * 
 * Hint: One stroke is escaped by the javascript interpreter, the second stroke escapes the stroke.
 * 
 * ```text
 * a\ b  ↦ a b
 * a\\ b ↦ a\ b
 * ```
 * 
 * @since 1.24.0
 * @memberOf Monster.Util
 * @copyright schukai GmbH
 * @param {string} value
 * @return {string}
 * @throws {TypeError} value is not a string
 */

function trimSpaces(value) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(value);
  var placeholder = new Map();

  var regex = /*#__PURE__*/_wrapRegExp(/((\\(.)){1})/mig, {
    pattern: 2,
    char: 3
  }); // The separator for args must be escaped
  // undefined string which should not occur normally and is also not a regex


  var result = value.matchAll(regex);

  var _iterator = _createForOfIteratorHelper(result),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var m = _step.value;
      var g = m === null || m === void 0 ? void 0 : m['groups'];

      if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(g)) {
        continue;
      }

      var p = g === null || g === void 0 ? void 0 : g['pattern'];
      var c = g === null || g === void 0 ? void 0 : g['char'];

      if (p && c) {
        var r = '__' + new _types_id_js__WEBPACK_IMPORTED_MODULE_1__.ID().toString() + '__';
        placeholder.set(r, c);
        value = value.replace(p, r);
      }
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  value = value.trim();
  placeholder.forEach(function (v, k) {
    value = value.replace(k, '\\' + v);
  });
  return value;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Util', trimSpaces);


/***/ }),
/* 42 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "findTargetElementFromEvent": function() { return /* binding */ findTargetElementFromEvent; },
/* harmony export */   "fireEvent": function() { return /* binding */ fireEvent; },
/* harmony export */   "fireCustomEvent": function() { return /* binding */ fireCustomEvent; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);
/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(43);

/**
 * @author schukai GmbH
 */

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }





/**
 * You can call the function via the monster namespace `new Monster.DOM.fireEvent()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.fireEvent()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {fireEvent} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/events.js';
 * fireEvent()
 * </script>
 * ```
 *
 * @param {HTMLElement|HTMLCollection|NodeList} element
 * @param {string} type
 * @return {void}
 * @since 1.10.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {TypeError} value is not an instance of HTMLElement or HTMLCollection
 * @summary Construct and send and event
 */

function fireEvent(element, type) {
  var document = (0,_util_js__WEBPACK_IMPORTED_MODULE_3__.getDocument)();

  if (element instanceof HTMLElement) {
    if (type === 'click') {
      element.click();
      return;
    }

    var event = new Event((0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(type), {
      bubbles: true,
      cancelable: true
    });
    element.dispatchEvent(event);
  } else if (element instanceof HTMLCollection || element instanceof NodeList) {
    var _iterator = _createForOfIteratorHelper(element),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var e = _step.value;
        fireEvent(e, type);
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  } else {
    throw new TypeError('value is not an instance of HTMLElement or HTMLCollection');
  }
}
/**
 * You can call the function via the monster namespace `new Monster.DOM.fireCustomEvent()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.fireCustomEvent()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {fireCustomEvent} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/events.js';
 * fireCustomEvent()
 * </script>
 * ```
 *
 * @param {HTMLElement|HTMLCollection|NodeList} element
 * @param {string} type
 * @return {void}
 * @since 1.29.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {TypeError} value is not an instance of HTMLElement or HTMLCollection
 * @summary Construct and send and event
 */


function fireCustomEvent(element, type, detail) {
  var document = (0,_util_js__WEBPACK_IMPORTED_MODULE_3__.getDocument)();

  if (element instanceof HTMLElement) {
    if (!(0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isObject)(detail)) {
      detail = {
        detail: detail
      };
    }

    var event = new CustomEvent((0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(type), {
      bubbles: true,
      cancelable: true,
      detail: detail
    });
    element.dispatchEvent(event);
  } else if (element instanceof HTMLCollection || element instanceof NodeList) {
    var _iterator2 = _createForOfIteratorHelper(element),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var e = _step2.value;
        fireCustomEvent(e, type, detail);
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
  } else {
    throw new TypeError('value is not an instance of HTMLElement or HTMLCollection');
  }
}
/**
 * This function gets the path `Event.composedPath()` from an event and tries to find the next element
 * up the tree `element.closest()` with the attribute and value. If no value, or a value that is undefined or null,
 * is specified, only the attribute is searched.
 *
 * You can call the function via the monster namespace `new Monster.DOM.findTargetElementFromEvent()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.findTargetElementFromEvent()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {findTargetElementFromEvent} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/events.js';
 * findTargetElementFromEvent()
 * </script>
 * ```
 *
 * @since 1.14.0
 * @param {Event} event
 * @param {string} attributeName
 * @param {string|null|undefined} attributeValue
 * @throws {Error} unsupported event
 * @memberOf Monster.DOM
 * @throws {TypeError} value is not a string
 * @throws {TypeError} value is not an instance of HTMLElement
 * @summary Help function to find the appropriate control
 */


function findTargetElementFromEvent(event, attributeName, attributeValue) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateInstance)(event, Event);

  if (typeof event.composedPath !== 'function') {
    throw new Error('unsupported event');
  }

  var path = event.composedPath(); // closest cannot be used here, because closest is not correct for slotted elements

  if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_1__.isArray)(path)) {
    for (var i = 0; i < path.length; i++) {
      var o = path[i];

      if (o instanceof HTMLElement && o.hasAttribute(attributeName) && (attributeValue === undefined || o.getAttribute(attributeName) === attributeValue)) {
        return o;
      }
    }
  }

  return undefined;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.DOM', findTargetElementFromEvent, fireEvent, fireCustomEvent);


/***/ }),
/* 43 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "getWindow": function() { return /* binding */ getWindow; },
/* harmony export */   "getDocument": function() { return /* binding */ getDocument; },
/* harmony export */   "getDocumentFragmentFromString": function() { return /* binding */ getDocumentFragmentFromString; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(16);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }




/**
 * this method fetches the document object
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.DOM.getDocument())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getDocument} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/util.js';
 * console.log(getDocument())
 * </script>
 * ```
 *
 * in nodejs this functionality can be performed with [jsdom](https://www.npmjs.com/package/jsdom).
 *
 * ```
 * import {JSDOM} from "jsdom"
 * if (typeof window !== "object") {
 *    const {window} = new JSDOM('', {
 *        url: 'http://example.com/',
 *        pretendToBeVisual: true
 *    });
 *
 *    [
 *        'self',
 *        'document',
 *        'Document',
 *        'Node',
 *        'Element',
 *        'HTMLElement',
 *        'DocumentFragment',
 *        'DOMParser',
 *        'XMLSerializer',
 *        'NodeFilter',
 *        'InputEvent',
 *        'CustomEvent'
 *    ].forEach(key => (getGlobal()[key] = window[key]));
 * }
 * ```
 *
 * @returns {object}
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {Error} not supported environment
 */

function getDocument() {
  var _getGlobal;

  var document = (_getGlobal = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_1__.getGlobal)()) === null || _getGlobal === void 0 ? void 0 : _getGlobal['document'];

  if (_typeof(document) !== 'object') {
    throw new Error("not supported environment");
  }

  return document;
}
/**
 * this method fetches the window object
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.DOM.getWindow())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getWindow} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/util.js';
 * console.log(getWindow(null))
 * </script>
 * ```
 *
 * in nodejs this functionality can be performed with [jsdom](https://www.npmjs.com/package/jsdom).
 *
 * ```
 * import {JSDOM} from "jsdom"
 * if (typeof window !== "object") {
 *    const {window} = new JSDOM('', {
 *        url: 'http://example.com/',
 *        pretendToBeVisual: true
 *    });
 *
 *    getGlobal()['window']=window;
 * 
 *    [
 *        'self',
 *        'document',
 *        'Document',
 *        'Node',
 *        'Element',
 *        'HTMLElement',
 *        'DocumentFragment',
 *        'DOMParser',
 *        'XMLSerializer',
 *        'NodeFilter',
 *        'InputEvent',
 *        'CustomEvent'
 *    ].forEach(key => (getGlobal()[key] = window[key]));
 * }
 * ```
 *
 * @returns {object}
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {Error} not supported environment
 */


function getWindow() {
  var _getGlobal2;

  var window = (_getGlobal2 = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_1__.getGlobal)()) === null || _getGlobal2 === void 0 ? void 0 : _getGlobal2['window'];

  if (_typeof(window) !== 'object') {
    throw new Error("not supported environment");
  }

  return window;
}
/**
 *
 *
 * this method fetches the document object
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.DOM.getDocumentFragmentFromString())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getDocumentFragmentFromString} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/util.js';
 * console.log(getDocumentFragmentFromString('<div></div>'))
 * </script>
 * ```
 *
 * in nodejs this functionality can be performed with [jsdom](https://www.npmjs.com/package/jsdom).
 *
 * ```
 * import {JSDOM} from "jsdom"
 * if (typeof window !== "object") {
 *    const {window} = new JSDOM('', {
 *        url: 'http://example.com/',
 *        pretendToBeVisual: true
 *    });
 *
 *    [
 *        'self',
 *        'document',
 *        'Document',
 *        'Node',
 *        'Element',
 *        'HTMLElement',
 *        'DocumentFragment',
 *        'DOMParser',
 *        'XMLSerializer',
 *        'NodeFilter',
 *        'InputEvent',
 *        'CustomEvent'
 *    ].forEach(key => (getGlobal()[key] = window[key]));
 * }
 * ```
 *
 * @returns {DocumentFragment}
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {Error} not supported environment
 * @throws {TypeError} value is not a string
 */


function getDocumentFragmentFromString(html) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(html);
  var document = getDocument();
  var template = document.createElement('template');
  template.innerHTML = html;
  return template.content;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.DOM', getWindow, getDocument, getDocumentFragmentFromString);


/***/ }),
/* 44 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_1__.Monster; },
/* harmony export */   "getLocaleOfDocument": function() { return /* binding */ getLocaleOfDocument; }
/* harmony export */ });
/* harmony import */ var _i18n_locale_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(45);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2);
/* harmony import */ var _util_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(43);

/**
 * @author schukai GmbH
 */




/**
 * @private
 * @type {string}
 */

var DEFAULT_LANGUAGE = 'en';
/**
 * With this function you can read the language version set by the document.
 * For this the attribute `lang` in the html tag is read. If no attribute is set, `en` is used as default.
 * 
 * ```html
 * <html lang="en">
 * ```
 *
 * You can call the function via the monster namespace `new Monster.DOM.getLocaleOfDocument()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.DOM.getLocaleOfDocument()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getLocaleOfDocument} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/dom/locale.js';
 * new getLocaleOfDocument()
 * </script>
 * ```
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.DOM
 * @throws {TypeError} value is not a string
 * @throws {Error} unsupported locale
 * @summary Tries to determine the locale used
 */

function getLocaleOfDocument() {
  var document = (0,_util_js__WEBPACK_IMPORTED_MODULE_2__.getDocument)();
  var html = document.querySelector('html');

  if (html instanceof HTMLElement && html.hasAttribute('lang')) {
    var locale = html.getAttribute('lang');

    if (locale) {
      return new _i18n_locale_js__WEBPACK_IMPORTED_MODULE_0__.parseLocale(locale);
    }
  }

  return (0,_i18n_locale_js__WEBPACK_IMPORTED_MODULE_0__.parseLocale)(DEFAULT_LANGUAGE);
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_1__.assignToNamespace)('Monster.DOM', getLocaleOfDocument);


/***/ }),
/* 45 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Locale": function() { return /* binding */ Locale; },
/* harmony export */   "parseLocale": function() { return /* binding */ parseLocale; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);
/* harmony import */ var _util_clone_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(15);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }





/**
 * @memberOf Monster.I18n
 * @type {symbol}
 */

var propertiesSymbol = Symbol('properties');
/**
 * @type {symbol}
 * @memberOf Monster.I18n
 */

var localeStringSymbol = Symbol('localeString');
/**
 * You can create an instance via the monster namespace `new Monster.I18n.Locale()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.I18n.Locale()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this class individually.
 *
 * ```
 * <script type="module">
 * import {Locale} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/locale.js';
 * new Locale()
 * </script>
 * ```
 *
 * RFC
 *
 * ```
 * A Language-Tag consists of:
 * langtag                           ; generated tag
 *           -or- private-use        ; a private use tag
 *
 * langtag       = (language
 *                    ["-" script]
 *                    ["-" region]
 *                    *("-" variant)
 *                    *("-" extension)
 *                    ["-" privateuse])
 *
 * language      = "en", "ale", or a registered value
 *
 * script        = "Latn", "Cyrl", "Hant" ISO 15924 codes
 *
 * region        = "US", "CS", "FR" ISO 3166 codes
 *                 "419", "019",  or UN M.49 codes
 *
 * variant       = "rozaj", "nedis", "1996", multiple subtags can be used in a tag
 *
 * extension     = single letter followed by additional subtags; more than one extension
 *                 may be used in a language tag
 *
 * private-use   = "x-" followed by additional subtags, as many as are required
 *                 Note that these can start a tag or appear at the end (but not
 *                 in the middle)
 * ```
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.I18n
 * @see https://datatracker.ietf.org/doc/html/rfc3066
 */

var Locale = /*#__PURE__*/function (_Base) {
  _inherits(Locale, _Base);

  var _super = _createSuper(Locale);

  /**
   * @param {string} language
   * @param {string} [region]
   * @param {string} [script]
   * @param {string} [variants]
   * @param {string} [extlang]
   * @param {string} [privateUse]
   * @throws {Error} unsupported locale
   */
  function Locale(language, region, script, variants, extlang, privateUse) {
    var _this;

    _classCallCheck(this, Locale);

    _this = _super.call(this);
    _this[propertiesSymbol] = {
      language: language === undefined ? undefined : (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(language),
      script: script === undefined ? undefined : (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(script),
      region: region === undefined ? undefined : (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(region),
      variants: variants === undefined ? undefined : (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(variants),
      extlang: extlang === undefined ? undefined : (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(extlang),
      privateUse: privateUse === undefined ? undefined : (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(privateUse)
    };
    var s = [];
    if (language !== undefined) s.push(language);
    if (script !== undefined) s.push(script);
    if (region !== undefined) s.push(region);
    if (variants !== undefined) s.push(variants);
    if (extlang !== undefined) s.push(extlang);
    if (privateUse !== undefined) s.push(privateUse);

    if (s.length === 0) {
      throw new Error('unsupported locale');
    }

    _this[localeStringSymbol] = s.join('-');
    return _this;
  }
  /**
   * @return {string}
   */


  _createClass(Locale, [{
    key: "localeString",
    get: function get() {
      return this[localeStringSymbol];
    }
    /**
     * @return {string|undefined}
     */

  }, {
    key: "language",
    get: function get() {
      return this[propertiesSymbol].language;
    }
    /**
     * @return {string|undefined}
     */

  }, {
    key: "region",
    get: function get() {
      return this[propertiesSymbol].region;
    }
    /**
     * @return {string|undefined}
     */

  }, {
    key: "script",
    get: function get() {
      return this[propertiesSymbol].script;
    }
    /**
     * @return {string|undefined}
     */

  }, {
    key: "variants",
    get: function get() {
      return this[propertiesSymbol].variants;
    }
    /**
     * @return {string|undefined}
     */

  }, {
    key: "extlang",
    get: function get() {
      return this[propertiesSymbol].extlang;
    }
    /**
     * @return {string|undefined}
     */

  }, {
    key: "privateUse",
    get: function get() {
      return this[propertiesSymbol].privateValue;
    }
    /**
     * @return {string}
     */

  }, {
    key: "toString",
    value: function toString() {
      return "" + this.localeString;
    }
    /**
     * The structure has the following: language, script, region, variants, extlang, privateUse
     *
     * @return {Monster.I18n.LocaleMap}
     */

  }, {
    key: "getMap",
    value: function getMap() {
      return (0,_util_clone_js__WEBPACK_IMPORTED_MODULE_3__.clone)(this[propertiesSymbol]);
    }
  }]);

  return Locale;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);
/**
 * @typedef {Object} LocaleMap
 * @property {string} language
 * @property {string} script
 * @property {string} region
 * @property {string} variants
 * @property {string} extlang
 * @property {string} privateUse
 * @memberOf Monster.I18n
 */

/**
 * Parse local according to rfc4646 standard
 *
 * Limitations: The regex cannot handle multiple variants or private.
 *
 * You can call the method via the monster namespace `Monster.I18n.createLocale()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.I18n.createLocale()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {createLocale} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/locale.js';
 * createLocale()
 * </script>
 * ```
 *
 * RFC
 *
 * ```
 *   The syntax of the language tag in ABNF [RFC4234] is:
 *
 *   Language-Tag  = langtag
 *                 / privateuse             ; private use tag
 *                 / grandfathered          ; grandfathered registrations
 *
 *   langtag       = (language
 *                    ["-" script]
 *                    ["-" region]
 *                    *("-" variant)
 *                    *("-" extension)
 *                    ["-" privateuse])
 *
 *   language      = (2*3ALPHA [ extlang ]) ; shortest ISO 639 code
 *                 / 4ALPHA                 ; reserved for future use
 *                 / 5*8ALPHA               ; registered language subtag
 *
 *   extlang       = *3("-" 3ALPHA)         ; reserved for future use
 *
 *   script        = 4ALPHA                 ; ISO 15924 code
 *
 *   region        = 2ALPHA                 ; ISO 3166 code
 *                 / 3DIGIT                 ; UN M.49 code
 *
 *   variant       = 5*8alphanum            ; registered variants
 *                 / (DIGIT 3alphanum)
 *
 *   extension     = singleton 1*("-" (2*8alphanum))
 *
 *   singleton     = %x41-57 / %x59-5A / %x61-77 / %x79-7A / DIGIT
 *                 ; "a"-"w" / "y"-"z" / "A"-"W" / "Y"-"Z" / "0"-"9"
 *                 ; Single letters: x/X is reserved for private use
 *
 *   privateuse    = ("x"/"X") 1*("-" (1*8alphanum))
 *
 *   grandfathered = 1*3ALPHA 1*2("-" (2*8alphanum))
 *                   ; grandfathered registration
 *                   ; Note: i is the only singleton
 *                   ; that starts a grandfathered tag
 *
 *   alphanum      = (ALPHA / DIGIT)       ; letters and numbers
 *
 *                        Figure 1: Language Tag ABNF
 * ```
 *
 * @param {string} locale
 * @returns {Locale}
 * @since 1.14.0
 * @copyright schukai GmbH
 * @memberOf Monster.I18n
 * @throws {TypeError} value is not a string
 * @throws {Error} unsupported locale
 */


function parseLocale(locale) {
  locale = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateString)(locale).replace(/_/g, "-");
  var language,
      region,
      variants,
      parts,
      script,
      extlang,
      regexRegular = "(art-lojban|cel-gaulish|no-bok|no-nyn|zh-guoyu|zh-hakka|zh-min|zh-min-nan|zh-xiang)",
      regexIrregular = "(en-GB-oed|i-ami|i-bnn|i-default|i-enochian|i-hak|i-klingon|i-lux|i-mingo|i-navajo|i-pwn|i-tao|i-tay|i-tsu|sgn-BE-FR|sgn-BE-NL|sgn-CH-DE)",
      regexGrandfathered = "(" + regexIrregular + "|" + regexRegular + ")",
      regexPrivateUse = "(x(-[A-Za-z0-9]{1,8})+)",
      regexSingleton = "[0-9A-WY-Za-wy-z]",
      regexExtension = "(" + regexSingleton + "(-[A-Za-z0-9]{2,8})+)",
      regexVariant = "([A-Za-z0-9]{5,8}|[0-9][A-Za-z0-9]{3})",
      regexRegion = "([A-Za-z]{2}|[0-9]{3})",
      regexScript = "([A-Za-z]{4})",
      regexExtlang = "([A-Za-z]{3}(-[A-Za-z]{3}){0,2})",
      regexLanguage = "(([A-Za-z]{2,3}(-" + regexExtlang + ")?)|[A-Za-z]{4}|[A-Za-z]{5,8})",
      regexLangtag = "(" + regexLanguage + "(-" + regexScript + ")?" + "(-" + regexRegion + ")?" + "(-" + regexVariant + ")*" + "(-" + regexExtension + ")*" + "(-" + regexPrivateUse + ")?" + ")",
      regexLanguageTag = "^(" + regexGrandfathered + "|" + regexLangtag + "|" + regexPrivateUse + ")$",
      regex = new RegExp(regexLanguageTag),
      match;

  if ((match = regex.exec(locale)) !== null) {
    if (match.index === regex.lastIndex) {
      regex.lastIndex++;
    }
  }

  if (match === undefined || match === null) {
    throw new Error('unsupported locale');
  }

  if (match[6] !== undefined) {
    language = match[6];
    parts = language.split('-');

    if (parts.length > 1) {
      language = parts[0];
      extlang = parts[1];
    }
  }

  if (match[14] !== undefined) {
    region = match[14];
  }

  if (match[12] !== undefined) {
    script = match[12];
  }

  if (match[16] !== undefined) {
    variants = match[16];
  }

  return new Locale(language, region, script, variants, extlang);
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.I18n', Locale, parseLocale);


/***/ }),
/* 46 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Provider": function() { return /* binding */ Provider; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_basewithoptions_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(47);
/* harmony import */ var _locale_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(45);
/* harmony import */ var _translations_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(48);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }





/**
 * A provider makes a translation object available.
 *
 * You can call the method via the monster namespace `new Monster.I18n.Provider()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.I18n.Provider()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Provider} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/provider.js';
 * new Provider()
 * </script>
 * ```
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.I18n
 * @see {@link https://datatracker.ietf.org/doc/html/rfc3066}
 */

var Provider = /*#__PURE__*/function (_BaseWithOptions) {
  _inherits(Provider, _BaseWithOptions);

  var _super = _createSuper(Provider);

  function Provider() {
    _classCallCheck(this, Provider);

    return _super.apply(this, arguments);
  }

  _createClass(Provider, [{
    key: "getTranslations",
    value:
    /**
     * @param {Locale|string} locale
     * @return {Promise}
     */
    function getTranslations(locale) {
      return new Promise(function (resolve, reject) {
        try {
          resolve(new _translations_js__WEBPACK_IMPORTED_MODULE_3__.Translations(locale));
        } catch (e) {
          reject(e);
        }
      });
    }
  }]);

  return Provider;
}(_types_basewithoptions_js__WEBPACK_IMPORTED_MODULE_1__.BaseWithOptions);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.I18n', Provider);


/***/ }),
/* 47 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_3__.Monster; },
/* harmony export */   "BaseWithOptions": function() { return /* binding */ BaseWithOptions; }
/* harmony export */ });
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(21);
/* harmony import */ var _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4);
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }







/**
 * This is the base class with options from which some monster classes are derived.
 *
 * This class is actually only used as a base class.
 * 
 * However, you can also create an instance directly via the monster namespace `new Monster.Types.BaseWithOptions()`.
 *
 * ```html
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Types.BaseWithOptions()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```html
 * <script type="module">
 * import {BaseWithOptions} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/basewithoptions.js';
 * new BaseWithOptions()
 * </script>
 * ```
 * 
 * Classes that require the possibility of options can be derived directly from this class.
 * Derived classes almost always override the `defaul` getter with their own values.
 *
 * ```javascript
 * class My extends BaseWithOptions {
 *    get defaults() {
 *        return Object.assign({}, super.defaults, {
 *            mykey: true
 *        });
 *    }  
 * }
 * ```
 * 
 * The class was formerly called Object.
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 */

var BaseWithOptions = /*#__PURE__*/function (_Base) {
  _inherits(BaseWithOptions, _Base);

  var _super = _createSuper(BaseWithOptions);

  /**
   *
   * @param {object} options
   */
  function BaseWithOptions(options) {
    var _this;

    _classCallCheck(this, BaseWithOptions);

    _this = _super.call(this);

    if (options === undefined) {
      options = {};
    }

    _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol] = (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_1__.extend)({}, _this.defaults, (0,_validate_js__WEBPACK_IMPORTED_MODULE_5__.validateObject)(options));
    return _this;
  }
  /**
   * This getter provides the options. Derived classes overwrite 
   * this getter with their own values. It is good karma to always include 
   * the values from the parent class.
   * 
   * ```javascript
   * get defaults() {
   *     return Object.assign({}, super.defaults, {
   *         mykey: true
   *     });
   * }
   * 
   * ```
   *
   * @return {object}
   */


  _createClass(BaseWithOptions, [{
    key: "defaults",
    get: function get() {
      return {};
    }
    /**
     * nested options can be specified by path `a.b.c`
     *
     * @param {string} path
     * @param {*} defaultValue
     * @return {*}
     * @since 1.10.0
     */

  }, {
    key: "getOption",
    value: function getOption(path, defaultValue) {
      var value;

      try {
        value = new _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_2__.Pathfinder(this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]).getVia(path);
      } catch (e) {}

      if (value === undefined) return defaultValue;
      return value;
    }
  }]);

  return BaseWithOptions;
}(_base_js__WEBPACK_IMPORTED_MODULE_4__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_3__.assignToNamespace)('Monster.Types', BaseWithOptions);


/***/ }),
/* 48 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Translations": function() { return /* binding */ Translations; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14);
/* harmony import */ var _locale_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(45);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * With this class you can manage translations and access the keys.
 *
 * You can call the method via the monster namespace `new Monster.I18n.Translations()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.I18n.Translations()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Translations} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/translations.js';
 * new Translations()
 * </script>
 * ```
 *
 * @example
 *
 * import {Translations} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/translations.js';
 * import {parseLocale} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/locale.js';
 *
 * const translation = new Translations(parseLocale('en-GB'));
 *
 * translation.assignTranslations({
 *           text1: "click",
 *           text2: {
 *             'one': 'click once',
 *             'other': 'click n times'
 *           }
 *        });
 *
 * console.log(translation.getText('text1'));
 * // ↦ click
 *
 * console.log(translation.getPluralRuleText('text2',1));
 * // -> click once
 * console.log(translation.getPluralRuleText('text2',2));
 * // -> click n times
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.I18n
 * @see https://datatracker.ietf.org/doc/html/rfc3066
 */

var Translations = /*#__PURE__*/function (_Base) {
  _inherits(Translations, _Base);

  var _super = _createSuper(Translations);

  /**
   *
   * @param {Locale} locale
   */
  function Translations(locale) {
    var _this;

    _classCallCheck(this, Translations);

    _this = _super.call(this);

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isString)(locale)) {
      locale = (0,_locale_js__WEBPACK_IMPORTED_MODULE_4__.parseLocale)(locale);
    }

    _this.locale = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInstance)(locale, _locale_js__WEBPACK_IMPORTED_MODULE_4__.Locale);
    _this.storage = new Map();
    return _this;
  }
  /**
   * Fetches a text using the specified key.
   * If no suitable key is found, `defaultText` is taken.
   *
   * @param {string} key
   * @param {string|undefined} defaultText
   * @return {string}
   * @throws {Error} key not found
   */


  _createClass(Translations, [{
    key: "getText",
    value: function getText(key, defaultText) {
      if (!this.storage.has(key)) {
        if (defaultText === undefined) {
          throw new Error('key ' + key + ' not found');
        }

        return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(defaultText);
      }

      var r = this.storage.get(key);

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(r)) {
        return this.getPluralRuleText(key, 'other', defaultText);
      }

      return this.storage.get(key);
    }
    /**
     * A number `count` can be passed to this method. In addition to a number, one of the keywords can also be passed directly.
     * "zero", "one", "two", "few", "many" and "other". Remember: not every language has all rules.
     *
     * The appropriate text for this number is then selected. If no suitable key is found, `defaultText` is taken.
     *
     * @param {string} key
     * @param {integer|count} count
     * @param {string|undefined} defaultText
     * @return {string}
     */

  }, {
    key: "getPluralRuleText",
    value: function getPluralRuleText(key, count, defaultText) {
      if (!this.storage.has(key)) {
        return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(defaultText);
      }

      var r = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateObject)(this.storage.get(key));
      var keyword;

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isString)(count)) {
        keyword = count.toLocaleString();
      } else {
        count = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInteger)(count);

        if (count === 0) {
          // special handlig for zero count
          if (r.hasOwnProperty('zero')) {
            return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(r['zero']);
          }
        }

        keyword = new Intl.PluralRules(this.locale.toString()).select((0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateInteger)(count));
      }

      if (r.hasOwnProperty(keyword)) {
        return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(r[keyword]);
      }

      if (r.hasOwnProperty(DEFAULT_KEY)) {
        return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(r[DEFAULT_KEY]);
      }

      return (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(defaultText);
    }
    /**
     * Set a text for a key
     *
     * ```
     * translations.setText("text1": "Make my day!");
     * // plural rules
     * translations.setText("text6": {
     *     "zero": "There are no files on Disk.",
     *     "one": "There is one file on Disk.",
     *     "other": "There are files on Disk."
     *     "default": "There are files on Disk."
     * });
     * ```
     *
     * @param {string} key
     * @param {string|object} text
     * @return {Translations}
     * @throws {TypeError} value is not a string or object
     */

  }, {
    key: "setText",
    value: function setText(key, text) {
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isString)(text) || (0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isObject)(text)) {
        this.storage.set((0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateString)(key), text);
        return this;
      }

      throw new TypeError('value is not a string or object');
    }
    /**
     * This method can be used to transfer overlays from an object. The keys are transferred and the values are entered as text.
     *
     * The values can either be character strings or, in the case of texts with plural forms, objects. The plural forms must be stored as text via a standard key "zero", "one", "two", "few", "many" and "other".
     *
     * Additionally, the key default can be specified, which will be used if no other key fits.
     *
     * In some languages, like for example in german, there is no own more number at the value 0. In these languages the function applies additionally zero.
     *
     * ```
     * translations.assignTranslations({
     *   "text1": "Make my day!",
     *   "text2": "I'll be back!",
     *   "text6": {
     *     "zero": "There are no files on Disk.",
     *     "one": "There is one file on Disk.",
     *     "other": "There are files on Disk."
     *     "default": "There are files on Disk."
     * });
     * ```
     *
     * @param {object} translations
     * @return {Translations}
     */

  }, {
    key: "assignTranslations",
    value: function assignTranslations(translations) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_3__.validateObject)(translations);

      for (var _i = 0, _Object$entries = Object.entries(translations); _i < _Object$entries.length; _i++) {
        var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
            k = _Object$entries$_i[0],
            v = _Object$entries$_i[1];

        this.setText(k, v);
      }

      return this;
    }
  }]);

  return Translations;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.I18n', Translations);


/***/ }),
/* 49 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_2__.Monster; },
/* harmony export */   "Fetch": function() { return /* binding */ Fetch; }
/* harmony export */ });
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(21);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2);
/* harmony import */ var _text_formatter_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(50);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(16);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(14);
/* harmony import */ var _locale_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(45);
/* harmony import */ var _provider_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(46);
/* harmony import */ var _translations_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(48);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }











/**
 * The fetch provider retrieves a JSON file from the given URL and returns a translation object.
 *
 * You can create the object via the monster namespace `new Monster.I18n.Provider.Fetch()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.I18n.Providers.Fetch()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Fetch} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/providers/fetch.js';
 * new Fetch()
 * </script>
 * ```
 * 
 * @example <caption>das ist ein test</caption>
 * 
 * import {Fetch} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/i18n/providers/fetch.js';
 * 
 * // fetch from API
 * const translation = new Fetch('https://example.com/${language}.json').getTranslation('en-GB');
 * // ↦ https://example.com/en.json
 *
 * @since 1.13.0
 * @copyright schukai GmbH
 * @memberOf Monster.I18n.Providers
 * @see {@link https://datatracker.ietf.org/doc/html/rfc3066}
 * @tutorial i18n-locale-and-formatter
 */

var Fetch = /*#__PURE__*/function (_Provider) {
  _inherits(Fetch, _Provider);

  var _super = _createSuper(Fetch);

  /**
   * As options the key `fetch` can be passed. This config object is passed to the fetch method as init.
   * 
   * The url may contain placeholders (language, script, region, variants, extlang, privateUse), so you can specify one url for all translations.
   * 
   * ```
   * new Fetch('https://www.example.com/assets/${language}.json')
   * ```
   * 
   * @param {string|URL} url
   * @param {Object} options see {@link Monster.I18n.Providers.Fetch#defaults}
   * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/fetch}
   */
  function Fetch(url, options) {
    var _thisSuper, _this;

    _classCallCheck(this, Fetch);

    _this = _super.call(this, options);

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_5__.isInstance)(url, URL)) {
      url = url.toString();
    }

    if (options === undefined) {
      options = {};
    }

    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateString)(url);
    /**
     * @property {string}
     */

    _this.url = url;
    /**
     * @private
     * @property {Object} options
     */

    _this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol] = (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_1__.extend)({}, _get((_thisSuper = _assertThisInitialized(_this), _getPrototypeOf(Fetch.prototype)), "defaults", _thisSuper), _this.defaults, (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateObject)(options));
    return _this;
  }
  /**
   * Defaults
   *
   * @property {Object} fetch
   * @property {String} fetch.method=GET
   * @property {String} fetch.mode=cors
   * @property {String} fetch.cache=no-cache
   * @property {String} fetch.credentials=omit
   * @property {String} fetch.redirect=follow
   * @property {String} fetch.referrerPolicy=no-referrer
   *
   * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API}
   */


  _createClass(Fetch, [{
    key: "defaults",
    get: function get() {
      return {
        fetch: {
          method: 'GET',
          // *GET, POST, PUT, DELETE, etc.
          mode: 'cors',
          // no-cors, *cors, same-origin
          cache: 'no-cache',
          // *default, no-cache, reload, force-cache, only-if-cached
          credentials: 'omit',
          // include, *same-origin, omit
          redirect: 'follow',
          // manual, *follow, error
          referrerPolicy: 'no-referrer' // no-referrer, *no-referrer-when-downgrade, origin, origin-when-cross-origin, same-origin, strict-origin, strict-origin-when-cross-origin, unsafe-url

        }
      };
    }
    /**
     *
     * @param {Locale|string} locale
     * @return {Promise}
     */

  }, {
    key: "getTranslations",
    value: function getTranslations(locale) {
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_5__.isString)(locale)) {
        locale = (0,_locale_js__WEBPACK_IMPORTED_MODULE_7__.parseLocale)(locale);
      }

      var formatter = new _text_formatter_js__WEBPACK_IMPORTED_MODULE_3__.Formatter(locale.getMap());
      return (0,_types_global_js__WEBPACK_IMPORTED_MODULE_4__.getGlobalFunction)('fetch')(formatter.format(this.url), this.getOption('fetch', {})).then(function (response) {
        return response.json();
      }).then(function (data) {
        return new _translations_js__WEBPACK_IMPORTED_MODULE_9__.Translations(locale).assignTranslations(data);
      });
    }
  }]);

  return Fetch;
}(_provider_js__WEBPACK_IMPORTED_MODULE_8__.Provider);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_2__.assignToNamespace)('Monster.I18n.Providers', Fetch);


/***/ }),
/* 50 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_3__.Monster; },
/* harmony export */   "Formatter": function() { return /* binding */ Formatter; }
/* harmony export */ });
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(21);
/* harmony import */ var _data_pipe_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(22);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(2);
/* harmony import */ var _types_basewithoptions_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(47);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(9);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }








/**
 * @private
 * @type {symbol}
 */

var internalObjectSymbol = Symbol('internalObject');
/**
 * @private
 * @type {symbol}
 */

var watchdogSymbol = Symbol('watchdog');
/**
 * @private
 * @type {symbol}
 */

var markerOpenIndexSymbol = Symbol('markerOpenIndex');
/**
 * @private
 * @type {symbol}
 */

var markerCloseIndexSymbol = Symbol('markercloseIndex');
/**
 * @private
 * @type {symbol}
 */

var workingDataSymbol = Symbol('workingData');
/**
 * Messages can be formatted with the formatter. To do this, an object with the values must be passed to the formatter. The message can then contain placeholders.
 *
 * Look at the example below. The placeholders use the logic of Pipe.
 *
 * You can create an instance via the monster namespace `new Monster.Text.Formatter()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Text.Formatter()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Formatter} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/text/formatter.js';
 * new Formatter()
 * </script>
 * ```
 *
 * ## Marker in marker
 *
 * Markers can be nested. Here, the inner marker is resolved first `${subkey} ↦ 1 = ${mykey2}` and then the outer marker `${mykey2}`.
 *
 * ```
 * const text = '${mykey${subkey}}';
 * let obj = {
 *  mykey2: "1",
 *  subkey: "2"
 * };
 *
 * new Formatter(obj).format(text);
 * // ↦ 1
 * ```
 *
 * ## Callbacks
 *
 * The values in a formatter can be adjusted via the commands of the `Transformer` or the`Pipe`.
 * There is also the possibility to use callbacks.
 *
 * const formatter = new Formatter({x: '1'}, {
 *                callbacks: {
 *                    quote: (value) => {
 *                        return '"' + value + '"'
 *                    }
 *                }
 *            });
 *
 * formatter.format('${x | call:quote}'))
 * // ↦ "1"
 *
 * ## Marker with parameter
 *
 * A string can also bring its own values. These must then be separated from the key by a separator `::`.
 * The values themselves must be specified in key/value pairs. The key must be separated from the value by a separator `=`.
 *
 * When using a pipe, you must pay attention to the separators.
 *
 * @example
 *
 * import {Formatter} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/text/formatter.js';
 *
 * new Formatter({
 *       a: {
 *           b: {
 *               c: "Hello"
 *           },
 *           d: "world",
 *       }
 *   }).format("${a.b.c} ${a.d | ucfirst}!"); // with pipe
 *
 * // ↦ Hello World!
 *
 * @since 1.12.0
 * @copyright schukai GmbH
 * @memberOf Monster.Text
 */

var Formatter = /*#__PURE__*/function (_BaseWithOptions) {
  _inherits(Formatter, _BaseWithOptions);

  var _super = _createSuper(Formatter);

  /**
   * Default values for the markers are `${` and `}`
   *
   * @param {object} object
   * @throws {TypeError} value is not a object
   */
  function Formatter(object, options) {
    var _this;

    _classCallCheck(this, Formatter);

    _this = _super.call(this, options);
    _this[internalObjectSymbol] = object || {};
    _this[markerOpenIndexSymbol] = 0;
    _this[markerCloseIndexSymbol] = 0;
    return _this;
  }
  /**
   * @property {object} marker
   * @property {array} marker.open=["${"]
   * @property {array} marker.close=["${"]
   * @property {object} parameter
   * @property {string} parameter.delimiter="::"
   * @property {string} parameter.assignment="="
   * @property {object} callbacks={}
   */


  _createClass(Formatter, [{
    key: "defaults",
    get: function get() {
      return (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_1__.extend)({}, _get(_getPrototypeOf(Formatter.prototype), "defaults", this), {
        marker: {
          open: ['${'],
          close: ['}']
        },
        parameter: {
          delimiter: '::',
          assignment: '='
        },
        callbacks: {}
      });
    }
    /**
     * Set new Parameter Character
     *
     * Default values for the chars are `::` and `=`
     *
     * ```
     * formatter.setParameterChars('#');
     * formatter.setParameterChars('[',']');
     * formatter.setParameterChars('i18n{','}');
     * ```
     *
     * @param {string} delimiter
     * @param {string} assignment
     * @return {Formatter}
     * @since 1.24.0
     * @throws {TypeError} value is not a string
     */

  }, {
    key: "setParameterChars",
    value: function setParameterChars(delimiter, assignment) {
      if (delimiter !== undefined) {
        this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['parameter']['delimiter'] = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateString)(delimiter);
      }

      if (assignment !== undefined) {
        this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['parameter']['assignment'] = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateString)(assignment);
      }

      return this;
    }
    /**
     * Set new Marker
     *
     * Default values for the markers are `${` and `}`
     *
     * ```
     * formatter.setMarker('#'); // open and close are both #
     * formatter.setMarker('[',']');
     * formatter.setMarker('i18n{','}');
     * ```
     *
     * @param {array|string} open
     * @param {array|string|undefined} close
     * @return {Formatter}
     * @since 1.12.0
     * @throws {TypeError} value is not a string
     */

  }, {
    key: "setMarker",
    value: function setMarker(open, close) {
      if (close === undefined) {
        close = open;
      }

      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_5__.isString)(open)) open = [open];
      if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_5__.isString)(close)) close = [close];
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['marker']['open'] = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateArray)(open);
      this[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['marker']['close'] = (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateArray)(close);
      return this;
    }
    /**
     *
     * @param {string} text
     * @return {string}
     * @throws {TypeError} value is not a string
     * @throws {Error} too deep nesting
     */

  }, {
    key: "format",
    value: function format(text) {
      this[watchdogSymbol] = 0;
      this[markerOpenIndexSymbol] = 0;
      this[markerCloseIndexSymbol] = 0;
      this[workingDataSymbol] = {};
      return _format.call(this, text);
    }
  }]);

  return Formatter;
}(_types_basewithoptions_js__WEBPACK_IMPORTED_MODULE_4__.BaseWithOptions);
/**
 * @private
 * @return {string}
 */


function _format(text) {
  var _self$internalSymbol$, _self$internalSymbol$2, _self$internalSymbol$3, _self$internalSymbol$4;

  var self = this;
  self[watchdogSymbol]++;

  if (this[watchdogSymbol] > 20) {
    throw new Error('too deep nesting');
  }

  var openMarker = (_self$internalSymbol$ = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['marker']['open']) === null || _self$internalSymbol$ === void 0 ? void 0 : _self$internalSymbol$[this[markerOpenIndexSymbol]];
  var closeMarker = (_self$internalSymbol$2 = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['marker']['close']) === null || _self$internalSymbol$2 === void 0 ? void 0 : _self$internalSymbol$2[this[markerCloseIndexSymbol]]; // contains no placeholders

  if (text.indexOf(openMarker) === -1 || text.indexOf(closeMarker) === -1) {
    return text;
  }

  var result = tokenize.call(this, (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateString)(text), openMarker, closeMarker);

  if ((_self$internalSymbol$3 = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['marker']['open']) !== null && _self$internalSymbol$3 !== void 0 && _self$internalSymbol$3[this[markerOpenIndexSymbol] + 1]) {
    this[markerOpenIndexSymbol]++;
  }

  if ((_self$internalSymbol$4 = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['marker']['close']) !== null && _self$internalSymbol$4 !== void 0 && _self$internalSymbol$4[this[markerCloseIndexSymbol] + 1]) {
    this[markerCloseIndexSymbol]++;
  }

  result = _format.call(self, result);
  return result;
}
/**
 * @private
 * @since 1.12.0
 * @param text
 * @return {string}
 */


function tokenize(text, openMarker, closeMarker) {
  var self = this;
  var formatted = [];
  var parameterAssignment = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['parameter']['assignment'];
  var parameterDelimiter = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['parameter']['delimiter'];
  var callbacks = self[_constants_js__WEBPACK_IMPORTED_MODULE_0__.internalSymbol]['callbacks'];

  while (true) {
    var _self$workingDataSymb;

    var startIndex = text.indexOf(openMarker); // no marker 

    if (startIndex === -1) {
      formatted.push(text);
      break;
    } else if (startIndex > 0) {
      formatted.push(text.substring(0, startIndex));
      text = text.substring(startIndex);
    }

    var endIndex = text.substring(openMarker.length).indexOf(closeMarker);
    if (endIndex !== -1) endIndex += openMarker.length;
    var insideStartIndex = text.substring(openMarker.length).indexOf(openMarker);

    if (insideStartIndex !== -1) {
      insideStartIndex += openMarker.length;

      if (insideStartIndex < endIndex) {
        var result = tokenize.call(self, text.substring(insideStartIndex), openMarker, closeMarker);
        text = text.substring(0, insideStartIndex) + result;
        endIndex = text.substring(openMarker.length).indexOf(closeMarker);
        if (endIndex !== -1) endIndex += openMarker.length;
      }
    }

    if (endIndex === -1) {
      throw new Error("syntax error in formatter template");
      return;
    }

    var key = text.substring(openMarker.length, endIndex);
    var parts = key.split(parameterDelimiter);
    var currentPipe = parts.shift();
    self[workingDataSymbol] = (0,_data_extend_js__WEBPACK_IMPORTED_MODULE_1__.extend)({}, self[internalObjectSymbol], self[workingDataSymbol]);

    var _iterator = _createForOfIteratorHelper(parts),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var kv = _step.value;

        var _kv$split = kv.split(parameterAssignment),
            _kv$split2 = _slicedToArray(_kv$split, 2),
            k = _kv$split2[0],
            v = _kv$split2[1];

        self[workingDataSymbol][k] = v;
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    var t1 = key.split('|').shift().trim(); // pipe symbol

    var t2 = t1.split('::').shift().trim(); // key value delimiter

    var t3 = t2.split('.').shift().trim(); // path delimiter

    var prefix = (_self$workingDataSymb = self[workingDataSymbol]) !== null && _self$workingDataSymb !== void 0 && _self$workingDataSymb[t3] ? 'path:' : 'static:';
    var command = "";

    if (prefix && key.indexOf(prefix) !== 0 && key.indexOf('path:') !== 0 && key.indexOf('static:') !== 0) {
      command = prefix;
    }

    command += currentPipe;
    var pipe = new _data_pipe_js__WEBPACK_IMPORTED_MODULE_2__.Pipe(command);

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_5__.isObject)(callbacks)) {
      for (var _i = 0, _Object$entries = Object.entries(callbacks); _i < _Object$entries.length; _i++) {
        var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
            name = _Object$entries$_i[0],
            callback = _Object$entries$_i[1];

        pipe.setCallback(name, callback);
      }
    }

    formatted.push((0,_types_validate_js__WEBPACK_IMPORTED_MODULE_6__.validateString)(pipe.run(self[workingDataSymbol])));
    text = text.substring(endIndex + closeMarker.length);
  }

  return formatted.join('');
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_3__.assignToNamespace)('Monster.Text', Formatter);


/***/ }),
/* 51 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Handler": function() { return /* binding */ Handler; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);
/* harmony import */ var _logentry_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(52);
/* harmony import */ var _logger_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(53);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * you can call the method via the monster namespace `new Monster.Logging.Handler()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Logging.Handler())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {ID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/logging/handler.js';
 * console.log(new Handler())
 * </script>
 * ```
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Logging
 */

var Handler = /*#__PURE__*/function (_Base) {
  _inherits(Handler, _Base);

  var _super = _createSuper(Handler);

  function Handler() {
    var _this;

    _classCallCheck(this, Handler);

    _this = _super.call(this);
    /**
     * Loglevel
     *
     * @type {integer}
     */

    _this.loglevel = _logger_js__WEBPACK_IMPORTED_MODULE_4__.OFF;
    return _this;
  }
  /**
   * This is the central log function. this method must be
   * overwritten by derived handlers with their own logic.
   *
   * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
   *
   * @param {LogEntry} entry
   * @returns {boolean}
   */


  _createClass(Handler, [{
    key: "log",
    value: function log(entry) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateInstance)(entry, _logentry_js__WEBPACK_IMPORTED_MODULE_3__.LogEntry);

      if (this.loglevel < entry.getLogLevel()) {
        return false;
      }

      return true;
    }
    /**
     * set loglevel
     *
     * @param {integer} loglevel
     * @returns {Handler}
     * @since 1.5.0
     */

  }, {
    key: "setLogLevel",
    value: function setLogLevel(loglevel) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateInteger)(loglevel);
      this.loglevel = loglevel;
      return this;
    }
    /**
     * get loglevel
     *
     * @returns {integer}
     * @since 1.5.0
     */

  }, {
    key: "getLogLevel",
    value: function getLogLevel() {
      return this.loglevel;
    }
    /**
     *  Set log level to All
     *
     * @returns {Handler}
     * @since 1.5.0
     */

  }, {
    key: "setAll",
    value: function setAll() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.ALL);
      return this;
    }
  }, {
    key: "setTrace",
    value:
    /**
     * Set log level to Trace
     *
     * @returns {Handler}
     * @since 1.5.0
     */
    function setTrace() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.TRACE);
      return this;
    }
  }, {
    key: "setDebug",
    value:
    /**
     * Set log level to Debug
     *
     * @returns {Handler}
     * @since 1.5.0
     */
    function setDebug() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.DEBUG);
      return this;
    }
  }, {
    key: "setInfo",
    value:
    /**
     * Set log level to Info
     *
     * @returns {Handler}
     * @since 1.5.0
     */
    function setInfo() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.INFO);
      return this;
    }
  }, {
    key: "setWarn",
    value:
    /**
     * Set log level to Warn
     *
     * @returns {undefined}
     * @since 1.5.0
     */
    function setWarn() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.WARN);
      return this;
    }
  }, {
    key: "setError",
    value:
    /**
     * Set log level to Error
     *
     * @returns {Handler}
     * @since 1.5.0
     */
    function setError() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.ERROR);
      return this;
    }
  }, {
    key: "setFatal",
    value:
    /**
     * Set log level to Fatal
     *
     * @returns {Handler}
     * @since 1.5.0
     */
    function setFatal() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.FATAL);
      return this;
    }
  }, {
    key: "setOff",
    value:
    /**
     * Set log level to Off
     *
     * @returns {Handler}
     * @since 1.5.0
     */
    function setOff() {
      this.setLogLevel(_logger_js__WEBPACK_IMPORTED_MODULE_4__.OFF);
      return this;
    }
  }]);

  return Handler;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Logging', Handler);


/***/ }),
/* 52 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "LogEntry": function() { return /* binding */ LogEntry; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }




/**
 * you can call the method via the monster namespace `new Monster.Logging.LogEntry()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Logging.LogEntry())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {ID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/logging/logentry.js';
 * console.log(new LogEntry())
 * </script>
 * ```
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Logging
 */

var LogEntry = /*#__PURE__*/function (_Base) {
  _inherits(LogEntry, _Base);

  var _super = _createSuper(LogEntry);

  /**
   *
   * @param {Integer} loglevel
   * @param {...*} args
   */
  function LogEntry(loglevel) {
    var _this;

    _classCallCheck(this, LogEntry);

    _this = _super.call(this);
    (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_2__.validateInteger)(loglevel);
    _this.loglevel = loglevel;

    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    _this.arguments = args;
    return _this;
  }
  /**
   *
   * @returns {integerr}
   */


  _createClass(LogEntry, [{
    key: "getLogLevel",
    value: function getLogLevel() {
      return this.loglevel;
    }
    /**
     *
     * @returns {array}
     */

  }, {
    key: "getArguments",
    value: function getArguments() {
      return this.arguments;
    }
  }]);

  return LogEntry;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Logging', LogEntry);


/***/ }),
/* 53 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_2__.Monster; },
/* harmony export */   "Logger": function() { return /* binding */ Logger; },
/* harmony export */   "ALL": function() { return /* binding */ ALL; },
/* harmony export */   "TRACE": function() { return /* binding */ TRACE; },
/* harmony export */   "DEBUG": function() { return /* binding */ DEBUG; },
/* harmony export */   "INFO": function() { return /* binding */ INFO; },
/* harmony export */   "WARN": function() { return /* binding */ WARN; },
/* harmony export */   "ERROR": function() { return /* binding */ ERROR; },
/* harmony export */   "FATAL": function() { return /* binding */ FATAL; },
/* harmony export */   "OFF": function() { return /* binding */ OFF; }
/* harmony export */ });
/* harmony import */ var _logging_handler_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(51);
/* harmony import */ var _logging_logentry_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(52);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var ALL = 255;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var TRACE = 64;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var DEBUG = 32;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var INFO = 16;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var WARN = 8;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var ERROR = 4;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var FATAL = 2;
/**
 * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF
 * @type {number}
 * @memberOf Monster.Logging
 */

var OFF = 0;
/**
 * You can create an object of the class simply by using the namespace `new Monster.Logging.Logger()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Logging.Logger()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this class individually.
 *
 * ```
 * <script type="module">
 * import {ID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/logging/logger.js';
 * new Logger()
 * </script>
 * ```
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Logging
 */

var Logger = /*#__PURE__*/function (_Base) {
  _inherits(Logger, _Base);

  var _super = _createSuper(Logger);

  /**
   *
   */
  function Logger() {
    var _this;

    _classCallCheck(this, Logger);

    _this = _super.call(this);
    _this.handler = new Set();
    return _this;
  }
  /**
   *
   * @param {Handler} handler
   * @returns {Logger}
   * @throws {Error} the handler must be an instance of Handler
   */


  _createClass(Logger, [{
    key: "addHandler",
    value: function addHandler(handler) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateObject)(handler);

      if (!(handler instanceof _logging_handler_js__WEBPACK_IMPORTED_MODULE_0__.Handler)) {
        throw new Error("the handler must be an instance of Handler");
      }

      this.handler.add(handler);
      return this;
    }
    /**
     *
     * @param {Handler} handler
     * @returns {Logger}
     * @throws {Error} the handler must be an instance of Handler
     */

  }, {
    key: "removeHandler",
    value: function removeHandler(handler) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateObject)(handler);

      if (!(handler instanceof _logging_handler_js__WEBPACK_IMPORTED_MODULE_0__.Handler)) {
        throw new Error("the handler must be an instance of Handler");
      }

      this.handler.delete(handler);
      return this;
    }
    /**
     * log Trace message
     *
     * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
     *
     * @param {*} arguments
     * @returns {Logger}
     * @since 1.5.0
     */

  }, {
    key: "logTrace",
    value: function logTrace() {
      triggerLog.apply(this, [TRACE].concat(Array.prototype.slice.call(arguments)));
      return this;
    }
  }, {
    key: "logDebug",
    value:
    /**
     * log Debug message
     *
     * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
     *
     * @param {*} arguments
     * @returns {Logger}
     * @since 1.5.0
     */
    function logDebug() {
      triggerLog.apply(this, [DEBUG].concat(Array.prototype.slice.call(arguments)));
      return this;
    }
  }, {
    key: "logInfo",
    value:
    /**
     * log Info message
     *
     * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
     *
     *
     * @param {*} arguments
     * @returns {Logger}
     * @since 1.5.0
     */
    function logInfo() {
      triggerLog.apply(this, [INFO].concat(Array.prototype.slice.call(arguments)));
      return this;
    }
  }, {
    key: "logWarn",
    value:
    /**
     * log Warn message
     *
     * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
     *
     * @param {*} arguments
     * @returns {Logger}
     * @since 1.5.0
     */
    function logWarn() {
      triggerLog.apply(this, [WARN].concat(Array.prototype.slice.call(arguments)));
      return this;
    }
  }, {
    key: "logError",
    value:
    /**
     * log Error message
     *
     * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
     *
     * @param {*} arguments
     * @returns {Logger}
     * @since 1.5.0
     */
    function logError() {
      triggerLog.apply(this, [ERROR].concat(Array.prototype.slice.call(arguments)));
      return this;
    }
  }, {
    key: "logFatal",
    value:
    /**
     * log Fatal message
     *
     * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
     *
     * @param {*} arguments
     * @returns {Logger}
     * @since 1.5.0
     */
    function logFatal() {
      triggerLog.apply(this, [FATAL].concat(Array.prototype.slice.call(arguments)));
      return this;
    }
  }, {
    key: "getLabel",
    value:
    /**
     * Labels
     *
     * @param {integer} level
     * @returns {string}
     */
    function getLabel(level) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateInteger)(level);
      if (level === ALL) return 'ALL';
      if (level === TRACE) return 'TRACE';
      if (level === DEBUG) return 'DEBUG';
      if (level === INFO) return 'INFO';
      if (level === WARN) return 'WARN';
      if (level === ERROR) return 'ERROR';
      if (level === FATAL) return 'FATAL';
      if (level === OFF) return 'OFF';
      return 'unknown';
    }
  }, {
    key: "getLevel",
    value:
    /**
     * Level
     *
     * @param {string} label
     * @returns {integer}
     */
    function getLevel(label) {
      (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_4__.validateString)(label);
      if (label === 'ALL') return ALL;
      if (label === 'TRACE') return TRACE;
      if (label === 'DEBUG') return DEBUG;
      if (label === 'INFO') return INFO;
      if (label === 'WARN') return WARN;
      if (label === 'ERROR') return ERROR;
      if (label === 'FATAL') return FATAL;
      if (label === 'OFF') return OFF;
      return 0;
    }
  }]);

  return Logger;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_3__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_2__.assignToNamespace)('Monster.Logging', Logger);

/**
 * Log triggern
 *
 * @param {integer} loglevel
 * @param {*} args
 * @returns {Logger}
 * @private
 */

function triggerLog(loglevel) {
  var logger = this;

  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  var _iterator = _createForOfIteratorHelper(logger.handler),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var handler = _step.value;
      handler.log(new _logging_logentry_js__WEBPACK_IMPORTED_MODULE_1__.LogEntry(loglevel, args));
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  return logger;
}

/***/ }),
/* 54 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "ConsoleHandler": function() { return /* binding */ ConsoleHandler; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(16);
/* harmony import */ var _handler_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(51);
/* harmony import */ var _logentry_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(52);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _get(target, property, receiver) { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }






/**
 * You can create an object of the class simply by using the namespace `new Monster.Logging.Handler.ConsoleHandler()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Logging.Handler.ConsoleHandler())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this class individually.
 *
 * ```
 * <script type="module">
 * import {ConsoleHandler} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/logging/handler/console.js';
 * console.log(new ConsoleHandler())
 * </script>
 * ```
 *
 * @since 1.5.0
 * @copyright schukai GmbH
 * @memberOf Monster.Logging.Handler
 */

var ConsoleHandler = /*#__PURE__*/function (_Handler) {
  _inherits(ConsoleHandler, _Handler);

  var _super = _createSuper(ConsoleHandler);

  function ConsoleHandler() {
    _classCallCheck(this, ConsoleHandler);

    return _super.call(this);
  }
  /**
   * This is the central log function. this method must be
   * overwritten by derived handlers with their own logic.
   *
   * ALL > TRACE > DEBUG > INFO > WARN > ERROR > FATAL > OFF  (ALL = 0xff;OFF = 0x00;
   *
   * @param {LogEntry} entry
   * @returns {boolean}
   */


  _createClass(ConsoleHandler, [{
    key: "log",
    value: function log(entry) {
      if (_get(_getPrototypeOf(ConsoleHandler.prototype), "log", this).call(this, entry)) {
        var console = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobalObject)('console');
        if (!console) return false;
        console.log(entry.toString());
        return true;
      }

      return false;
    }
  }]);

  return ConsoleHandler;
}(_handler_js__WEBPACK_IMPORTED_MODULE_3__.Handler);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Logging.Handler', ConsoleHandler);


/***/ }),
/* 55 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "random": function() { return /* binding */ random; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(16);

/**
 * @author schukai GmbH
 */



/**
 * this function uses crypt and returns a random number.
 *
 * you can call the method via the monster namespace `Monster.Math.random()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Math.random(1,10)
 * // ↦ 5
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {random} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/math/random.js';
 * random(1,10)
 * // ↦ 5
 * </script>
 * ```
 *
 * @param {number} min starting value of the definition set (default is 0)
 * @param {number} max end value of the definition set (default is 1000000000)
 * @returns {number}
 * @memberOf Monster.Math
 * @throws {Error} missing crypt
 * @throws {Error} we cannot generate numbers larger than 53 bits.
 * @throws {Error} the distance is too small to create a random number.

 * @since 1.0.0
 * @copyright schukai GmbH
 */

function random(min, max) {
  if (min === undefined) {
    min = 0;
  }

  if (max === undefined) {
    max = MAX;
  }

  if (max < min) {
    throw new Error("max must be greater than min");
  }

  return Math.round(create(min, max));
}
/**
 * @private
 * @type {number}
 */


var MAX = 1000000000;

Math.log2 = Math.log2 || function (n) {
  return Math.log(n) / Math.log(2);
};
/**
 *
 * @param {number} min
 * @param {number} max
 * @returns {number}
 * @private
 * @throws {Error} missing crypt
 * @throws {Error} we cannot generate numbers larger than 53 bits.
 * @throws {Error} the distance is too small to create a random number.
 */


function create(min, max) {
  var crypt;
  var globalReference = (0,_types_global_js__WEBPACK_IMPORTED_MODULE_1__.getGlobal)();
  crypt = (globalReference === null || globalReference === void 0 ? void 0 : globalReference['crypto']) || (globalReference === null || globalReference === void 0 ? void 0 : globalReference['msCrypto']) || (globalReference === null || globalReference === void 0 ? void 0 : globalReference['crypto']) || undefined;

  if (typeof crypt === "undefined") {
    throw new Error("missing crypt");
  }

  var rval = 0;
  var range = max - min;

  if (range < 2) {
    throw new Error('the distance is too small to create a random number.');
  }

  var bitsNeeded = Math.ceil(Math.log2(range));

  if (bitsNeeded > 53) {
    throw new Error("we cannot generate numbers larger than 53 bits.");
  }

  var bytesNeeded = Math.ceil(bitsNeeded / 8);
  var mask = Math.pow(2, bitsNeeded) - 1;
  var byteArray = new Uint8Array(bytesNeeded);
  crypt.getRandomValues(byteArray);
  var p = (bytesNeeded - 1) * 8;

  for (var i = 0; i < bytesNeeded; i++) {
    rval += byteArray[i] * Math.pow(2, p);
    p -= 8;
  }

  rval = rval & mask;

  if (rval >= range) {
    return create(min, max);
  }

  if (rval < min) {
    rval += min;
  }

  return rval;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Math', random);


/***/ }),
/* 56 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_1__.Monster; },
/* harmony export */   "RandomID": function() { return /* binding */ RandomID; }
/* harmony export */ });
/* harmony import */ var _math_random_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(55);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2);
/* harmony import */ var _global_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(16);
/* harmony import */ var _id_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(24);


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }


/**
 * @author schukai GmbH
 */




/**
 * @private
 * @type {number}
 */

var internalCounter = 0;
/**
 * You can call the method via the monster namespace `new Monster.Types.RandomID()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Types.RandomID())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {RandomID} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/randomid.js';
 * console.log(new RandomID())
 * </script>
 * ```
 *
 * @since 1.6.0
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @summary class to generate random numbers
 */

var RandomID = /*#__PURE__*/function (_ID) {
  _inherits(RandomID, _ID);

  var _super = _createSuper(RandomID);

  /**
   * create new object
   */
  function RandomID() {
    var _this;

    _classCallCheck(this, RandomID);

    _this = _super.call(this);
    internalCounter += 1;
    _this.id = (0,_global_js__WEBPACK_IMPORTED_MODULE_2__.getGlobal)().btoa((0,_math_random_js__WEBPACK_IMPORTED_MODULE_0__.random)(1, 10000)).replace(/=/g, '')
    /** No numbers at the beginning of the ID, because of possible problems with DOM */
    .replace(/^[0-9]+/, 'X') + internalCounter;
    return _this;
  }

  return _createClass(RandomID);
}(_id_js__WEBPACK_IMPORTED_MODULE_3__.ID);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_1__.assignToNamespace)('Monster.Types', RandomID);


/***/ }),
/* 57 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Version": function() { return /* binding */ Version; },
/* harmony export */   "getVersion": function() { return /* binding */ getVersion; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }



/**
 * The version object contains a sematic version number
 *
 * You can create the object via the monster namespace `new Monster.Types.Version()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(new Monster.Types.Version('1.2.3')) // ↦ 1.2.3
 * console.log(new Monster.Types.Version('1')) // ↦ 1.0.0
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this class individually.
 *
 * ```
 * <script type="module">
 * import {Version} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/version.js';
 * console.log(new Version('1.2.3')) // ↦ 1.2.3
 * console.log(new Version('1')) // ↦ 1.0.0
 * </script>
 * ```
 *
 * @example
 *
 * import {Version} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/version.js';
 *
 * new Version('1.0.0') // ↦ 1.0.0
 * new Version(1)  // ↦ 1.0.0
 * new Version(1, 0, 0) // ↦ 1.0.0
 * new Version('1.2.3', 4, 5) // ↦ 1.4.5
 *
 * @since 1.0.0
 * @author schukai GmbH
 * @copyright schukai GmbH
 * @memberOf Monster.Types
 * @summary The version object contains a sematic version number
 */

var Version = /*#__PURE__*/function (_Base) {
  _inherits(Version, _Base);

  var _super = _createSuper(Version);

  /**
   *
   * @param major
   * @param minor
   * @param patch
   * @throws {Error} major is not a number
   * @throws {Error} minor is not a number
   * @throws {Error} patch is not a number
   */
  function Version(major, minor, patch) {
    var _this;

    _classCallCheck(this, Version);

    _this = _super.call(this);

    if (typeof major === 'string' && minor === undefined && patch === undefined) {
      var parts = major.toString().split('.');
      major = parseInt(parts[0] || 0);
      minor = parseInt(parts[1] || 0);
      patch = parseInt(parts[2] || 0);
    }

    if (major === undefined) {
      throw new Error("major version is undefined");
    }

    if (minor === undefined) {
      minor = 0;
    }

    if (patch === undefined) {
      patch = 0;
    }

    _this.major = parseInt(major);
    _this.minor = parseInt(minor);
    _this.patch = parseInt(patch);

    if (isNaN(_this.major)) {
      throw new Error("major is not a number");
    }

    if (isNaN(_this.minor)) {
      throw new Error("minor is not a number");
    }

    if (isNaN(_this.patch)) {
      throw new Error("patch is not a number");
    }

    return _this;
  }
  /**
   *
   * @returns {string}
   */


  _createClass(Version, [{
    key: "toString",
    value: function toString() {
      return this.major + '.' + this.minor + '.' + this.patch;
    }
    /**
     * returns 0 if equal, -1 if the object version is less and 1 if greater
     * then the compared version
     *
     * @param {string|Version} version Version to compare
     * @returns {number}
     */

  }, {
    key: "compareTo",
    value: function compareTo(version) {
      if (version instanceof Version) {
        version = version.toString();
      }

      if (typeof version !== 'string') {
        throw new Error("type exception");
      }

      if (version === this.toString()) {
        return 0;
      }

      var a = [this.major, this.minor, this.patch];
      var b = version.split('.');
      var len = Math.max(a.length, b.length);

      for (var i = 0; i < len; i += 1) {
        if (a[i] && !b[i] && parseInt(a[i]) > 0 || parseInt(a[i]) > parseInt(b[i])) {
          return 1;
        } else if (b[i] && !a[i] && parseInt(b[i]) > 0 || parseInt(a[i]) < parseInt(b[i])) {
          return -1;
        }
      }

      return 0;
    }
  }]);

  return Version;
}(_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Types', Version);
var monsterVersion;
/**
 * Version of monster
 *
 * You can call the method via the monster namespace `Monster.getVersion()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * console.log(Monster.getVersion())
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {getVersion} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/types/version.js';
 * console.log(getVersion())
 * </script>
 * ```
 *
 * @returns {Monster.Types.Version}
 * @since 1.0.0
 * @copyright schukai GmbH
 * @author schukai GmbH
 * @memberOf Monster
 */

function getVersion() {
  if (monsterVersion instanceof Version) {
    return monsterVersion;
  }
  /**#@+ dont touch, replaced by make with package.json version */


  monsterVersion = new Version('1.30.0');
  /**#@-*/

  return monsterVersion;
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster', getVersion);


/***/ }),
/* 58 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "Comparator": function() { return /* binding */ Comparator; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }




/**
 * The comparator allows a comparison function to be abstracted.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * new Monster.Util.Comparator()
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {Comparator} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/util/comparator.js';
 * console.log(new Comparator())
 * </script>
 * ```
 *
 * The following are some examples of the application of the class.
 *
 * ```
 * new Comparator().lessThanOrEqual(2, 5) // ↦ true
 * new Comparator().greaterThan(4, 2) // ↦ true
 * new Comparator().equal(4, 4) // ↦ true
 * new Comparator().equal(4, 5) // ↦ false
 * ```
 *
 * You can also pass your own comparison function, and thus define the comparison function.
 *
 * ```
 * new Comparator(function (a, b) {
 *      if (a.v === b.v) return 0;
 *         return a.v < b.v ? -1 : 1;
 *      }).equal({v: 2}, {v: 2});  // ↦ true
 * ```
 *
 * @example
 *
 * import {Comparator} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/util/comparator.js';
 *
 * console.log(new Comparator().lessThanOrEqual(2, 5))
 * // ↦ true
 * console.log(new Comparator().greaterThan(4, 2))
 * // ↦ true
 * console.log(new Comparator().equal(4, 4))
 * // ↦ true
 * console.log(new Comparator().equal(4, 5))
 * // ↦ false
 *
 * @since 1.3.0
 * @memberOf Monster.Util
 */

var Comparator = /*#__PURE__*/function (_Base) {
  _inherits(Comparator, _Base);

  var _super = _createSuper(Comparator);

  /**
   * create new comparator
   *
   * @param {Monster.Util~exampleCallback} [callback] Comparator callback
   * @throw {TypeError} unsupported type
   * @throw {TypeError} impractical comparison
   */
  function Comparator(callback) {
    var _this;

    _classCallCheck(this, Comparator);

    _this = _super.call(this);

    if ((0,_types_is_js__WEBPACK_IMPORTED_MODULE_2__.isFunction)(callback)) {
      _this.compare = callback;
    } else if (callback !== undefined) {
      throw new TypeError("unsupported type");
    } else {
      // default compare function

      /**
       *
       * @param {*} a
       * @param {*} b
       * @return {integer} -1, 0 or 1
       */
      _this.compare = function (a, b) {
        if (_typeof(a) !== _typeof(b)) {
          throw new TypeError("impractical comparison", "types/comparator.js");
        }

        if (a === b) {
          return 0;
        }

        return a < b ? -1 : 1;
      };
    }

    return _this;
  }
  /**
   * changes the order of the operators
   *
   * @return {Comparator}
   */


  _createClass(Comparator, [{
    key: "reverse",
    value: function reverse() {
      var original = this.compare;

      this.compare = function (a, b) {
        return original(b, a);
      };

      return this;
    }
    /**
     * Checks if two variables are equal.
     *
     * @param {*} a
     * @param {*} b
     *
     * @return {boolean}
     */

  }, {
    key: "equal",
    value: function equal(a, b) {
      return this.compare(a, b) === 0;
    }
    /**
     * Checks if variable `a` is greater than `b`
     *
     * @param {*} a
     * @param {*} b
     *
     * @return {boolean}
     */

  }, {
    key: "greaterThan",
    value: function greaterThan(a, b) {
      return this.compare(a, b) > 0;
    }
    /**
     * Checks if variable `a` is greater than or equal to `b`
     *
     * @param {*} a
     * @param {*} b
     *
     * @return {boolean}
     */

  }, {
    key: "greaterThanOrEqual",
    value: function greaterThanOrEqual(a, b) {
      return this.greaterThan(a, b) || this.equal(a, b);
    }
    /**
     * Checks if variable `a` is less than or equal to `b`
     *
     * @param {*} a
     * @param {*} b
     *
     * @return {boolean}
     */

  }, {
    key: "lessThanOrEqual",
    value: function lessThanOrEqual(a, b) {
      return this.lessThan(a, b) || this.equal(a, b);
    }
    /**
     * Checks if variable a is less than b
     *
     * @param {*} a
     * @param {*} b
     *
     * @return {boolean}
     */

  }, {
    key: "lessThan",
    value: function lessThan(a, b) {
      return this.compare(a, b) < 0;
    }
  }]);

  return Comparator;
}(_types_base_js__WEBPACK_IMPORTED_MODULE_1__.Base);
/**
 * This is the description for the callback function used by the operator
 *
 * ```
 * new Comparator(function (a, b) {
 *      if (a.v === b.v) return 0;
 *         return a.v < b.v ? -1 : 1;
 *      }).equal({v: 2}, {v: 2});  // ↦ true
 * ```
 *
 * @callback Monster.Util~exampleCallback
 * @param {*} a
 * @param {*} b
 * @return {integer} -1, 0 or 1
 * @memberOf Monster.Util
 * @see Monster.Util.Comparator
 */

/**
 *
 */


(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Util', Comparator);


/***/ }),
/* 59 */
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_0__.Monster; },
/* harmony export */   "deepFreeze": function() { return /* binding */ deepFreeze; }
/* harmony export */ });
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(14);

/**
 * @author schukai GmbH
 */

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }



/**
 * Deep freeze a object
 *
 * You can call the method via the monster namespace `Monster.Util.deepFreeze()`.
 *
 * ```
 * <script type="module">
 * import {Monster} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/monster.js';
 * Monster.Util.deepFreeze({})
 * </script>
 * ```
 *
 * Alternatively, you can also integrate this function individually.
 *
 * ```
 * <script type="module">
 * import {deepFreeze} from 'https://cdn.jsdelivr.net/npm/@schukai/monster@1.30.0/dist/modules/util/freeze.js';
 * deepFreeze({})
 * </script>
 * ```
 *
 * @param {object} object object to be freeze
 * @since 1.0.0
 * @returns {object}
 * @memberOf Monster.Util
 * @copyright schukai GmbH
 * @throws {TypeError} value is not a object
 */

function deepFreeze(object) {
  (0,_types_validate_js__WEBPACK_IMPORTED_MODULE_1__.validateObject)(object); // Retrieve the defined property names of the object

  var propNames = Object.getOwnPropertyNames(object); // Freeze properties before freezing yourself

  var _iterator = _createForOfIteratorHelper(propNames),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var name = _step.value;
      var value = object[name];
      object[name] = value && _typeof(value) === "object" ? deepFreeze(value) : value;
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  return Object.freeze(object);
}

(0,_namespace_js__WEBPACK_IMPORTED_MODULE_0__.assignToNamespace)('Monster.Util', deepFreeze);


/***/ })
/******/ 	]);
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId](module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/define property getters */
/******/ 	!function() {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = function(exports, definition) {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	!function() {
/******/ 		__webpack_require__.o = function(obj, prop) { return Object.prototype.hasOwnProperty.call(obj, prop); }
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	!function() {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = function(exports) {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	}();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// This entry need to be wrapped in an IIFE because it need to be isolated against other modules in the chunk.
!function() {
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Monster": function() { return /* reexport safe */ _namespace_js__WEBPACK_IMPORTED_MODULE_35__.Monster; }
/* harmony export */ });
/* harmony import */ var _constants_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _constraints_abstract_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(3);
/* harmony import */ var _constraints_abstractoperator_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(5);
/* harmony import */ var _constraints_andoperator_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(6);
/* harmony import */ var _constraints_invalid_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7);
/* harmony import */ var _constraints_isarray_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(8);
/* harmony import */ var _constraints_isobject_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(10);
/* harmony import */ var _constraints_oroperator_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(11);
/* harmony import */ var _constraints_valid_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(12);
/* harmony import */ var _data_buildmap_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(13);
/* harmony import */ var _data_diff_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(20);
/* harmony import */ var _data_extend_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(21);
/* harmony import */ var _data_pathfinder_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(18);
/* harmony import */ var _data_pipe_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(22);
/* harmony import */ var _data_transformer_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(23);
/* harmony import */ var _dom_assembler_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(25);
/* harmony import */ var _dom_attributes_js__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(32);
/* harmony import */ var _dom_constants_js__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(33);
/* harmony import */ var _dom_customcontrol_js__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(34);
/* harmony import */ var _dom_customelement_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(35);
/* harmony import */ var _dom_events_js__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(42);
/* harmony import */ var _dom_locale_js__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(44);
/* harmony import */ var _dom_template_js__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(38);
/* harmony import */ var _dom_theme_js__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(39);
/* harmony import */ var _dom_updater_js__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(40);
/* harmony import */ var _dom_util_js__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(43);
/* harmony import */ var _i18n_locale_js__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(45);
/* harmony import */ var _i18n_provider_js__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(46);
/* harmony import */ var _i18n_providers_fetch_js__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(49);
/* harmony import */ var _i18n_translations_js__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(48);
/* harmony import */ var _logging_handler_js__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(51);
/* harmony import */ var _logging_handler_console_js__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(54);
/* harmony import */ var _logging_logentry_js__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(52);
/* harmony import */ var _logging_logger_js__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(53);
/* harmony import */ var _math_random_js__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(55);
/* harmony import */ var _namespace_js__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(2);
/* harmony import */ var _text_formatter_js__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(50);
/* harmony import */ var _types_base_js__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(4);
/* harmony import */ var _types_basewithoptions_js__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(47);
/* harmony import */ var _types_global_js__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(16);
/* harmony import */ var _types_id_js__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(24);
/* harmony import */ var _types_is_js__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(9);
/* harmony import */ var _types_observer_js__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(27);
/* harmony import */ var _types_observerlist_js__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(31);
/* harmony import */ var _types_proxyobserver_js__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(26);
/* harmony import */ var _types_queue_js__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(30);
/* harmony import */ var _types_randomid_js__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(56);
/* harmony import */ var _types_stack_js__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(19);
/* harmony import */ var _types_tokenlist_js__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(28);
/* harmony import */ var _types_typeof_js__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(17);
/* harmony import */ var _types_uniquequeue_js__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(29);
/* harmony import */ var _types_validate_js__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(14);
/* harmony import */ var _types_version_js__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(57);
/* harmony import */ var _util_clone_js__WEBPACK_IMPORTED_MODULE_53__ = __webpack_require__(15);
/* harmony import */ var _util_comparator_js__WEBPACK_IMPORTED_MODULE_54__ = __webpack_require__(58);
/* harmony import */ var _util_freeze_js__WEBPACK_IMPORTED_MODULE_55__ = __webpack_require__(59);
/**
 * @license
 * Copyright 2021 schukai GmbH
 * SPDX-License-Identifier: AGPL-3.0-only or COMMERCIAL
 * @author schukai GmbH
 */







 // find packages/monster/source/ -type f -name "*.js" -not -name "*namespace*" -not -iname  "monster.js"



















































var rootName;

try {
  rootName = _namespace_js__WEBPACK_IMPORTED_MODULE_35__.Monster.Types.getGlobalObject('__MonsterRootName__');
} catch (e) {}

if (!rootName) rootName = "Monster";
_namespace_js__WEBPACK_IMPORTED_MODULE_35__.Monster.Types.getGlobal()[rootName] = _namespace_js__WEBPACK_IMPORTED_MODULE_35__.Monster;

}();
/******/ 	return __webpack_exports__;
/******/ })()
;
});
//# sourceMappingURL=monster.dev.js.map